# UPark-Server

The UPark responsive web page server

## Backend

- ### Pre-requisites:
    - 3.10 > [Python](https://www.python.org/downloads/) >= 3.7
    - pytorch 1.10.0+cu111 https://download.pytorch.org/whl/cu111/torch_stable.html (can't install via pipenv)
    - Pip - _comes with python_
    - pipenv (install with `pip install pipenv`)
    - mysqlclient (with pip/pipenv)
    - [MariaDB 10.5](https://mariadb.org/download)

If `python`, `pip` or `pipenv` aren't accessible in the command line for Windows users, put them into environment path

Clone the `upark-server` repo. `git clone https://capstone-cs.eng.utah.edu/upark/upark-server.git`

- ### Start Environment:
    - `cd upark-server\backend`
    - Install the required packages with `pipenv install`
    - Load the environment with `pipenv shell`

- ### Initialize Database & Migrate:
    - Create a new MySQL Database: `CREATE DATABASE putnamhere;`
    - Edit `server\server\settings.py` where it says `DATABASES`. Change the info to match your database.
    - Make sure to clear all the migrations (files) in `server\api\migrations` except for init.py.
    - Create migrations to the database:`python manage.py makemigrations`
    - `python manage.py migrate --fake-initial`. This creates the django auth_tables that manage users.
    - Now in `backend\db.sql` Replace all `[CHANGEME]` tags with your new database name.
    - Run the scipts in your MariaDB MySQL command interface. `source path/to/git/folder/backend/db.sql` or `mysql databasenamehere < backend\db.sql`
    - **Go back to your db.sql and undo the name back to [CHANGEME]** (this prevents it from changing the database scripts)
    - create admin user to manage your database with `python manage.py createsuperuser`
    - fill the database with lot data using the database seeding script:
        - run `python manage.py seed --mode=refresh` to clear then restore the tables
        - run `python manage.py seed --mode=clear` to wipe the tables (except for any superusers)
    - Run the server: `python manage.py runserver [path]`

- ### Initialize some instances (might change with more updates):
    - Log into server `localhost:8000/admin` with your superuser credentials
    - You can add parking lots in here
    - See the list of parking lots with `localhost:8000/api/lot` and one parking lot with `localhost:8000/api/lot/putlotnumberhere`

- ### To run API tests:
    - `cd` to `backend/server`, then run `python manage.py test --testrunner="api.tests.ExistingDBTestRunner"`
    - note: Tests assume empty database (database referenced in settings.py)

- ### Run Django API on production (or through LAN):
    - Add frontend web path to CORS allowed and whitelist in `settings.py`
    - Change SECRET_KEY in `settings.py`
    - `python runserver.py [address:port]`

## Frontend:
- ### Pre-requisites:
    - npm & node.js - _[Linux & MacOS nvm](https://docs.npmjs.com/downloading-and-installing-node-js-and-npm) or [nvm-windows](https://github.com/coreybutler/nvm-windows)_

- ### Initialize frontend modules:
    - cd into the front-end server: `cd frontend`
    - Install node modules (only install once): `npm install`
    - Once the installation is done you can start the server: `npm run start:dev` to run with `.env.development` settings.

- ### Testing:
    - Run backend and frontend in development mode (ensure database is seeded as well)
    - Enter backend pipenv: `cd backend`, then `pipenv shell`
    - Install Pylenium: `pip install pyleniumio`
    - Switch back to frontend folder `cd ../frontend`
    - Run tests: `python3 -m pytest tests -n 3`

The default frontend address is `localhost:3000` in development mode.

- ### Production:
    - Make sure to `npm install` to get the required packages
    - Change the URLS in .env.production to match the backend API address (without trailing slash), desired host to serve frontend, and grafana address
    - To serve a dynamic webpage: `npm run start:prod`
    - To build a static bundled site (doesn't require packages): `npm run build:production`, `npm install -g serve`, `serve -s build`
    

## Sensor Hardware Metrics (instructions for deployed Ubuntu server):
 - ### InfluxDB (Timeseries DB for storing sensor harware metrics):
    - `sudo apt install influxdb`
    - `sudo systemctl enable influxd` (`influxd`, not `influxdb`). Will cause InfluxDB to automatically start at startup.
 - ### Grafana (graphing service):
    - `sudo apt install grafana`
    - `sudo systemctl enable grafana-server` (make sure grafana also starts automatically)
    - configure `/etc/grafana/grafana.ini`
        - allow anonymous access by setting `enabled = true` under `[auth.anonymous]` section
        - disable login form by setting `disable_login_form = true` under `[auth]` section
        - allow embedding panels by setting `allow_embedding = true` under [security] section
    - Add InfluxDB datasource
        - navigate to port 3000 to view Grafana, hover over gear icon in sidebar and select "Data sources"
        - click "Add data source" and fill with the following information:
            - Name: `InfluxDB telegraf`
            - URL: `http://localhost:8086` (8086 is the default port for InfluxDB)
            - Database: `telegraf_metrics`
            - User: `telegraf`
            - Password: `telegraf`
        - click "Save & test" to ensure working communication with InfluxDB
    - Add "Telegraf: system dashboard" (pre-made dashboard used for displaying system metrics, developed by Lex Rivera):
        - hover over the plus icon on the Grafana sidebar and select the "Import" button
        - upload the json file `telegraf_system_dashboard.json` from the upark `grafana_resources` folder 
        - Confirm each of the Grafana environment variables in `.env.production` and `.env.development` match the new dashboard information  so that the frontend can load the correct panels.







