from geopy.distance import great_circle
from api.models import *
from django.db.models import F

# pre process filters that are in a space separated string
def parseFilters(filters):
    filters = filters.split()
    return {'passes' : filters}


# This function sorts a list of objects by proximity to a set of lat/long coordinates 
# and returns a list of those objects ordered closest to furthest.
def sort_by_proximity(coordinates, list_to_sort):
    return sorted(list_to_sort, key=lambda obj: great_circle(coordinates, (obj['latitude'],obj['longitude'])))

# This function performs a search of database parking lots if terms are provided and returns a list of parking lots
# and their associated information in order from closest to furthest.
def search_and_sort_lots(search_terms="", location=None, filters=""):
    
    if search_terms == "*":
        search_terms = ""

    lots = None
    filters = parseFilters(filters)
    filtered_passes = Pass.objects.filter(shortname__in=filters['passes'])
    filtered_acc_passes = AcceptedPass.objects.filter(passid__in=filtered_passes)
        
    if search_terms == "":
        lots = (ParkingLot.objects.all().filter(lotid__in=filtered_acc_passes.values('lotid'))
                                        .values())
    else:
        lots = (ParkingLot.objects.all().filter(lotid__in=filtered_acc_passes.values('lotid'))
                                        .filter(name__icontains=search_terms)
                                        .values())
    
    data = []
    
    if location != None:
        lots = sort_by_proximity(location, lots) # After search, sort everything from closest to furthest

    # Get all relevant parking lot data for the frontend, including passid, accpassid, shortname, and extrance exit counts.
    for lot in lots:
        accpasses = list(AcceptedPass.objects.all().filter(lotid=lot['lotid'])
                    .select_related("passid__shortname", "passid__name")
                    .values('accpassid', 'allottedstalls', shortname=F('passid__shortname'), name=F('passid__name')))
        enexcount = EntranceExit.objects.filter(lotid=lot['lotid']).count()
        
        capacity = 0
        for accpass in accpasses:
            capacity += accpass['allottedstalls']
        
        percentfull = 1.0 # If capacity of a lot is zero then default percent full to 100%
        if capacity != 0:
            percentfull = lot['usedstalls'] / capacity

        obj = {"lot": lot, "accpasses": accpasses, "enexcount": enexcount, "percentfull": percentfull}
        if location != None:
            obj["distance"] = great_circle(location, (lot['latitude'],lot['longitude'])).miles
        data.append(obj)
    
    return data