from django.contrib import admin
from api.models import ParkingLot, CvImageSensor, User, EntranceExit, Pass, AcceptedPass
from django import forms

# Register your models here.
from django.contrib.auth import get_user_model
admin.site.register(ParkingLot)
admin.site.register(CvImageSensor)
admin.site.register(EntranceExit)
admin.site.register(Pass)
admin.site.register(AcceptedPass)
from django.contrib.auth.admin import UserAdmin 

class UserCreationForm(forms.ModelForm):
    password1 = forms.CharField(label='Password', widget=forms.PasswordInput)
    password2 = forms.CharField(label='Password confirmation', widget=forms.PasswordInput)

    class Meta:
        model = User
        fields = '__all__'

    def clean_password2(self):
        password1 = self.cleaned_data.get("password1")
        password2 = self.cleaned_data.get("password2")
        if password1 and password2 and password1 != password2:
            raise forms.ValidationError("Passwords don't match")
        return password2

    def save(self, commit=True):
        user = super().save(commit=False)
        user.set_password(self.cleaned_data["password1"])
        if commit:
            user.save()
        return user

class CustomUserAdmin(UserAdmin):
    add_form = UserCreationForm
    add_fieldsets = (
        (None, {
            'classes': ('wide',),
            'fields': ('email','username', 'first_name', 'last_name', 'is_sensor', 'password1', 'password2')}
        ),
    )

admin.site.register(User, CustomUserAdmin)