from openpyxl import load_workbook
import pickle
import math
from os.path import exists

LOT_METADATA = "../../lot_data_spreadsheets/Lot Names- Master.xlsx"
STALL_TOTALS = "../../lot_data_spreadsheets/Stall totals by lot- Oct 2021.xlsm"


def get_lot_numbers_and_names():
    """return a dictionary of lot_number -> lot_name"""
    lot_name_sheet = load_workbook(filename = LOT_METADATA).active
    lot_number_cells = lot_name_sheet['A3':'A139']
    lot_name_cells = lot_name_sheet['F3':'F139']
    lot_status = lot_name_sheet['C3':'C139']

    numsxnames = {}
    for i, num_cell in enumerate(lot_number_cells):
        num = num_cell[0].value
        name = lot_name_cells[i][0].value
        status = lot_status[i][0].value
        if 'unassigned' in name or 'reserved' in name  or 'U.S.A.' in name or status != None:
            continue
        if not isinstance(num, int): #filter out all lots with multiple levels for now (parking garages)
            numsxnames[int(str(num).split('.')[0])] = "".join(name.split("Level")[0])
            continue
        numsxnames[num] = name
    return numsxnames

def get_lot_stall_passes():
    """return a dictionary of lot_number -> (U_pass_count, A_pass_count, D_pass_count)"""
    stall_totals_sheet = load_workbook(filename = STALL_TOTALS)['TYPExlot']
    lot_number_cells = stall_totals_sheet['A4':'A186']
    U_pass_cells = stall_totals_sheet['AD4':'AD186']
    A_pass_cells = stall_totals_sheet['B4':'B186']
    D_pass_cells = stall_totals_sheet['G4':'G186']
    V_pass_cells = stall_totals_sheet['AE4':'AE186']
    P_pass_cells = stall_totals_sheet['V4':'V186']

    numsxpasses = {}
    for i, num_cell in enumerate(lot_number_cells):
        num = num_cell[0].value
        u_count = U_pass_cells[i][0].value or 0
        a_count = A_pass_cells[i][0].value or 0
        d_count = D_pass_cells[i][0].value or 0
        v_count = V_pass_cells[i][0].value or 0
        p_count = P_pass_cells[i][0].value or 0

        if not isinstance(num, int): #filter out all lots with multiple levels for now (parking garages)
            num = str(num).split('.')[0]
            if num in numsxpasses:
                u_count += numsxpasses[num][0]
                a_count += numsxpasses[num][1]
                d_count += numsxpasses[num][2]
                v_count += numsxpasses[num][3]
                p_count += numsxpasses[num][4]
            else:
                numsxpasses[num] = (u_count, a_count, d_count, v_count, p_count)
        else:
            numsxpasses[num] = (u_count, a_count, d_count, v_count, p_count)
    return numsxpasses

def get_lots_and_passes():
    """return a dictionary of lot_number -> (lot_name, (U_pass_count, A_pass_count, D_pass_count, ...))"""
    
    # check if data has already been parsed and stored
    pickled_lot_data_path = '../../lot_data_spreadsheets/lot_data.pickle'
    if exists(pickled_lot_data_path):
        with open(pickled_lot_data_path, 'rb') as f:
            return pickle.load(f)
    else:
        nums_x_names = get_lot_numbers_and_names()
        nums_x_pass_counts = get_lot_stall_passes()

        lot_number_to_name_and_passes = {}

        for num in nums_x_names:
            if num in nums_x_pass_counts:
                lot_number_to_name_and_passes[int(num)] = (nums_x_names[num], nums_x_pass_counts[num])
        
        # write out the parsed data
        with open(pickled_lot_data_path, 'wb') as f:
            pickle.dump(lot_number_to_name_and_passes, f)

        return lot_number_to_name_and_passes