from django.core.files.storage import FileSystemStorage
from django.db import models
from django.http import request
from django.utils.translation import gettext_lazy as _
from django.conf import settings
import fnmatch
import os

class AcceptedPass(models.Model):
    accpassid = models.PositiveIntegerField(db_column='accPassID', primary_key=True)  # Field name made lowercase.
    lotid = models.ForeignKey('ParkingLot', models.DO_NOTHING, db_column='lotID')  # Field name made lowercase.
    passid = models.ForeignKey('Pass', models.DO_NOTHING, db_column='passID')  # Field name made lowercase.
    allottedstalls = models.SmallIntegerField(db_column='allottedStalls')  # Field name made lowercase.

    class Meta:
        managed = False
        db_table = 'AcceptedPass'
        unique_together = (('lotid', 'passid'),)


class EntranceExit(models.Model):
    enid = models.AutoField(db_column='enID', primary_key=True)  # Field name made lowercase.
    lotid = models.ForeignKey('ParkingLot', models.DO_NOTHING, db_column='lotID', null = True)  # Field name made lowercase.
    longitude = models.DecimalField(max_digits=10, decimal_places=6)
    latitude = models.DecimalField(max_digits=10, decimal_places=6)
    class Meta:
        managed = False
        db_table = 'EntranceExit'


class ParkingLot(models.Model):
    lotid = models.PositiveIntegerField(db_column='lotID', primary_key=True)  # Field name made lowercase.
    name = models.CharField(unique=True, max_length=100)
    longitude = models.DecimalField(max_digits=10, decimal_places=6)
    latitude = models.DecimalField(max_digits=10, decimal_places=6)
    usedstalls = models.PositiveSmallIntegerField(db_column='usedStalls')  # Field name made lowercase.
    timecountupdated = models.DateTimeField(db_column='timeCountUpdated', blank=True, null=True)  # Field name made lowercase.

    class Meta:
        managed = False
        db_table = 'ParkingLot'


class Pass(models.Model):
    passid = models.PositiveIntegerField(db_column='passID', primary_key=True)  # Field name made lowercase.
    shortname = models.CharField(db_column='shortName', unique=True, max_length=2)  # Field name made lowercase.
    name = models.CharField(unique=True, max_length=50)

    class Meta:
        managed = False
        db_table = 'Pass'


#-----------------USER-----------------------#
from django.contrib.auth.models import AbstractUser
class User(AbstractUser):
    is_sensor = models.BooleanField(default=False)


class CvImageSensor(models.Model):
    user = models.OneToOneField(User ,on_delete=models.CASCADE, db_column='userID') #user.id <pk>
    sensorid = models.PositiveIntegerField(db_column='sensorID', primary_key=True)  # Field name made lowercase.
    enid = models.OneToOneField('EntranceExit', models.DO_NOTHING, db_column='enID')  # Field name made lowercase.
    timelastupdate = models.DateTimeField(db_column='timeLastUpdate', blank=True, null=True)  # Field name made lowercase.
    isentranceside = models.IntegerField(db_column='isEntranceSide')  # Field name made lowercase.
    imageurl = models.CharField(db_column='imageURL', max_length=200, blank=True, null=True)  # Field name made lowercase.
    imagetime = models.DateTimeField(db_column='imageTime', blank=True, null=True)  # Field name made lowercase.

    class Meta:
        managed = False
        db_table = 'CvImageSensor'

#-----------------SETUP-----------------------#

# This class overwrites any file named profile in the given directory in order to maintain a unique profile image
class OverwriteStorage(FileSystemStorage):

    # def get_available_name(self, name, max_length=None):
    #     # Get a list of all files in directory
    #     for rootDir, subdirs, filenames in os.walk('./media/images'):
    #         # Find the files that matches the given patterm
    #         for filename in fnmatch.filter(filenames, 'profile.*'):
    #             try:
    #                 os.remove(os.path.join(rootDir, filename))
    #             except OSError:
    #                 print("Error while deleting file")
    #     return name
    def get_available_name(self, name,  max_length=None):
        if self.exists(name):
            os.remove(os.path.join(settings.MEDIA_ROOT, name))
        return name

# This function names the image as "profile" and appends the correct file extension
def upload_to_folder(instance, filename):
    split_tup = os.path.splitext(filename)
    #add folder path if not None
    folder_path = instance.folder if len(instance.folder) > 0 else None
    filepath =  '/'.join(filter(None, [folder_path, filename]))
    # extract the file name and extension
    return filepath

# This class defines the image for the POST command to upload a profile photo
class MediaStorage(models.Model):
    description = models.CharField(max_length=255, blank=True)
    file = models.FileField(_("File"), upload_to = upload_to_folder, storage=OverwriteStorage,blank=False)
    folder = models.CharField(max_length=255, blank=True)
    # TODO: Options to overwrite logo.png or system_info.json or NewFile, etc.. (storage=OverwriteStorage())
    # TODO: Media table in DB check for deleted files


