import os
import sys

# add to the system path so filenames/imports can be relative
directory = f'{os.path.dirname(os.path.realpath(__file__))}/../'
sys.path.insert(0, directory)

import schedule
import time
import requests
import signal
from datetime import datetime
from predictor import UpdateType
import predictor
import server.settings as settings

def interupt_handler(signum, frame):
    print('Predictor exiting...')
    sys.exit()


def schedule_predictor(update_type):
    
    if update_type == UpdateType.MINUTE:
        schedule.every().minute.at(":00").do(predictor._update, update_type)
    elif update_type == UpdateType.HALFHOUR:
        schedule.every().hour.at(":00").do(predictor._update, update_type)
        schedule.every().hour.at(":30").do(predictor._update, update_type)
    else:
        print("Unsupported update type selected. Exiting predictor.")
        sys.exit()

def main():
    signal.signal(signal.SIGINT, interupt_handler)
    
    full_address = sys.argv[1]

    print('Predictor scheduling...')
    update_type = settings.PREDICTOR['UPDATE_TYPE']
    schedule_predictor(update_type)

    wait_time_max = 60 # wait one minute
    server_running = False
    start_ts = datetime.now().timestamp()

    while True:
        try:
            # check if server is running
            response = requests.get(f'http://{full_address}/api/dummy/')
        except:
            curr_ts = datetime.now().timestamp()
            elapsed_secs = curr_ts - start_ts
            
            # if server was running and stopped, or if it hasn't started 
            #  in a given time period
            if server_running or elapsed_secs > wait_time_max:
                print('Server is not running. Stopping predictor.')
                break
            else:
                continue
        
        server_running = True

        schedule.run_pending()
        time.sleep(15)

if __name__ == "__main__":
    main()