import axios from "axios";
import React, { useEffect, useState } from "react";
import {Link} from "react-router-dom";
import {ReactComponent as UParkSvg} from "../../assets/icons/upark.svg";
import QuickSearchBar from "./quicksearch/QuickSearchBar";

/**
 * Main Page of the frontend. Include other components as a good practice :)
 * @returns App.js DOM element
 */
function AdminNav() {
  const [systemName, setSystemName] = useState(<><span className='p-0 m-0 space-x-0 font-extrabold'>U</span>
  <span className='p-0 m-0 font-normal tracking-tight'>Park</span></>);

  const custom_image_url = `${process.env.REACT_APP_API_URL}/api/media/images/profile.png`;
  var http = new XMLHttpRequest();
  http.open('HEAD', custom_image_url, false);
  http.send();
  var image;
  if(http.status !== 404){
    image = <img className="w-[48px] h-[48px] align-middle inline-block mr-2 rounded-xl" alt="icon" src={custom_image_url} />;
  } else {
    image = <UParkSvg className='inline' width='50' height='50'/>;
  }

  useEffect(()=>{
    const sysInfoUrl = `${process.env.REACT_APP_API_URL}/api/setup/systeminfo/`;
    const config = {url: sysInfoUrl,
                    method: "GET",
                    headers: {"Content-Type": "application/json",
                    Authorization: `Bearer ${localStorage.getItem("token")}`}};
    axios(config)
        .then((response)=>{
            const sysName = response.data["systemName"];
            setSystemName(<span className='p-0 m-0 font-normal tracking-tight'>{sysName}</span>);
        })
        .catch((error)=>{
            console.error(error);
        })
  }, [])


  return (
    //   Header Navigation Bar
    <div className="flex w-full admin-navbar">
    <nav className="w-full bg-white rounded-b-lg shadow-lg">
        <div className="flex items-center justify-between px-8 py-2 md:px-10 md:gap-x-8">
            {/* UPark Icon Left */}
            <div className="flex items-center justify-start gap-1">
                <Link to="/admin/dashboard"
                  className="hidden text-5xl  text-transparent align-middle md:inline-block bg-clip-text bg-gradient-to-br text-[#ef3d59] md:text-3xl">
                    {image}
                    {systemName}
                </Link>
            </div>
            {/* Search Bar Middle */}
            <div className="flex grow z-[2000]">
                <div className="flex items-center w-full max-w-full p-2 mr-4">
                    <div className="w-full pl-3 text-lg font-bold bg-transparent outline-none text-neutral-600 focus:outline-none">
                      <QuickSearchBar/>
                    </div>
                </div>
            </div>
            {/* Nav Bar Right */}
            <div className="hidden -mx-2 md:flex">
                <Link to="/admin/setup" className="px-2 py-2 text-gray-800 rounded hover:bg-gray-900 hover:text-gray-100 hover:font-medium md:mx-2">Setup</Link>
                <Link to="/admin/login" className="px-2 py-2 text-gray-800 rounded hover:bg-gray-900 hover:text-gray-100 hover:font-medium md:mx-2">Login</Link>
                <Link to="/admin/logout" className="px-2 py-2 text-gray-800 rounded hover:bg-gray-900 hover:text-gray-100 hover:font-medium md:mx-2">Logout</Link>
                <Link to="/admin/dashboard" className="px-2 py-2 text-gray-800 rounded hover:bg-gray-900 hover:text-gray-100 hover:font-medium md:mx-2">Dashboard</Link>
            </div>
        </div>
    </nav>
    </div>
  );
}

export default AdminNav;

