import React, { useState, useEffect, Fragment } from "react";
import axios from "axios";
import { ChevronDownIcon } from '@heroicons/react/solid';
import { Menu, Transition } from '@headlessui/react';
import { useHistory } from 'react-router'
export function ParkingLotAccPassAdd({ lotid, passData, parentRefreshHandler }) {
  const [startAdd, setStartAdd] = useState(false);
  const [apiError, setApiError] = useState();
  const [availablePasses, setAvailablePasses] = useState();
  const history = useHistory();
  useEffect(() => {
    //find all available passes that was set in system
    //If the user want to add a new permit type, they'll have to add that in passes.
	axios({
		url:`${process.env.REACT_APP_API_URL}/api/lot/${lotid}/availableacceptedpasses/`,
		method: "GET",
		headers: {
        "Content-Type": "application/json",
	},
	})
	.then(response=>{
		setAvailablePasses(response.data);
	})
	.catch(error=>{
		console.error(error);
		setApiError(true);
	})
  }, [passData, lotid]);

  const handleAddPass = (e, pass) => {
    if (e.preventDefault) e.preventDefault();
	const acceptedPassData = {
		lotid:lotid,
		passid:pass.passid,
		allottedstalls:0,
	}
    axios( {
      url: `${process.env.REACT_APP_API_URL}/api/acceptedpass/`,
      method: "POST",
	  headers: {
        Authorization: `Bearer ${localStorage.getItem("token")}`,
        "Content-Type": "application/json",
		},
		data: JSON.stringify(acceptedPassData),
		withCredentials: true,
    })
	.then(response=>{
		setStartAdd(false);
		if (parentRefreshHandler) parentRefreshHandler()
		else history.go(0);

	})
	.catch(error=>{
		console.error(error);
		setApiError(true);
	})
  };
  return (
    <>
      {!startAdd && ( // Add Pass button shows up initially
        <button onClick={(e) => {e.preventDefault(); setStartAdd(true)}} className="flex flex-row items-baseline justify-start gap-1 tracking-wide">
          <i className="invisible fa-solid fa-circle-xmark"></i>
          <i className="text-sm fa-solid fa-plus"></i>
          <span className="font-normal">Add Passes</span>
        </button>
      )}
	  {!!(startAdd && availablePasses && availablePasses.length === 0)&&(
		  <div className="flex flex-row items-baseline justify-start gap-1 tracking-wide">
          <span className="text-sm font-normal">All pass types added</span>
        </div>
	  )}
	  {!!(startAdd && availablePasses && availablePasses.length) && ( //if startAdding and there are available passes
		<Menu as="div" className="relative mx-auto text-left w-max">
          <Menu.Button className="inline-flex justify-center w-full px-1 py-1 text-sm font-medium text-black bg-white border rounded-md bg-opacity-20 hover:bg-opacity-30 focus:outline-none focus-visible:ring-2 focus-visible:ring-slate-400 focus-visible:ring-opacity-75">
            Add Pass
            <ChevronDownIcon
              className="w-5 h-5 ml-2 -mr-1 text-violet-200 hover:text-violet-100"
              aria-hidden="true"
            />
          </Menu.Button>
        <Transition
          as={Fragment}
          enter="transition ease-out duration-100"
          enterFrom="transform opacity-0 scale-95"
          enterTo="transform opacity-100 scale-100"
          leave="transition ease-in duration-75"
          leaveFrom="transform opacity-100 scale-100"
          leaveTo="transform opacity-0 scale-95"
        >
          <Menu.Items className="absolute w-full py-1 mt-1 overflow-auto text-base bg-white rounded-md shadow-lg max-h-60 ring-1 ring-black ring-opacity-5 focus:outline-none sm:text-sm">
			{availablePasses.map(function (pass,idx){
				return (
				<div key={pass.passid} className="px-1 py-1 ">
				<Menu.Item>
				{({ active }) => (
					<button
					  onClick={(e)=> handleAddPass(e,pass)}
					  className={active ? 'text-gray-900 group flex rounded-md items-center w-full px-2 py-2 text-sm bg-gray-100 hover:text-slate-800' : ' group flex rounded-md items-center w-full px-2 py-2 text-sm bg-white text-black'}

					>
					  {pass.shortname && <span className="mr-2 text-lg font-bold text-amaranth-500">{pass.shortname}</span>}
					  <span className="uppercase">{pass.name}</span>
					</button>
					)}
				</Menu.Item>
			   </div>)
			})}

          </Menu.Items>
        </Transition>
      </Menu>
	  )}
    </>
  );
}
