import React, { useState, useEffect, Fragment } from "react";
import axios from "axios";
import ContentEditable from "react-contenteditable";
import {useHistory} from "react-router";
export default function ParkingLotMiniPass(props) {
  const [pass, setPass] = useState();
  const [passDataNew, setPassDataNew] = useState();
  const [shouldRefresh, setShouldRefresh] = useState();
  const [apiError, setApiError] = useState();
  const history = useHistory();
  useEffect(() => {
    const getPassConfig = {
      url: `${process.env.REACT_APP_API_URL}/api/acceptedpass/${props.pass.accpassid}`,
      method: 'GET',
      headers: {
				"Content-Type": "application/json",
			},
    };
    axios(getPassConfig)
    .then(response=>{
      setPass(response.data);
      setPassDataNew(response.data);
    })
    .catch(error=>{
      console.error(error);
      setApiError(true);
    })
  },[shouldRefresh, props.pass.accpassid])

  const pasteAsPlainText = (event) => {
    event.preventDefault();

    const text = event.clipboardData.getData("text/plain");
    document.execCommand("insertHTML", false, text);
  };
  const handleKeyPress = (e, field) => {
    var keyCode = e.which || e.keyCode;
    // HIT ENTER
    if (keyCode === 13) {
      e.preventDefault();
    }
  };
  const handlePassTotalOnChange = (e, pass) => {
    if (e.preventDefault) e.preventDefault();
    let newValue = parseInt(e.target.value);
    if (!newValue)
      newValue=0;
    setPassDataNew({ ...passDataNew, ["allottedstalls"]: newValue});
  };
  const handleSubmitChanges = (e, field) => {
    if (e.preventDefault) e.preventDefault();
    const passPatchConfig = {
      url: `${process.env.REACT_APP_API_URL}/api/acceptedpass/${props.pass.accpassid}`,
      method: "PATCH",
      headers: {
        Authorization: `Bearer ${localStorage.getItem("token")}`,
        "Content-Type": "application/json",
      },
      data: passDataNew,
      withCredentials: true,
    };
    axios(passPatchConfig)
      .then((response) => {
        setShouldRefresh(shouldRefresh ? false : true);
      })
      .catch((error) => {
        setApiError(error);
        console.error(error);
      });
  };
  const handleDeletePass = (e)=>{
    e.preventDefault();
    axios( {
      url: `${process.env.REACT_APP_API_URL}/api/acceptedpass/${props.pass.accpassid}`,
      method: "DELETE",
      headers: {
        Authorization: `Bearer ${localStorage.getItem("token")}`,
      },
      withCredentials: true,
    })
    .then(response=>{
      setPass();
      setPassDataNew();
      if (props.parentRefreshHandler) props.parentRefreshHandler()
      else history.go(0);

    })
    .catch(error=>{
      setApiError(error);
      console.error(error);
    })

  }

  return(
      <Fragment>
    {pass && passDataNew && (
        <div className="flex flex-row flex-wrap items-center gap-1 tracking-wide break-words pass group">
        <button
          onClick={(e) => handleDeletePass(e)}
          className="invisible text-red-400 group-hover:visible">
          <i className="fa-solid fa-circle-xmark"></i>
        </button>
        <span className="text-lg font-extrabold text-amaranth-500">{props.pass.shortname}</span>
        <span className="text-xs">&bull;</span>
        <ContentEditable
          html={passDataNew.allottedstalls.toString()}
          onPaste={pasteAsPlainText}
          onKeyDown={(e) => handleKeyPress(e, pass)}
          onChange={(e) => handlePassTotalOnChange(e, pass)}
          className="underline underline-offset-4 decoration-indigo-600 decoration-dotted focus:no-underline hover:no-underline hover:outline-dashed outline-offset-2 outline-sky-500 focus:outline-2 focus:outline-dotted focus:bg-slate-200"
        />
        <span className="font-normal">spaces</span>
        <button
          onClick={(e) => handleSubmitChanges(e, props.pass.accpassid)}
          className={(parseInt(passDataNew["allottedstalls"]) === parseInt(pass["allottedstalls"])) ? "hidden" : "flex tracking-wide truncate text-green-400 hover:text-green-600 hover:font-bold"}
        >
          <i className="text-xl fa-solid fa-check"></i>
        </button>
      </div>
    )}
    </Fragment>
  )
}
