import React from "react";
import { useParams, Switch, Route, NavLink } from "react-router-dom";
import ParkingLots from "../parkinglot/ParkingLots";
import Statistics from "../statistics/Statistics";
import Sensors from "../sensor/Sensors"
import Passes from "../pass/Passes"
import EntranceExits from "../entranceexit/EntranceExits"
import NotFound from "../notfound/NotFound";
import Announcements from "../announcement/Announcements"
import { useSelector, useDispatch } from "react-redux";

function ActionBar() {
  // ToLoad Dictionary
  const actionBarList = {
    ParkingLots: <ParkingLots />,
    Sensors: <Sensors />,
    Passes: <Passes />,
    EntranceExits: <EntranceExits />,
    Statistics: <Statistics />
  };
  const isShowing = useSelector((state) => state.actionBar.showing);
  const componentToLoad = useSelector((state) => state.actionBar.componentToLoad);
  let {whichComponent} = useParams();
  const width = whichComponent === 'statistics' ? 'w-[100%]' : 'w-80 md:w-96';
  return (

      <div
        className="action-bar bg-white flex flex-col h-full self-center antialiased rounded-tl-[50px] z-[1200] text-dark-700 font-semibold hover:rounded-tl-md border shadow space-y-2  p-2 inset-y-0 left-0 transform transition-all duration-200"
        style={{
          transform: whichComponent ? "translateX(0px)" : "translateX(100%)",
          width: whichComponent === 'statistics' ? '100%' : '24rem'
        }}
      >
        <div className="flex flex-col z-[1200] overflow-y-auto">

          <div className="flex flex-row items-end justify-center p-1">
            <NavLink
             to="/admin/dashboard/"
             className="flex z-[1100] flex-row justify-center p-2 transition-all duration-500 transform bg-white border rounded-full shadow-lg w-8 h-8 group hover:w-36 hover:justify-around hover:bg-amaranth-500 border-amaranth-300/20 text-slate-700">
              <span className="absolute self-center invisible text-sm text-white truncate group-hover:text-lg group-hover:visible group-hover:flex group-hover:relative">Hide Panel</span>
              <i className="flex self-center text-lg transition-colors duration-700 fa-solid fa-chevron-right text-amaranth-400 group-hover:text-white"></i>
            </NavLink>
          </div>
          {/* Show Component based on Redux */}

          <Switch>
            <Route path="/admin/dashboard/parkinglots/">
              <ParkingLots/>
            </Route>
            <Route path="/admin/dashboard/sensors/">
              <Sensors/>
            </Route>
            <Route path="/admin/dashboard/passes/">
              <Passes/>
            </Route>
            <Route path="/admin/dashboard/entranceexits/">
              <EntranceExits/>
            </Route>
            <Route path="/admin/dashboard/statistics/">
              <Statistics/>
            </Route>
            <Route path="/admin/dashboard/announcements/">
              <Announcements/>
            </Route>
            {/* Render 404 only when the param is specified */}
            {whichComponent && <Route path="*"><NotFound/></Route> }

        </Switch>
        </div>
        </div>

  );
}
export default ActionBar;
