import React, { useState, useEffect } from "react";
import { GeoJSON, useMap } from "react-leaflet";
import axios from "axios";
import {useHistory} from "react-router";
import { useDispatch, useSelector } from "react-redux";
import L from "leaflet";
export default function LotsLayer(props) {
  const [alreadyPanToMap, setAlreadyPanToMap] = useState(false);
  let history = useHistory();
	// const [lotPercents, setLotPercents] = useState();
  const lotStallsRemaining=useSelector((state) => state.map.lotStallsRemaining);
  const geoJsonRef = React.useRef();
	const map = useMap();
  const adminMapFlyToLatLng = useSelector((state)=>state.map.adminMapFlyToLatLng);
  const adminMapFlyToZoomLevel = useSelector((state)=>state.map.adminMapFlyToZoomLevel);
	useEffect(() => {
		if (map && geoJsonRef.current && !alreadyPanToMap) {
      setTimeout(() => {
        map.flyToBounds(geoJsonRef.current.getBounds());
        setAlreadyPanToMap(true);
      }, 500);
    }
	});

  // UseEffect to fly to bounds when adminMapFlyToLatLng changes
  useEffect(()=>{
    if (map && geoJsonRef.current && adminMapFlyToLatLng){
      if (adminMapFlyToZoomLevel)
        map.setView(adminMapFlyToLatLng, adminMapFlyToZoomLevel);
      else
        map.setView(adminMapFlyToLatLng);
    }
  },[adminMapFlyToLatLng]);

  // This function colors lots based on percentage full thresholds. It is being kept in case there is a need to revert to it.
  // function setColorThresholdPercents(percent) {
  //   // percent = Math.random(); // Used for rudimentary simulation of lot coloring
  //   if (percent === "nodata") {
  //     return "#d3d3d3";
  //   }
  //   if (percent < 0.25) {
  //     return "#60d394";
  //   } else if (percent < 0.75) {
  //     return "#ffd97d";
  //   } else {
  //     return "#ee6055";
  //   }
  // }

  // This function colors lots based on total spaces still available. It is the current implementation
    function setColorThresholdRemainingStalls(stallsRemaining){
      // No used stall data exists color
      if (stallsRemaining === "nodata") {
        return "#d3d3d3";
      }
      // most available stalls
      if (stallsRemaining > 50) {
        return "#60d394";
      }
      // medium available stalls
      else if (stallsRemaining > 25) {
        return "#ffd97d";
      }
      // least available stalls
      else {
        return "#ee6055";
      }
    }

  //DO WHATEVER YOU WANT WITH EACH feature/layer
  // Note: lotStallsRemaining changes to lotPercents if a percentage threshold is used
  const onEachFeature = React.useCallback((feature, layer) =>{
      layer.setStyle({
        color: setColorThresholdRemainingStalls(lotStallsRemaining[parseInt(feature.properties.PLOT)])
        // color: setColorThreshold(lotPercents[parseInt(feature.properties.PLOT)]), // used if reverting back to percentage thresholds
      });

    //Bind click:
    layer.on("click", function (e) {
      // e.originalEvent.DomEvent.stopPropagation(e);
      //e.originalEvent.view.L.DomEvent.stopPropagation(e)
      history.push(`/admin/dashboard/parkinglots/edit/${parseInt(feature.properties.PLOT)}`);
    });
  },[lotStallsRemaining]);

	const Layer = React.useMemo(()=>{
		return <GeoJSON ref={geoJsonRef} data={props.mapData} key="map-lots-geojson" onEachFeature={onEachFeature}></GeoJSON>
	}
	,[props.mapData, lotStallsRemaining]);

    return (
			<>
			{/* Only render Geojson when mapData (geojson) and percents are loaded */}
			{props.mapData && Object.keys(lotStallsRemaining).length === Object.keys(props.mapData.features).length && Layer}
			</>
    );
}
