import axios from "axios";
import React, { useState, useEffect } from "react";

// Date Range for Admin Announcement imports
import { DateRange } from "react-date-range";
import { useParams } from "react-router";
import { useHistory, useLocation } from "react-router-dom";

import "react-date-range/dist/styles.css"; // main css file
import "react-date-range/dist/theme/default.css"; // theme css file

export default function ReadUpdateSensorForm(props) {
  let { announcementlotid } = useParams();
  const [apiError, setApiError] = useState(false);
  const [responseSuccess, setResponseSuccess] = useState(false);
  const location = useLocation();
  const history = useHistory();
  const announcementDetailURL = `${process.env.REACT_APP_API_URL}/api/adminannouncement/${announcementlotid}/`;
  const [announcementInfo, setAnnouncementInfo] = useState({
    announcement: "",
    startDate: new Date(),
    endDate: new Date(),
  });
  const [shouldRefresh, setShouldRefresh] = useState(true);

  // DateRange Use State
  const [state, setState] = useState({
    startDate: new Date(),
    endDate: null,
    key: "selection",
  });

  const handleChange = (event) => {
    setAnnouncementInfo({ ...announcementInfo, [event.target.name]: event.target.value });
    setResponseSuccess(false);
  };
  const handleSubmit = (e) => {
    e.preventDefault();
    announcementInfo.startDate = state.startDate;
    announcementInfo.endDate = state.endDate;

    const patchConfig = {
      url: announcementDetailURL,
      method: "POST",
      headers: {
        Authorization: `Bearer ${localStorage.getItem("token")}`,
        "Content-Type": "application/json",
      },
      data: { ...announcementInfo },
      withCredentials: true,
    };

    axios(patchConfig)
      .then(function (response) {
        setApiError(false);
        setResponseSuccess(true);
        setShouldRefresh(!shouldRefresh);
      })
      .catch((error) => {
        setApiError(true);
        console.error(error);
      });
  };
  //
  // UseEffect (update when lots changed) and  GET Parking LOTS function
  //
  useEffect(() => {
    const getConfig = {
      url: announcementDetailURL,
      method: "GET",
      headers: {
        "Content-Type": "application/json",
      },
    };
    axios(getConfig)
      .then((response) => {
        setAnnouncementInfo(response.data);
        if (response.data.endDate != "N/A" && response.data.endDate != "N/A")
          setState({
            ...state,
            ["endDate"]: new Date(response.data.endDate),
            ["startDate"]: new Date(response.data.startDate),
          });
      })
      .catch((error) => {
        console.error(error);
      });
  }, [announcementDetailURL, shouldRefresh]);

  return (
    <div className="flex flex-col justify-between w-full lot-post">
      <div className="max-w-sm px-1 my-2 rounded-xl">
        {/* Add a Goback button here */}
        <div className="flex flex-row w-full">
          <button
            disabled={!location.key}
            onClick={(e) => {
              e.preventDefault();
              if (location.key) history.goBack();
            }}
            className="flex flex-row justify-center p-2 transition-all duration-700 transform bg-white border rounded-full shadow-lg w-9 h-9 group hover:w-28 hover:justify-around hover:bg-amaranth-500 border-amaranth-300/20 text-slate-700"
          >
            <i className="flex self-center text-lg fa-solid fa-chevron-left text-amaranth-400 group-hover:text-white"></i>
            <span className="self-center hidden text-lg text-white truncate transition-all duration group-hover:flex">
              Go Back
            </span>
          </button>
        </div>
        <form onSubmit={handleSubmit}>
          <div className="space-y-4 space-y">
            <div>
              <label htmlFor="announcement" className="block mb-1 font-semibold text-gray-600">
                Announcement:
              </label>
              <textarea
                type="text"
                id="announcement"
                name="announcement"
                className="w-full px-2 py-2 text-sm transition-all duration-150 ease-linear bg-white border-0 rounded shadow placeholder-blueGray-300 text-blueGray-600 focus:outline-none focus:ring"
                onChange={handleChange}
                value={announcementInfo.announcement}
                required
              />
              <div className="block mb-1 font-semibold text-gray-600">
                <label htmlFor="announcement-dates" className="block mb-1 font-semibold text-gray-600">
                  Announcement Dates:
                </label>
                <DateRange
                  className="w-full tracking-wider"
                  editableDateInputs={true}
                  onChange={(item) => setState(item.selection)}
                  moveRangeOnFirstSelection={false}
                  ranges={[state]}
                  minDate={new Date()}
                />
              </div>
            </div>
            <div className="flex-row block gap-2">
              <button
                type="submit"
                className="w-full py-2 mt-4 text-lg font-semibold tracking-wider text-white rounded-md bg-gradient-to-tr from-amaranth-500 to-amaranth-400 hover:from-amaranth-500 hover:to-amaranth-300 focus:outline-none focus:ring focus:ring-pink-500"
              >
                Submit
              </button>
            </div>
          </div>
          {apiError === true && <h5>Cannot update Announcement.</h5>}
          {responseSuccess === true && <h5>Announcement created successfully</h5>}
        </form>
      </div>
    </div>
  );
}
