import axios from "axios";
import React, { useState, useEffect } from "react";
import "./Announcement.css";
import {Link} from "react-router-dom";
export default function AnnouncementsList() {
  const [apiError, setApiError] = useState(false);
  const lotListUrl = `${process.env.REACT_APP_API_URL}/api/lot/`;
  const [lotList, setLotList] = useState([]);
  const [shouldRefresh, setShouldRefresh] = useState(true);
  //
  // UseEffect (update when lots changed) and  GET Parking LOTS function
  //
  useEffect(() => {
    const getConfig = {
      url: lotListUrl,
      method: "GET",
      headers: {
        "Content-Type": "application/json",
      },
    };
    function fetchList(){
      axios(getConfig)
      .then((response) => {
        setLotList(response.data);
      })
      .catch((error) => {
        console.error(error);
      });
    }
    fetchList();
    // FETCH new data after x seconds;
    const interval = setTimeout(() => {
     setShouldRefresh(!shouldRefresh);
    }, 4000);
    return ()=>clearTimeout(interval);
  }, [lotListUrl, shouldRefresh]);

  const handleDeleteLot = (event, lotid) => {
    event.preventDefault();
    const deleteConfig = {
      url: `${process.env.REACT_APP_API_URL}/api/adminannouncement/${lotid}`,
      method: "DELETE",
      headers: {
        Authorization: `Bearer ${localStorage.getItem("token")}`,
        "Content-Type": "application/json",
      },
    };
    axios(deleteConfig)
      .then((response) => {
        setShouldRefresh(!shouldRefresh);
      })
      .catch((error) => {
        console.error(error);
      });
  };


  return (
    <div className="flex flex-col items-center justify-between flex-shrink-0 h-full overflow-y-auto lot-list">
      {lotList.map(function (data, idx) {
        return (
          <div
            key={data.lotid}
            className="grid grid-cols-12 p-5 my-1 transition duration-300 transform bg-white rounded-lg drop-shadow-lg hover:scale-101 hover:-translate-x-3"
          >
            <div className="col-span-10">
              <h4 className="my-2 text-xl font-semibold leading-tight uppercase ">{data.name}</h4>
            </div>
              <Link
                to={`/admin/dashboard/announcements/edit/${data.lotid}`}
                className="content-center text-gray-600 hover:scale-120 hover:text-black focus:ring-2 focus:ring-blue-300 font-medium rounded-full text-md px-1 py-2.5 text-center mr-2 mb-2">
                <i className="fas fa-pencil-alt"></i>
              </Link>
              <button
                onClick={(e) => handleDeleteLot(e, data.lotid)}
                className="text-red-500  hover:scale-120 hover:text-red-700 focus:ring-2 focus:ring-red-300 font-medium rounded-full text-md px-1 py-2.5 text-center mr-2 mb-2"
              >
                <i className="fas fa-trash-alt"></i>
              </button>
          </div>
        );
      })}
    </div>
  );
}

