import React from "react";
import "./LoginForm.css";
import { useState, useEffect } from "react";
import axios from "axios";
import { verifyAccessToken, refreshToken } from "../../../utils/auth";
import { Redirect } from "react-router";

const LoginForm = () => {
  const [username, setUsername] = useState("");
  const [password, setPassword] = useState("");
  const [errors, setErrors] = useState(false);
  const [isAuth, setIsAuth] = useState();
  useEffect(() => {
    //
    // Check if localstorage's token is valid still
    //
    if (localStorage.getItem("token") === null) {
      setIsAuth(false);
    } else {
      verifyAccessToken()
        .then(function (response) {
          if (response.status === 200) setIsAuth(true);
        })
        .catch((error) => {
          console.error("cached access token denied", error);
          setIsAuth(false);
        });
    }
    if (isAuth === false)
      refreshToken()
        .then(function (response) {
          if (response.status === 200) {
            localStorage.setItem("token", response.data.access);
            setIsAuth(true);
          }
        })
        .catch((error) => {
          console.error("cached refresh token denied", error);
          localStorage.removeItem("token");
          setIsAuth(false);
        });
  }, [isAuth]);

  const onSubmit = (e) => {
    e.preventDefault();
    const userCreds = {
      username: username,
      password: password,
    };
    const requestConfig = {
      url: `${process.env.REACT_APP_API_URL}/api/token/`,
      method: "POST",
      headers: {
        "Content-Type": "application/json",
      },
      data: userCreds,
      withCredentials: true,
    };
    axios(requestConfig)
      .then(function (response) {
        if (response.data.access) {
          localStorage.clear();
          localStorage.setItem("token", response.data.access);
          setIsAuth(true);
        }
      })
      .catch((error) => {
        setUsername("");
        setPassword("");
        localStorage.clear();
        setIsAuth(false);
        setErrors(true);
      });
  };

  return (
    <div>

      {(isAuth === undefined || isAuth === false) && (
        <div className="relative flex flex-col items-center min-h-screen bg-indigo-300 sm:justify-center ">
          <div className="relative w-full sm:max-w-sm">
            <div className="relative w-full max-w-sm px-10 py-8 my-2 bg-white shadow-md rounded-xl">
              <form onSubmit={onSubmit}>
                <div className="block mb-1 space-y-4 font-semibold text-gray-600 space-y">
                  <h1 className="text-2xl font-semibold text-center text-gray-600 ">Admin Login</h1>
                  <div>
                  <label htmlFor="username">Username</label> <br />
                  <input
                    name="username"
                    type="username"
                    className="w-full px-4 py-2 rounded-md outline-none bg-indigo-50"
                    value={username}
                    required
                    onChange={(e) => setUsername(e.target.value)}
                  />{" "}
                  </div>
                  <div>
                  <label htmlFor="password">Password</label> <br />
                  <input
                    name="password"
                    type="password"
                    className="w-full px-4 py-2 rounded-md outline-none bg-indigo-50"

                    value={password}
                    required
                    onChange={(e) => setPassword(e.target.value)}
                  />{" "}
                  </div>
                  <button
              type="submit"
              value="Login"
              className="w-full py-2 mt-4 text-lg font-semibold tracking-wider text-white rounded-md bg-gradient-to-tr from-purple-500 to-blue-500 hover:from-pink-400 hover:to-indigo-500 focus:outline-none focus:ring focus:ring-violet-300"
            >Login</button>
            {errors === true && <h5>Cannot log in with provided credentials</h5>}
                </div>
              </form>
            </div>
          </div>
        </div>
      )}
      {isAuth && <Redirect to={"/admin/dashboard"} />}
    </div>
  );
};

export default LoginForm;
