import React, { useState, useEffect } from "react";
import { Redirect } from "react-router";
import { verifyAccessToken, refreshToken, getBadRefreshToken } from "../../../utils/auth";

const LogoutForm = () => {
  const [loading, setLoading] = useState(true);
  const [isAuth, setIsAuth] = useState();
  useEffect(() => {
    //
    // Check if localstorage's token is valid still
    //

    verifyAccessToken()
      .then(function (response) {
        if (response.status === 200) setIsAuth(true);
      })
      .catch((error) => {
        console.error("cached access token denied");
      });

    //
    // if Access Token failed try refresh
    //
    if (isAuth !== true)
      refreshToken()
        .then(function (response) {
          if (response.status === 200) {
            localStorage.setItem("token", response.data.access);
            setIsAuth(true);
          }
        })
        .catch((error) => {
          console.error("cached refresh token denied");
          localStorage.removeItem("token");
          setIsAuth(false);
        });
  }, [isAuth]);

  const handleLogout = (e) => {
    e.preventDefault();
    getBadRefreshToken()
      .then((response) => {
        localStorage.removeItem("token");
        setIsAuth(false);
      })
      .catch((error) => {
        console.error(error);
      });
  };

  return (
    <div>
      {isAuth === true && (
        <div>
          <div className="relative flex flex-col items-center min-h-screen bg-indigo-300 sm:justify-center ">
            <div className="relative w-full sm:max-w-sm">
              <div className="relative w-full max-w-sm px-10 py-8 bg-white shadow-md rounded-xl">
                <div className="flex flex-col justify-center w-full mb-1 space-y-4 font-semibold text-gray-600 space-y ">
                  <h1 className="mx-auto text-xl font-semibold text-center text-gray-600 ">Are you sure you want to logout?</h1>
                  <button
                    type="button"
                    value="Logout"
                    onClick={handleLogout}
                    className="w-1/2 py-2 mx-auto text-lg font-semibold tracking-wider text-white rounded-md bg-gradient-to-tr from-purple-500 to-blue-500 hover:from-pink-400 hover:to-indigo-500 focus:outline-none focus:ring focus:ring-violet-300"
                  >
                    Logout
                  </button>
                </div>
              </div>
            </div>
          </div>
        </div>
      )}
      {isAuth === false && <Redirect to="/admin/login"></Redirect>}
    </div>
  );
};

export default LogoutForm;
