import React, { useState, useEffect, Fragment } from "react";
import { verifyAccessToken, refreshToken } from "../../../utils/auth";
import axios from "axios";
import { Redirect } from "react-router";
import AdminMap from "../adminmap/AdminMap";
import ActionBar from "../actionbar/ActionBar";
import SideBar from "../sidebar/SideBar";
import { Switch, Route } from "react-router-dom";
const Dashboard = () => {
  const [lotData, setLotData] = useState("");
  const [loading, setLoading] = useState(true);
  const [isAuth, setIsAuth] = useState();
  useEffect(() => {
    //
    // Check if localstorage's token is valid still
    //
    verifyAccessToken()
      .then(function (response) {
        if (response.status === 200) setIsAuth(true);
      })
      .catch((error) => {
        console.error("cached access token denied");
        setIsAuth(false);
      });

    //
    // Try to fetch data if isAuthenticated
    //
    if (isAuth === true)
      axios({
        url: `${process.env.REACT_APP_API_URL}/api/lot/`,
        method: "GET",
        headers: {
          "Content-Type": "application/json",
          Authorization: `Bearer ${localStorage.getItem("token")}`,
        },
      })
        .then((response) => {
          setLotData(response.data[0]);
          setLoading(false);
        })
        .catch((error) => {
          setLoading(false);
        });
    // If not authenticated, try refresh token
    else
      refreshToken()
        .then(function (response) {
          if (response.status === 200) {
            localStorage.setItem("token", response.data.access);
            setIsAuth(true);
          }
        })
        .catch((error) => {
          console.error("cached refresh token denied");
          localStorage.removeItem("token");
          setIsAuth(false);
        });
  }, [isAuth]);

  return (
    <Fragment>
      {loading === false && isAuth === true && (
        <div className="flex flex-col w-full overflow-hidden">
        <div className="flex flex-row items-center justify-between h-screen overflow-hidden">
            <SideBar />
            <AdminMap />
            {/* Routing the ActionBar */}
            <Switch>
              <Route path="/admin/dashboard/:whichComponent?">
                  <ActionBar/>
              </Route>
            </Switch>
          </div>
          </div>
      )}
      {isAuth === false && (
        <Redirect to="/admin/login"></Redirect>
      )}
    </Fragment>
  );
};

export default Dashboard;
