import React, { useEffect } from "react";
import * as Tooltip from "@radix-ui/react-tooltip";
import { LocationMarkerIcon } from "@heroicons/react/outline";
import { PencilAltIcon, PlusIcon } from "@heroicons/react/outline";
import { useHistory } from "react-router";
import L from "leaflet";
import { updateMapData } from "../../../redux/mapSlice";
import { useDispatch } from "react-redux";
import SensorEnexMiniAdd from "../sensor/SensorEnexMiniAdd";
import { Link } from "react-router-dom";
export default function EnExMetadataMini({ enexMetadata }) {
  const history = useHistory();
  const dispatch = useDispatch();
  const handleEnexClick = (e) => {
    //Fly to that enex in adminmap/lotslayer.js
    dispatch(
      updateMapData({
        adminMapFlyToLatLng: { lat: enexMetadata.latitude, lng: enexMetadata.longitude },
        adminMapFlyToZoomLevel: 17,
      })
    );
  };
  return (
    <>
    {enexMetadata &&(
      <div className="flex flex-col">
      <div className="flex flex-row justify-between w-full px-2 flex-nowrap">
        <Tooltip.Provider delayDuration={700} skipDelayDuration={500}>
          <Tooltip.Root>
            <Tooltip.Trigger>
              <div onClick={(e) => handleEnexClick(e)} className="inline-flex font-normal">
                <LocationMarkerIcon className="w-5 h-5 mr-2 align-bottom" />
                <span className="font-medium tracking-wide hover:underline">EnEx {enexMetadata.enid}</span>
              </div>
            </Tooltip.Trigger>
            <Tooltip.Content className="flex-col p-2 bg-white border rounded-lg shadow-4sides border-slate-700 text-slate-700">
              <div className="flex flex-col gap-1">
                <span className="inline-block px-2 font-regular tracking-wide  transition transform duration-[700ms]">
                  Enid: {enexMetadata.enid}
                </span>
                <span className="inline-block px-2 font-regular tracking-wide transition transform duration-[700ms] ">
                  Latitude: {enexMetadata.latitude}
                </span>
                <span className="inline-block px-2 font-regular tracking-wide  transition transform duration-[700ms]">
                  Longitude: {enexMetadata.longitude}
                </span>
              </div>
              <Tooltip.Arrow className="fill-slate-200" offset={1} width={18} height={10} />
            </Tooltip.Content>
          </Tooltip.Root>
        </Tooltip.Provider>
        {/* Edit EnEx? */}
        <Link to={`/admin/dashboard/entranceexits/edit/${enexMetadata.enid}`} className="w-5 h-5">
          <PencilAltIcon />
        </Link>

      </div>
      {/* child Row EnEx's sensor Add/Edit  */}
      {enexMetadata && (
        <div className="px-1 ml-5 text-sm rounded-lg bg-slate-100/40">
          <SensorEnexMiniAdd enexMetadata={enexMetadata} />
        </div>
      )}
    </div>
    )}

    </>

  );
}

// Lat Long String Utils
function toDegreesMinutesAndSeconds(coordinate) {
  var absolute = Math.abs(coordinate);
  var degrees = Math.floor(absolute);
  var minutesNotTruncated = (absolute - degrees) * 60;
  var minutes = Math.floor(minutesNotTruncated);
  var seconds = Math.floor((minutesNotTruncated - minutes) * 60);

  return degrees + "°" + minutes + "'" + seconds;
}

function convertLatDMS(lat) {
  var latitude = toDegreesMinutesAndSeconds(lat);
  var latitudeCardinal = lat >= 0 ? "N" : "S";

  return latitude + " " + latitudeCardinal;
}

function convertLongDMS(lng) {
  var longitude = toDegreesMinutesAndSeconds(lng);
  var longitudeCardinal = lng >= 0 ? "E" : "W";
  return longitude + " " + longitudeCardinal;
}
