import axios from "axios";
import React, { useState, useEffect } from "react";
import { useHistory, useLocation } from "react-router-dom";
import { useParams } from "react-router";
import DeleteButton from "../utils/DeleteButton";
import { useDispatch, useSelector } from "react-redux";
import { LocationMarkerIcon, XIcon } from "@heroicons/react/solid";
import { updateMapData } from "../../../redux/mapSlice";
export default function ReadUpdateSensorForm(props) {
  const { enexid } = useParams();
  const [apiError, setApiError] = useState(false);
  const enexDetailURL = `${process.env.REACT_APP_API_URL}/api/enex/${enexid}`;
  const location = useLocation();
  const history = useHistory();
  const dispatch = useDispatch();
  const adminPickingOnMapState = useSelector((state) => state.map.adminPickingOnMapState);
  const adminPickingOnMapLocation = useSelector((state) => state.map.adminPickingOnMapLocation);
  const [enexInfo, setEnexInfo] = useState({
    enid: "",
    lotid: "",
    longitude: "",
    latitude: "",
  });
  const [shouldRefresh, setShouldRefresh] = useState(true);

  const handleChange = (event) => {
    setEnexInfo({ ...enexInfo, [event.target.name]: event.target.value });
  };

  const handleSubmit = (e) => {
    e.preventDefault();
    const patchConfig = {
      url: enexDetailURL,
      method: "PATCH",
      headers: {
        Authorization: `Bearer ${localStorage.getItem("token")}`,
        "Content-Type": "application/json",
      },
      data: { ...enexInfo },
      withCredentials: true,
    };

    axios(patchConfig)
      .then(function (response) {
        setApiError(false);
        setShouldRefresh(!shouldRefresh);
        dispatch(updateMapData({ adminPickingOnMapLocation: undefined, adminPickingOnMapState: undefined }));
      })
      .catch((error) => {
        setApiError(true);
        console.error(error);
        dispatch(updateMapData({ adminPickingOnMapLocation: undefined, adminPickingOnMapState: undefined }));
      });
  };
  //
  // UseEffect (update when lots changed) and  GET Parking LOTS function
  //
  useEffect(() => {
    const getConfig = {
      url: enexDetailURL,
      method: "GET",
      headers: {
        "Content-Type": "application/json",
      },
    };
    axios(getConfig)
      .then((response) => {
        setEnexInfo(response.data);
      })
      .catch((error) => {
        console.error(error);
      });
  }, [enexDetailURL, shouldRefresh]);

  //
  // useEffect to update enexInfo after picking a location on Map
  //
  useEffect(() => {
    if (adminPickingOnMapState === "pick" && adminPickingOnMapLocation) {
      setEnexInfo({
        ...enexInfo,
        ["latitude"]: adminPickingOnMapLocation.lat.toFixed(6),
        ["longitude"]: adminPickingOnMapLocation.lng.toFixed(6),
      });
    }
  }, [adminPickingOnMapState, adminPickingOnMapLocation]);
  // USE effect to reset picking on map states when first load
  // and reset the picking location state on unmount
  useEffect(() => {
    dispatch(updateMapData({ adminPickingOnMapLocation: undefined, adminPickingOnMapState: undefined }));
    return () => {
      dispatch(updateMapData({ adminPickingOnMapLocation: undefined, adminPickingOnMapState: undefined }));
    };
  }, []);
  const handleDeleteEnex = () => {
    const deleteConfig = {
      url: `${process.env.REACT_APP_API_URL}/api/enex/${enexid}`,
      method: "DELETE",
      headers: {
        Authorization: `Bearer ${localStorage.getItem("token")}`,
        "Content-Type": "application/json",
      },
    };
    axios(deleteConfig)
      .then((response) => {
        dispatch(updateMapData({ adminPickingOnMapLocation: undefined, adminPickingOnMapState: undefined }));
        if (location.key) history.goBack();
        else history.go("/admin/dashboard/entranceexits");
      })
      .catch((error) => {
        console.error(error);
        setApiError(true);
        dispatch(updateMapData({ adminPickingOnMapLocation: undefined, adminPickingOnMapState: undefined }));
      });
  };
  const handlePickOnMap = (e) => {
    e.preventDefault();
    dispatch(updateMapData({ adminPickingOnMapState: "pick" }));
  };

  return (
    <div className="relative flex flex-col items-center sm:justify-center ">
      <div className="w-full p-2">
        {/* Add a Goback button here */}
        <div className="flex flex-row w-full">
          <button
            disabled={!location.key}
            onClick={(e) => {
              e.preventDefault();
              if (location.key) history.goBack();
              dispatch(updateMapData({ adminPickingOnMapLocation: undefined, adminPickingOnMapState: undefined }));
            }}
            className="flex flex-row justify-center p-2 transition-all duration-700 transform bg-white border rounded-full shadow-lg w-9 h-9 group hover:w-28 hover:justify-around hover:bg-amaranth-500 border-amaranth-300/20 text-slate-700"
          >
            <i className="flex self-center text-lg fa-solid fa-chevron-left text-amaranth-400 group-hover:text-white"></i>
            <span className="self-center hidden text-lg text-white truncate transition-all duration group-hover:flex">
              Go Back
            </span>
          </button>
        </div>
        <div className="w-full max-w-sm px-10 py-8 mx-auto my-2 bg-white shadow-md rounded-xl">
          <form onSubmit={handleSubmit}>
            <div className="space-y-4 space-y">
              <div>
                <label htmlFor="lotid" className="block mb-1 font-semibold text-gray-600">
                  Lot ID
                </label>
                <input
                  type="number"
                  id="lotid"
                  name="lotid"
                  className="w-full px-4 py-2 rounded-md outline-none bg-indigo-50"
                  onChange={handleChange}
                  value={enexInfo.lotid}
                  required
                />
              </div>

              <div className="">
                <button onClick={(e) => handlePickOnMap(e)} className="flex flex-row mt-0.5 mb-1 flex-nowrap p-2 bg-slate-100 rounded-lg">
                  <LocationMarkerIcon className="w-5 h-5 mr-2"></LocationMarkerIcon>
                  {adminPickingOnMapState === undefined && <span className="">Pick on Map</span>}
                  {adminPickingOnMapState === "pick" && <span className="">Drag the marker to pick location</span>}
                </button>
                {adminPickingOnMapState === "pick" && (
                  <button
                    onClick={(e) => {
                      dispatch(
                        updateMapData({ adminPickingOnMapLocation: undefined, adminPickingOnMapState: undefined })
                      );
                    }}
                    className="flex flex-row mt-0.5 mb-1 flex-nowrap p-2 bg-gray-200 rounded-lg"
                  >
                    <XIcon className="w-5 h-5 mr-1 "></XIcon>
                    <span className="">Cancel</span>
                  </button>
                )}
                <label htmlFor="latitude" className="block mb-1 font-semibold text-gray-600">
                  Latitude
                </label>
                <input
                  type="text"
                  id="latitude"
                  name="latitude"
                  className="w-full px-4 py-2 rounded-md outline-none bg-indigo-50"
                  onChange={handleChange}
                  value={enexInfo.latitude}
                  required
                />
              </div>
              <div>
                <label htmlFor="longitude" className="block mb-1 font-semibold text-gray-600">
                  Longitude
                </label>
                <input
                  type="text"
                  id="longitude"
                  name="longitude"
                  className="w-full px-4 py-2 rounded-md outline-none bg-indigo-50"
                  onChange={handleChange}
                  value={enexInfo.longitude}
                  required
                />
              </div>
              <div className="flex flex-row gap-2">
                <button
                  type="submit"
                  className="w-full py-2 mt-4 text-lg font-semibold tracking-wider text-white rounded-md basis-5/6 bg-gradient-to-tr from-amaranth-500 to-amaranth-400 hover:from-amaranth-500 hover:to-amaranth-300 focus:outline-none focus:ring focus:ring-pink-500"
                >
                  Submit
                </button>

                <DeleteButton
                  deleteItemHandler={handleDeleteEnex}
                  buttonText={``}
                  trashIconClass={`w-5 h-5 mt-1 mx-auto`}
                  buttonClass={`flex w-full basis-1/6 align-center py-2 mt-4 text-lg font-semibold tracking-wider bg-white text-red-600 border border-red-600 hover:bg-red-600/80 hover:text-white rounded-md place-content-center basis-1/2 focus:outline-none focus:ring focus:ring-pink-500`}
                ></DeleteButton>
              </div>
            </div>
            {apiError === true && <h5>Cannot update Entrance/Exit information.</h5>}
          </form>
        </div>
      </div>
    </div>
  );
}
