import axios from "axios";
import React, { useState, useEffect } from "react";
import { useDispatch, useSelector } from "react-redux";
import {Link} from "react-router-dom";
import { showActionBar } from "../../../redux/actionBarSlice";
import { Disclosure } from "@headlessui/react";
import { useGetEnexData } from "../adminmap/AdminMap";

export default function EntranceExitsList() {
  const [apiError, setApiError] = useState(false);
  const enexListUrl = `${process.env.REACT_APP_API_URL}/api/enex/`;
  const [shouldRefresh, setShouldRefresh] = useState(true);
  const [lotListAccordions, setLotListAccordions] = useState([]);
  const adminLotList = useSelector((state) => state.map.adminLotList);
  const getEnexData = useGetEnexData();

  //
  // UseEffect (update when lots changed) and  GET Parking LOTS function
  //
  useEffect(() => {
    const getConfig = {
      url: enexListUrl,
      method: "GET",
      headers: {
        "Content-Type": "application/json",
      },
    };

    axios(getConfig)
      .then((response) => {
        setLotListAccordions(generateLotListAccordions(response.data));
      })
      .catch((error) => {
        console.error(error);
      });

    const generateLotListAccordions = (entranceexitList) => {
      let lotList = [];
      entranceexitList.forEach(function (enex, idx) {
        let lotid = parseInt(enex.lotid);
        if (!lotList[lotid]) {
          lotList[lotid] = [];
        }
        lotList[lotid].push(enex);
      });
      return lotList;
    };
  }, [enexListUrl, shouldRefresh]);

  const handleDeleteEnex = (event, enid) => {
    event.preventDefault();
    const deleteConfig = {
      url: `${process.env.REACT_APP_API_URL}/api/enex/${enid}`,
      method: "DELETE",
      headers: {
        Authorization: `Bearer ${localStorage.getItem("token")}`,
        "Content-Type": "application/json",
      },
    };
    axios(deleteConfig)
      .then((response) => {
        setShouldRefresh(!shouldRefresh);
        getEnexData();
      })
      .catch((error) => {
        console.error(error);
      });
  };


  return (
    <div className="flex flex-col items-center justify-between flex-shrink-0 h-full overflow-y-auto rounded-xl">
      {lotListAccordions.length > 0 &&
        lotListAccordions.map(function (data, idx) {
          let lotName;
          if (adminLotList)
            lotName = adminLotList.filter((lot)=>lot.lotid == idx)[0].name;
          return (
            <Disclosure
              key={idx}
              as="div"
              className="w-[95%] m-1 mt-2 transition duration-300 transform hover:scale-[102%] hover:-translate-x-1"
            >
              {({ open }) => (
                <>
                  <Disclosure.Button className="flex justify-between w-full px-4 py-2 text-sm font-medium text-left bg-white border rounded-lg shadow border-amaranth-200 text-amaranth-500 flex-nowrap hover:bg-amaranth-200 focus:outline-none focus-visible:ring focus-visible:ring-amaranth-500 focus-visible:ring-opacity-75">
                    <span className="w-full overflow-hidden text-sm font-light text-ellipsis whitespace-nowrap ">
                      Lot <span className="font-semibold">{idx}</span> <span className="mx-1 text-xs font-semibold">{lotName}</span>
                    </span>
                    <i
                      className={open ? "fa-chevron-down w-5 h-5 fa-solid text-middle" : "fa-chevron-up w-5 h-5 fa-solid text-middle"}
                    />
                  </Disclosure.Button>
                  <Disclosure.Panel
                      className={`flex flex-col gap-1 px-4 pt-2 pb-2 text-sm bg-gray-100 text-slate-800 rounded-b-lg
                           after:absolute after:content-[""] after:left-[0px] after:top-[-12px] after:bg-transparent after:rounded-bl-lg after:h-[50px] after:w-[15px]
                           after:shadow-[0_25px_0_0_#f3f4f6]
                           before:absolute before:content-[""] before:right-[0px] before:top-[-12px] before:bg-transparent before:rounded-br-lg before:h-[50px] before:w-[15px]
                           before:shadow-[0_25px_0_0_#f3f4f6]`}>
                    {data.map(function (enex, _) {
                      return (
                        <div className="flex flex-row justify-between w-full flex-nowrap place-items-center">
                          <div className="flex">Entrance/Exit <div className="mx-1 font-semibold">{enex.enid}</div> </div>
                          <div className="flex gap-4">
                          <Link
                            to={`/admin/dashboard/entranceexits/edit/${enex.enid}`}
                            className="font-medium text-gray-600 hover:scale-120 hover:text-black focus:ring-2 focus:ring-blue-300"
                          >
                            <i className="fas fa-pencil-alt"></i>
                          </Link>
                          <button
                            onClick={(e) => handleDeleteEnex(e, enex.enid)}
                            className="font-medium text-red-500 hover:scale-120 hover:text-red-700 focus:ring-2 focus:ring-red-300"
                          >
                            <i className="fas fa-trash-alt"></i>
                          </button>
                          </div>


                        </div>
                      );
                    })}
                  </Disclosure.Panel>
                </>
              )}
            </Disclosure>
          );
        })}
    </div>
  );
}
