import axios from "axios";
import React, { useState, useEffect, Fragment } from "react";
import ContentEditable from "react-contenteditable";
import ParkingLotMiniPass from "../acceptedpass/ParkingLotMiniPass";
import { ParkingLotAccPassAdd } from "../acceptedpass/ParkingLotAccPassAdd";
import FullnessVis from "../../userview/visualizations/FullnessVis";
import HalfHoursChart from "../../userview/visualizations/HalfHoursChart";
import {  useParams } from "react-router";
import { Link, useHistory, useLocation } from "react-router-dom";
import EnExMini from "../entranceexit/EnExMini";
import { PlusIcon } from "@heroicons/react/solid";
export default function ParkingLotEdit() {
  let { lotid } = useParams();
  const [apiError, setApiError] = useState();
  const [lotPercentage, setLotPercentage] = useState();
  const [lotDataChanged, setLotDataChanged] = useState({
    name: false,
    lotid: false,
    longitude: false,
    latitude: false,
    usedstalls: false,
  });
  const [shouldRefresh, setShouldRefresh] = useState();
  //Lot's passes consts
  const [passData, setPassData] = useState();
  const history = useHistory();
  const location = useLocation();
  //LotData consts
  const [lotData, setLotData] = useState();
  const [lotDataPatch, setLotDataPatch] = useState();
  const [halfHoursPrediction, setHalfHoursPrediction] = useState();
  const [enexesMetadata, setEnexesMetadata] = useState();
  //get lot data
  useEffect(() => {
    const lotUrl = `${process.env.REACT_APP_API_URL}/api/lotcomplete/${lotid}/`;
    const getLotConfig = {
      url: lotUrl,
      method: "GET",
      headers: {
        "Content-Type": "application/json",
      },
    };
    axios(getLotConfig)
      .then((response) => {
        setLotData(response.data.lot);
        setLotDataPatch(response.data.lot);
        setPassData(response.data.accpasses);
        setLotPercentage(response.data.percentfull);
        setEnexesMetadata(response.data.enexes);
      })
      .catch((error) => {
        setApiError(error);
        // setLotData();
        setLotDataPatch(undefined);
        console.error(error);
      });
    //get halfhours prediction:
    axios({
      url: `${process.env.REACT_APP_API_URL}/api/lot/${lotid}/prediction/halfhours/`,
      method: "GET",
      headers: {
        "Content-Type": "application/json",
      },
    })
      .then((response) => {
        setHalfHoursPrediction(response.data);
      })
      .catch((error) => {
        setHalfHoursPrediction("nodata");
        console.error(error);
        setApiError(error);
      });
  }, [shouldRefresh, lotid]);

  const handleKeyPress = (e, field) => {
    var keyCode = e.which || e.keyCode;
    // HIT ENTER
    if (keyCode === 13) {
      e.preventDefault();
    }
  };
  const trimSpaces = (string) => {
    return string
      .replace(/&nbsp;/g, "")
      .replace(/&amp;/g, "&")
      .replace(/&gt;/g, ">")
      .replace(/&lt;/g, "<");
  };
  const handleFieldOnChange = (e, field) => {
    setLotDataPatch({ ...lotDataPatch, [field]: e.target.value });
    if (e.target.value === lotData[field]) {
      setLotDataChanged({ ...lotDataChanged, [field]: false });
    } else setLotDataChanged({ ...lotDataChanged, [field]: true });
  };
  const pasteAsPlainText = (event) => {
    event.preventDefault();

    const text = event.clipboardData.getData("text/plain");
    document.execCommand("insertHTML", false, text);
  };
  const handleSubmitChanges = (e, field) => {
    if (e.preventDefault) e.preventDefault();
    const lotUrl = `${process.env.REACT_APP_API_URL}/api/lot/${lotid}/`;
    const patchConfig = {
      url: lotUrl,
      method: "PATCH",
      headers: {
        Authorization: `Bearer ${localStorage.getItem("token")}`,
        "Content-Type": "application/json",
      },
      data: { ...lotDataPatch, timecountupdated: new Date(Date.now()).toJSON() },
      withCredentials: true,
    };
    axios(patchConfig)
      .then((response) => {
        setLotDataChanged({ ...lotDataChanged, [field]: false });
        setShouldRefresh(shouldRefresh ? false : true);
      })
      .catch((error) => {
        setApiError(error);
        console.error(error);
      });
  };
  const handleRefresh = () => {
    setShouldRefresh(shouldRefresh ? false : true);
  };

  return (
    <Fragment>
      {lotDataPatch && (
        <div className="z-[1200] lot-view flex flex-col items-center overflow-y-auto p-2 pb-4 gap-4 overflow-x-clip flex-shrink-0 h-full">
          {/* Add a Goback button here */}
        <div className="flex flex-row w-full">
          <button
            disabled={!location.key}
            onClick={(e) => {
              e.preventDefault();
              if (location.key) history.goBack();
            }}
            className="flex flex-row justify-center p-2 transition-all duration-700 transform bg-white border rounded-full shadow-lg w-9 h-9 group hover:w-28 hover:justify-around hover:bg-amaranth-500 border-amaranth-300/20 text-slate-700"
          >
            <i className="flex self-center text-lg fa-solid fa-chevron-left text-amaranth-400 group-hover:text-white"></i>
            <span className="self-center hidden text-lg text-white truncate transition-all duration group-hover:flex">
              Go Back
            </span>
          </button>
        </div>
          {/* Overview card: Name, Visualization + Passes */}
          <div className="flex flex-col w-full py-2 bg-white shadow-4sides lot-overview rounded-xl text-slate-700">
            <div className="flex flex-row flex-wrap justify-start max-w-full px-5 py-2 space-x-3 break-all">
              <ContentEditable
                html={lotDataPatch.name}
                onPaste={pasteAsPlainText}
                onKeyDown={(e) => handleKeyPress(e, "name")}
                onChange={(e) => handleFieldOnChange(e, "name")}
                className="text-xl underline rounded-lg lot-name underline-offset-4 decoration-indigo-600 decoration-dotted focus:no-underline hover:no-underline hover:outline-dashed outline-offset-2 outline-sky-500 focus:outline-2 focus:outline-dotted focus:bg-slate-200"
              />
              <button
                onClick={(e) => handleSubmitChanges(e, "name")}
                className={lotDataChanged["name"] ? "flex tracking-wide truncate text-green-400 hover:text-green-600 hover:font-bold" : "hidden"}
              >
                <i className="text-xl fa-solid fa-check"></i>
              </button>
            </div>
            <div className="flex flex-row gap-2 ml-4">
              <span className="inline-block px-2 font-semibold tracking-wide uppercase rounded-full text-slate-600 bg-slate-100  transition transform duration-[700ms] ">
                {convertLatDMS(lotDataPatch.latitude)}
              </span>
              <span className="group-hover:text-white transition transform duration-700 group-hover:scale-[150%]">
                &bull;
              </span>
              <span className="inline-block px-2 font-semibold tracking-wide uppercase rounded-full text-slate-600 bg-slate-100 transition transform duration-[700ms]">
                {convertLongDMS(lotDataPatch.longitude)}
              </span>
            </div>
            {/* Vis  1/2 + pass 1/2  */}
            <div className="flex flex-row flex-1 w-full">
              <div className="grid w-full h-full grid-cols-12 lot-data">
                <div className="flex-col justify-between flex-auto col-span-6 gap-1 p-3 lot-passes">
                  {passData &&
                    passData.map(function (pass, idx) {
                      return <ParkingLotMiniPass parentRefreshHandler={handleRefresh} pass={pass} />;
                    })}
                  {/* Add passes? */}
                  <ParkingLotAccPassAdd
                    parentRefreshHandler={handleRefresh}
                    passData={passData}
                    lotid={lotData.lotid}
                  />
                </div>
                <div className="col-span-6 lot-vis">
                  {lotPercentage !== undefined && (
                    <FullnessVis percentage={lotPercentage} transitionEnded={true} showPercent={true} />
                  )}
                </div>
              </div>
            </div>
          </div>

          {/* Prediction Card */}
          <div className="flex flex-col w-full py-2 bg-white shadow-4sides lot-overview rounded-xl text-slate-700">
            <div className="flex flex-col flex-auto w-full">
              {lotPercentage !== undefined && halfHoursPrediction && (
                <HalfHoursChart halfhours={halfHoursPrediction} currentPercent={lotPercentage} transitionEnded={true} />
              )}
            </div>
          </div>
          {/* Entrance Exits/Sensor Card */}
          <div className="flex flex-col w-full px-2 py-2 bg-white shadow-4sides lot-overview rounded-xl text-slate-700">
            <div className="flex flex-row w-full ml-1 text-base font-medium tracking-wide text-slate-600">
              Entrance/Exits
            </div>
            <div className="flex flex-col w-full gap-y-1.5 px-1 mt-1">
              {enexesMetadata &&
                enexesMetadata.map(function (enexMetadata, idx) {
                  return (
                    <>
                      <EnExMini enexMetadata={enexMetadata} />
                    </>
                  );
                })}

              <div className="flex flex-row">
                <Link
                  to={{
                    pathname: `/admin/dashboard/entranceexits/newenex`,
                    state: {
                      defaultAddEnex: {
                        lotid: lotid,
                      },
                    },
                  }}
                  className="inline-flex text-sm"
                >
                  <PlusIcon className="w-5 h-5 mr-1" />
                  Add Entrance/Exit
                </Link>
              </div>
            </div>
          </div>
        </div>
      )}
    </Fragment>
  );
}
// SOME UTILS
function toDegreesMinutesAndSeconds(coordinate) {
  var absolute = Math.abs(coordinate);
  var degrees = Math.floor(absolute);
  var minutesNotTruncated = (absolute - degrees) * 60;
  var minutes = Math.floor(minutesNotTruncated);
  var seconds = Math.floor((minutesNotTruncated - minutes) * 60);

  return degrees + "°" + minutes + "'" + seconds;
}

function convertLatDMS(lat) {
  var latitude = toDegreesMinutesAndSeconds(lat);
  var latitudeCardinal = lat >= 0 ? "N" : "S";

  return latitude + " " + latitudeCardinal;
}

function convertLongDMS(lng) {
  var longitude = toDegreesMinutesAndSeconds(lng);
  var longitudeCardinal = lng >= 0 ? "E" : "W";
  return longitude + " " + longitudeCardinal;
}
