import axios from "axios";
import React, { useState, useEffect } from "react";
import { CheckCircleIcon, XIcon } from "@heroicons/react/solid";
import { useDispatch, useSelector } from "react-redux";
import { useHistory, useLocation } from "react-router-dom";
import { useParkingLotData } from "../adminmap/AdminMap";


import { LocationMarkerIcon } from "@heroicons/react/solid";
import { updateMapData } from "../../../redux/mapSlice";
// componentToLoad: "ParkingLots",
/*
  componentDisplayContent: "newlot" - display make new lot
*/
export default function ParkingLotPost() {
  const [apiError, setApiError] = useState(false);
  const [apiSuccess, setApiSuccess] = useState(false);
  const [parkingLotData, getParkingLotData] = useParkingLotData();
  const lotListUrl = `${process.env.REACT_APP_API_URL}/api/lot/`;
  const [lotInfo, setLotInfo] = useState({
    lotid: "",
    name: "",
    longitude: "",
    latitude: "",
    usedstalls: 0,
    timecountupdated: new Date(Date.now()).toJSON(),
  });
  const location = useLocation();
  const dispatch = useDispatch();
  const adminPickingOnMapState = useSelector((state) => state.map.adminPickingOnMapState);
  const adminPickingOnMapLocation = useSelector((state) => state.map.adminPickingOnMapLocation);
  let history = useHistory();
  const handleChange = (event) => {
    setLotInfo({ ...lotInfo, [event.target.name]: event.target.value });
  };
  const handlePickOnMap = (e) => {
    e.preventDefault();
    dispatch(updateMapData({ adminPickingOnMapState: "pick" }));
  };

  const directToLotEdit = (lotid) => {
    const interval = setTimeout(() => {
      history.push(`/admin/dashboard/parkinglots/edit/${lotid}`);
    }, 700);
    return () => clearTimeout(interval);
  };

  const handleSubmit = (e) => {
    e.preventDefault();
    const postConfig = {
      url: lotListUrl,
      method: "POST",
      headers: {
        Authorization: `Bearer ${localStorage.getItem("token")}`,
        "Content-Type": "application/json",
      },
      data: { ...lotInfo, timecountupdated: new Date(Date.now()).toJSON() },
      withCredentials: true,
    };

    axios(postConfig)
      .then(function (response) {
        //Delay and direct to lotlist
        directToLotEdit(lotInfo.lotid);
        // Reset Form
        setLotInfo({
          lotid: "",
          name: "",
          longitude: "",
          latitude: "",
          usedstalls: 0,
          timecountupdated: "",
        });
        getParkingLotData();
        setApiError(false);
        setApiSuccess(true);
        dispatch(updateMapData({ adminPickingOnMapLocation: undefined, adminPickingOnMapState: undefined }));
      })
      .catch((error) => {
        setApiError(true);
        setApiSuccess(false);
        console.error(error);
        dispatch(updateMapData({ adminPickingOnMapLocation: undefined, adminPickingOnMapState: undefined }));
      });
  };
  //
  // useEffect to update enexInfo after picking a location on Map
  //
  useEffect(() => {
    if (adminPickingOnMapState === "pick" && adminPickingOnMapLocation) {
      setLotInfo({
        ...lotInfo,
        ["latitude"]: adminPickingOnMapLocation.lat.toFixed(6),
        ["longitude"]: adminPickingOnMapLocation.lng.toFixed(6),
      });
    }
  }, [adminPickingOnMapState, adminPickingOnMapLocation]);
  // USE effect to reset picking on map states when first load
  // and reset the picking location state on unmount
  useEffect(() => {
    dispatch(updateMapData({ adminPickingOnMapLocation: undefined, adminPickingOnMapState: undefined }));
    return () => {
      dispatch(updateMapData({ adminPickingOnMapLocation: undefined, adminPickingOnMapState: undefined }));
    };
  }, []);
  //   Render
  return (
    <div className="flex flex-col justify-between w-full lot-post">
      <div className="max-w-sm px-1 my-2 rounded-xl">
        <button
          disabled={!location.key}
          onClick={(e) => {
            e.preventDefault();
            if (location.key) history.goBack();
            dispatch(updateMapData({ adminPickingOnMapLocation: undefined, adminPickingOnMapState: undefined }));
          }}
          className="flex flex-row justify-center p-2 transition-all duration-700 transform bg-white border rounded-full shadow-lg w-9 h-9 group hover:w-28 hover:justify-around hover:bg-amaranth-500 border-amaranth-300/20 text-slate-700"
        >
          <i className="flex self-center text-lg fa-solid fa-chevron-left text-amaranth-400 group-hover:text-white"></i>
          <span className="self-center hidden text-lg text-white truncate transition-all duration group-hover:flex">
            Go Back
          </span>
        </button>
        <form onSubmit={handleSubmit}>
          <div className="flex flex-col justify-between gap-2 ">
            <div className="flex flex-col w-full rounded-md">
              <label htmlFor="lotid" className="block mb-1 font-semibold text-gray-600 uppercase">
                LOT ID
              </label>
              <input
                type="text"
                pattern="[0-9]*"
                id="lotid"
                name="lotid"
                className="w-full px-2 py-2 text-sm transition-all duration-150 ease-linear bg-white border-0 rounded shadow placeholder-blueGray-300 text-blueGray-600 focus:outline-none focus:ring"
                onChange={handleChange}
                value={lotInfo.lotid}
                required
              />
            </div>
            <div>
              <label htmlFor="name" className="block mb-1 font-semibold text-gray-600 uppercase">
                Lot Name
              </label>
              <input
                type="text"
                id="name"
                name="name"
                className="w-full px-2 py-2 text-sm transition-all duration-150 ease-linear bg-white border-0 rounded shadow placeholder-blueGray-300 text-blueGray-600 focus:outline-none focus:ring"
                onChange={handleChange}
                value={lotInfo.name}
                required
              />
            </div>
            <div>
              <button
                onClick={(e) => handlePickOnMap(e)}
                className="flex flex-row mt-0.5 mb-1 flex-nowrap p-2 bg-slate-100 rounded-lg"
              >
                <LocationMarkerIcon className="w-5 h-5 mr-2"></LocationMarkerIcon>
                {adminPickingOnMapState === undefined && <span className="">Pick on Map</span>}
                {adminPickingOnMapState === "pick" && <span className="">Drag the marker to location</span>}
              </button>
              {adminPickingOnMapState === "pick" && (
                <button
                  onClick={(e) => {
                    dispatch(
                      updateMapData({ adminPickingOnMapLocation: undefined, adminPickingOnMapState: undefined })
                    );
                  }}
                  className="flex flex-row mt-0.5 mb-1 flex-nowrap p-2 bg-gray-200 rounded-lg"
                >
                  <XIcon className="w-5 h-5 mr-1 "></XIcon>
                  <span className="">Cancel</span>
                </button>
              )}

              <label htmlFor="latitude" className="block mb-1 font-semibold text-gray-600 uppercase">
                Latitude
              </label>
              <input
                type="text"
                id="latitude"
                name="latitude"
                className="w-full px-2 py-2 text-sm transition-all duration-150 ease-linear bg-white border-0 rounded shadow placeholder-blueGray-300 text-blueGray-600 focus:outline-none focus:ring"
                onChange={handleChange}
                value={lotInfo.latitude}
                required
              />
            </div>
            <div>
              <label htmlFor="longitude" className="block mb-1 font-semibold text-gray-600 uppercase">
                Longitude
              </label>
              <input
                type="text"
                id="longitude"
                name="longitude"
                className="w-full px-2 py-2 text-sm transition-all duration-150 ease-linear bg-white border-0 rounded shadow placeholder-blueGray-300 text-blueGray-600 focus:outline-none focus:ring"
                onChange={handleChange}
                value={lotInfo.longitude}
                required
              />
            </div>
            <div>
              <label htmlFor="usedstalls" className="block mb-1 font-semibold text-gray-600 uppercase">
                Number of Used Stalls (now)
              </label>
              <input
                type="number"
                id="usedstalls"
                min="0"
                step="1"
                name="usedstalls"
                className="w-full px-2 py-2 text-sm transition-all duration-150 ease-linear bg-white border-0 rounded shadow placeholder-blueGray-300 text-blueGray-600 focus:outline-none focus:ring"
                onChange={handleChange}
                value={lotInfo.usedstalls}
                required
              />
            </div>
            <div className="flex-row block gap-2">
              <button
                type="submit"
                className="w-full py-2 mt-4 text-lg font-semibold tracking-wider text-white rounded-md bg-gradient-to-tr from-amaranth-500 to-amaranth-400 hover:from-amaranth-500 hover:to-amaranth-300 focus:outline-none focus:ring focus:ring-pink-500"
              >
                Submit
              </button>
            </div>
          </div>
          {apiSuccess === true && (
            <div className="flex flex-wrap mt-2 text-base font-normal align-middle">
              {" "}
              <CheckCircleIcon className="w-5 h-5 mr-2 text-green-500 transition-all duration-700 delay-700 " /> New
              Parking Lot Created
            </div>
          )}
          {apiError === true && <h5>Cannot create a new parking lot</h5>}
        </form>
      </div>
    </div>
  );
}
