import axios from "axios";
import React, { useState, useEffect } from "react";
import { useDispatch, useSelector } from "react-redux";
import { updateMapData } from "../../../redux/mapSlice";
import {Link, useHistory} from "react-router-dom";
import "./ParkingLot.css";
export default function ParkingLotsList() {
  const [apiError, setApiError] = useState(false);
  const lotListUrl = `${process.env.REACT_APP_API_URL}/api/lot/`;
  const [lotList, setLotList] = useState([]);
  const lotStallsRemaining = useSelector((state) => state.map.lotStallsRemaining);
  const [lotListPrevious, setLotListPrevious] = useState([]);
  const dispatch = useDispatch();
  let history = useHistory();
  const [shouldRefresh, setShouldRefresh] = useState(true);
  //
  // UseEffect (update when lots changed) and  GET Parking LOTS function
  //
  useEffect(() => {
    const getConfig = {
      url: lotListUrl,
      method: "GET",
      headers: {
        "Content-Type": "application/json",
      },
    };
    function fetchList() {
      axios(getConfig)
        .then((response) => {
          setLotListPrevious(lotList);
          setLotList(response.data);
          dispatch(updateMapData({ adminLotList: response.data }));
        })
        .catch((error) => {
          console.error(error);
        });
    }
    fetchList();
    // FETCH new data after x seconds;
    const interval = setTimeout(() => {
      setShouldRefresh(!shouldRefresh);
    }, 4000);
    return () => clearTimeout(interval);
  }, [lotListUrl, shouldRefresh]);

  const handleDeleteLot = (event, lotid) => {
    event.preventDefault();
    const deleteConfig = {
      url: `${process.env.REACT_APP_API_URL}/api/lot/${lotid}`,
      method: "DELETE",
      headers: {
        Authorization: `Bearer ${localStorage.getItem("token")}`,
        "Content-Type": "application/json",
      },
    };
    axios(deleteConfig)
      .then((response) => {
        setShouldRefresh(!shouldRefresh);
      })
      .catch((error) => {
        console.error(error);
      });
  };


  return (
    <div className="flex flex-col items-center justify-between flex-shrink-0 h-full px-2 py-2 overflow-y-auto lot-list">
      {lotList.map(function (data, idx) {
        return (
          <Link
            to={`/admin/dashboard/parkinglots/edit/${data.lotid}`}
            key={data.lotid}
            className={`grid grid-cols-12 bg-white ring-offset-1 ring-amaranth-300 p-5 pt-3 rounded-lg drop-shadow-lg my-1 group transform transition duration-300 delay-300 hover:scale-[101%] hover:ring-2`}
          >
            <div className="col-span-11">
              <div className="inline-block w-full truncate">

              {lotStallsRemaining[data.lotid]!==undefined || lotStallsRemaining[data.lotid] !=="nodata"?
                lotStallsRemaining[data.lotid] > 50? (
                    <i className="text-sm text-green-500 align-middle -translate-y-1 fas fa-circle "></i>
                  ) : lotStallsRemaining[data.lotid] > 25 ? (
                    <i className="text-sm text-yellow-500 align-middle -translate-y-1 fas fa-circle"></i>
                  ) : (
                    <i className="text-sm text-red-500 align-middle -translate-y-1 fas fa-minus-circle"></i>
                  ): <i className="text-sm text-gray-400 align-middle -translate-y-1 fas fa-circle"></i> }
                <span className="my-2 mx-2 text-xl font-semibold leading-tight uppercase truncate transition ease-in-out transform duration-[1000ms] group-hover:text-amaranth-500">
                {data.name}
                </span >


              </div>

              <div className="flex gap-2">
                <span className="inline-block px-2 font-semibold tracking-wide uppercase rounded-full text-slate-600 bg-slate-100  transition transform duration-[700ms] ">
                  {convertLatDMS(data.latitude)}
                </span>
                <span className="group-hover:text-white transition transform duration-700 group-hover:scale-[150%]">
                  &bull;
                </span>
                <span className="inline-block px-2 font-semibold tracking-wide uppercase rounded-full text-slate-600 bg-slate-100 transition transform duration-[700ms]">
                  {convertLongDMS(data.longitude)}
                </span>
              </div>
              <div className="mt-4">
                <span
                  className={lotListPrevious[idx] && lotListPrevious[idx].usedstalls !== data.usedstalls ? "ping font-semibold text-amaranth-400 text-md  transition transform duration-[700ms] group-hover:text-amaranth-500" : "font-semibold text-amaranth-400 text-md  transition transform duration-[700ms] group-hover:text-amaranth-500"}
                >
                  {data.usedstalls} used stalls{" "}
                </span>
                <span className="text-sm text-gray-600 group-hover:text-slate-200">
                  ({data.timecountupdated ? "since " + data.timecountupdated : "no recent sensor updates"})
                </span>
              </div>
            </div>
            <div className="flex flex-col justify-center col-span-1 text-center align-middle">
              <button
                onClick={(e) => handleDeleteLot(e, data.lotid)}
                className="text-red-500  hover:scale-120 hover:text-red-700 focus:ring-2 focus:ring-red-300 font-medium rounded-full text-md px-5 py-2.5 text-center mr-2 mb-2"
              >
                <i className="fas fa-trash-alt"></i>
              </button>
              <div
                className="text-gray-600  hover:scale-120 hover:text-black focus:ring-2 focus:ring-blue-300 font-medium rounded-full text-md px-5 py-2.5 text-center mr-2 mb-2"
              >
                <i className="fas fa-pencil-alt"></i>
              </div>
            </div>
          </Link>
        );
      })}
    </div>
  );
}

// SOME UTILS
function toDegreesMinutesAndSeconds(coordinate) {
  var absolute = Math.abs(coordinate);
  var degrees = Math.floor(absolute);
  var minutesNotTruncated = (absolute - degrees) * 60;
  var minutes = Math.floor(minutesNotTruncated);
  var seconds = Math.floor((minutesNotTruncated - minutes) * 60);

  return degrees + "°" + minutes + "'" + seconds;
}

function convertLatDMS(lat) {
  var latitude = toDegreesMinutesAndSeconds(lat);
  var latitudeCardinal = lat >= 0 ? "N" : "S";

  return latitude + " " + latitudeCardinal;
}

function convertLongDMS(lng) {
  var longitude = toDegreesMinutesAndSeconds(lng);
  var longitudeCardinal = lng >= 0 ? "E" : "W";
  return longitude + " " + longitudeCardinal;
}
