import axios from "axios";
import React, { useState, useEffect } from "react";
import { useParams } from "react-router";
import { useHistory, useLocation } from "react-router-dom";
import DeleteButton from "../utils/DeleteButton";

export default function ReadUpdatePassForm(props) {
  const { passid } = useParams();
  const [apiError, setApiError] = useState(false);
  const passDetailURL = `${process.env.REACT_APP_API_URL}/api/pass/${passid}/`;
  const location = useLocation();
  const history = useHistory();
  const [passInfo, setPassInfo] = useState({
    passid: "",
    shortname: "",
    name: "",
  });
  const [shouldRefresh, setShouldRefresh] = useState(true);

  const handleChange = (event) => {
    setPassInfo({ ...passInfo, [event.target.name]: event.target.value });
  };
  const handleSubmit = (e) => {
    e.preventDefault();
    const patchConfig = {
      url: passDetailURL,
      method: "PATCH",
      headers: {
        Authorization: `Bearer ${localStorage.getItem("token")}`,
        "Content-Type": "application/json",
      },
      data: { ...passInfo },
      withCredentials: true,
    };

    axios(patchConfig)
      .then(function (response) {
        setApiError(false);
        setShouldRefresh(!shouldRefresh);
      })
      .catch((error) => {
        setApiError(true);
        console.error(error);
      });
  };
  //
  // UseEffect (update when pass changed) and  GET pass function
  //
  useEffect(() => {
    const getConfig = {
      url: passDetailURL,
      method: "GET",
      headers: {
        "Content-Type": "application/json",
      },
    };
    axios(getConfig)
      .then((response) => {
        setPassInfo({
          passid: response.data.passid,
          shortname: response.data.shortname,
          name: response.data.name,
        });
      })
      .catch((error) => {
        console.error(error);
      });
  }, [passDetailURL, shouldRefresh]);
  const handleDeletePass = () => {
    const deleteConfig = {
      url: `${process.env.REACT_APP_API_URL}/api/pass/${passid}/`,
      method: "DELETE",
      headers: {
        Authorization: `Bearer ${localStorage.getItem("token")}`,
        "Content-Type": "application/json",
      },
    };
    axios(deleteConfig)
      .then((response) => {
        if (location.key) history.goBack();
        else history.go("/admin/dashboard/passes");
      })
      .catch((error) => {
        console.error(error);
        setApiError(true);
      });
  };

  return (
    <div className="relative flex flex-col items-center sm:justify-center ">
      <div className="w-full p-2">
        {/* Add a Goback button here */}
        <div className="flex flex-row w-full">
          <button
            disabled={!location.key}
            onClick={(e) => {
              e.preventDefault();
              if (location.key) history.goBack();
            }}
            className="flex flex-row justify-center p-2 transition-all duration-700 transform bg-white border rounded-full shadow-lg w-9 h-9 group hover:w-28 hover:justify-around hover:bg-amaranth-500 border-amaranth-300/20 text-slate-700"
          >
            <i className="flex self-center text-lg fa-solid fa-chevron-left text-amaranth-400 group-hover:text-white"></i>
            <span className="self-center hidden text-lg text-white truncate transition-all duration group-hover:flex">
              Go Back
            </span>
          </button>
        </div>
        <div className="w-full max-w-sm px-10 py-8 mx-auto my-2 bg-white shadow-md rounded-xl">
          <form onSubmit={handleSubmit}>
            <div className="space-y-4 space-y">
              <h1 className="text-2xl font-semibold text-center text-gray-600">{passInfo.shortname} Pass</h1>
              <div>
                <label htmlFor="name" className="block mb-1 font-semibold text-gray-600">
                  Short Name
                </label>
                <input
                  type="text"
                  id="shortname"
                  name="shortname"
                  className="w-full px-4 py-2 rounded-md outline-none bg-indigo-50"
                  onChange={handleChange}
                  value={passInfo.shortname == null ? "" : passInfo.shortname}
                  required
                />
              </div>
              <div>
                <label htmlFor="name" className="block mb-1 font-semibold text-gray-600">
                  Full Name
                </label>
                <input
                  type="text"
                  id="name"
                  name="name"
                  className="w-full px-4 py-2 rounded-md outline-none bg-indigo-50"
                  onChange={handleChange}
                  value={passInfo.name}
                  required
                />
              </div>
              <div className="flex flex-row gap-2">
                <button
                  type="submit"
                  className="w-full py-2 mt-4 text-lg font-semibold tracking-wider text-white rounded-md basis-5/6 bg-gradient-to-tr from-amaranth-500 to-amaranth-400 hover:from-amaranth-500 hover:to-amaranth-300 focus:outline-none focus:ring focus:ring-pink-500"
                >
                  Submit
                </button>

                <DeleteButton
                deleteItemHandler={handleDeletePass}
                buttonText={``}
                trashIconClass={`w-5 h-5 mt-1 mx-auto`}
                buttonClass={`flex w-full basis-1/6 align-center py-2 mt-4 text-lg font-semibold tracking-wider bg-white text-red-600 border border-red-600 hover:bg-red-600/80 hover:text-white rounded-md place-content-center basis-1/2 focus:outline-none focus:ring focus:ring-pink-500`}>
                </DeleteButton>
							</div>
            </div>
            {apiError === true && <h5>Cannot update pass information.</h5>}
          </form>
        </div>
      </div>
    </div>
  );
}
