import axios from "axios";
import React, { useState } from "react";
import { useHistory, useLocation } from "react-router-dom";
import { useDispatch, useSelector } from "react-redux";
import { useGlobalPassData } from "../quicksearch/QuickSearchQueries";

export default function PassPost() {
  const Toggles = useSelector((state) => state.filterToggles.Toggles);
  const dispatch = useDispatch();
  const [apiError, setApiError] = useState(false);
  const {updateGlobalPassData} = useGlobalPassData();
  const [responseSuccess, setResponseSuccess] = useState(false);
  const passListUrl = `${process.env.REACT_APP_API_URL}/api/pass/`;
  const location = useLocation();
  const history = useHistory();
  const [passInfo, setPassInfo] = useState({
    shortname: "",
    name: "",
  });
  const handleChange = (event) => {
    setPassInfo({ ...passInfo, [event.target.name]: event.target.value });
    setResponseSuccess(false);
  };

  const handleSubmit = (e) => {
    const passListUrl = `${process.env.REACT_APP_API_URL}/api/pass/`;
    e.preventDefault();
    const postConfig = {
      url: passListUrl,
      method: "POST",
      headers: {
        Authorization: `Bearer ${localStorage.getItem("token")}`,
        "Content-Type": "application/json",
      },
      data: { ...passInfo },
      withCredentials: true,
    };

    axios(postConfig)
      .then(function (response) {
        // Reset Form
        setPassInfo({
          shortname: "",
          name: "",
        });
        setApiError(false);
        updateGlobalPassData();
        setResponseSuccess(true);
        // updatePasses(dispatch, Toggles);
      })
      .catch((error) => {
        setApiError(true);
        console.error(error);
      });
  };

  //   Render
  return (
    <div className="flex flex-col justify-between w-full lot-post">
      <div className="max-w-sm px-1 my-2 rounded-xl">
        {/* Add a Goback button here */}
        <div className="flex flex-row w-full">
          <button
            disabled={!location.key}
            onClick={(e) => {
              e.preventDefault();
              if (location.key) history.goBack();
            }}
            className="flex flex-row justify-center p-2 transition-all duration-700 transform bg-white border rounded-full shadow-lg w-9 h-9 group hover:w-28 hover:justify-around hover:bg-amaranth-500 border-amaranth-300/20 text-slate-700"
          >
            <i className="flex self-center text-lg fa-solid fa-chevron-left text-amaranth-400 group-hover:text-white"></i>
            <span className="self-center hidden text-lg text-white truncate transition-all duration group-hover:flex">
              Go Back
            </span>
          </button>
        </div>
        <form onSubmit={handleSubmit}>
          <div className="flex flex-col justify-between gap-2 ">
            <div className="flex flex-col w-full rounded-md">
              <div>
                <label htmlFor="shortname" className="block mb-1 font-semibold text-gray-600 uppercase">
                  Short Name
                </label>
                <input
                  type="text"
                  id="shortname"
                  name="shortname"
                  className="w-full px-2 py-2 text-sm transition-all duration-150 ease-linear bg-white border-0 rounded shadow placeholder-blueGray-300 text-blueGray-600 focus:outline-none focus:ring"
                  onChange={handleChange}
                  value={passInfo.shortname}
                  required
                />
              </div>
              <div>
                <label htmlFor="name" className="block mb-1 font-semibold text-gray-600 uppercase">
                  Full Name
                </label>
                <input
                  type="text"
                  id="name"
                  name="name"
                  className="w-full px-2 py-2 text-sm transition-all duration-150 ease-linear bg-white border-0 rounded shadow placeholder-blueGray-300 text-blueGray-600 focus:outline-none focus:ring"
                  onChange={handleChange}
                  value={passInfo.name}
                  required
                />
                <div className="flex-row block gap-2">
                  <button
                    type="submit"
                    className="w-full py-2 mt-4 text-lg font-semibold tracking-wider text-white rounded-md bg-gradient-to-tr from-amaranth-500 to-amaranth-400 hover:from-amaranth-500 hover:to-amaranth-300 focus:outline-none focus:ring focus:ring-pink-500"
                  >
                    Submit
                  </button>
                </div>
              </div>
            </div>
          </div>
          {apiError === true && <h5>Cannot create a new pass</h5>}
          {responseSuccess === true && <h5>Pass created successfully</h5>}
        </form>
      </div>
    </div>
  );
}
