import axios from "axios";
import React, { useState, useEffect } from "react";
import {Link} from "react-router-dom";
export default function PassesList() {
  const [apiError, setApiError] = useState(false);
  const passListUrl = `${process.env.REACT_APP_API_URL}/api/pass/`;
  const [passList, setPassList] = useState([]);
  const [shouldRefresh, setShouldRefresh] = useState(true);
  //
  // UseEffect (update when lots changed) and  GET Parking LOTS function
  //
  useEffect(() => {
    const getConfig = {
      url: passListUrl,
      method: "GET",
      headers: {
        "Content-Type": "application/json",
      },
    };
    axios(getConfig)
      .then((response) => {
        setPassList(response.data);
      })
      .catch((error) => {
        setApiError(true);
        console.error(error);
      });
  }, [passListUrl, shouldRefresh]);

  const handleDeletePass = (event, passid) => {
    event.preventDefault();
    const deleteConfig = {
      url: `${process.env.REACT_APP_API_URL}/api/pass/${passid}/`,
      method: "DELETE",
      headers: {
        Authorization: `Bearer ${localStorage.getItem("token")}`,
        "Content-Type": "application/json",
      },
    };
    axios(deleteConfig)
      .then((response) => {
        setShouldRefresh(!shouldRefresh);
      })
      .catch((error) => {
        console.error(error);
      });
  };


  return (
    <div className="flex flex-col items-center justify-between flex-shrink-0 h-full overflow-y-auto lot-list">
      {passList.map(function (data, idx) {
        return (
          <div key={data.passid} className="grid grid-cols-12 p-5 pt-3 my-1 transition duration-300 transform bg-white rounded-lg drop-shadow-lg hover:scale-105 hover:-translate-x-3">
            <div className="col-span-11">
              <h4 className="my-2 text-xl font-semibold leading-tight uppercase truncate">{data.shortname} Pass</h4>

              <div className="mt-4">
                <span className="font-semibold text-teal-600 text-md">Full name: {data.name}</span>
              </div>
            </div>
            <div className="flex flex-col justify-center col-span-1 text-center align-middle">
              <button
                onClick={(e) => handleDeletePass(e, data.passid)}
                className="text-red-500  hover:scale-120 hover:text-red-700 focus:ring-2 focus:ring-red-300 font-medium rounded-full text-md px-5 py-2.5 text-center mr-2 mb-2"
              >
                <i className="fas fa-trash-alt"></i>
              </button>
              <Link
                to={`/admin/dashboard/passes/edit/${data.passid}`}
                className="text-gray-600  hover:scale-120 hover:text-black focus:ring-2 focus:ring-blue-300 font-medium rounded-full text-md px-5 py-2.5 text-center mr-2 mb-2">
                <i className="fas fa-pencil-alt"></i>
              </Link>
            </div>
          </div>

        );
      })}
    </div>
  );
}