import { useSelector, dispatch } from "react-redux";
import React, { useState, useEffect } from "react";
import { useQuickSearchQueries } from "./QuickSearchQueries";
import { ReactSearchAutocomplete } from "react-search-autocomplete";
import { useHistory } from "react-router-dom";
export default function QuickSearchBar() {
  const searchQueries = useQuickSearchQueries();
  const history = useHistory();
  const [searchString, setSearchString] = useState("");
  const fuseOptions = {
    keys: [
      { name: "id", weight: 0.1 },
      { name: "itemId", weight: 0.4 },
      { name: "tags", weight: 0.3 },
      {
        name: "name",
        weight: 0.7,
      },
    ],
    minMatchCharLength: 2,
    threshold: 0.3,
  };

  const handleOnSelect = (item) => {
    history.push(item.url);
  };
  const handleOnSearch = (string, results) => {
    setSearchString(string);
  };
  const formatResult = (item) => {
    function getHighlightedText(text) {
			if (!searchString || searchString.length === 0 || !text)
				return <span>{text}</span>
      // Split on highlight term and include term into parts, ignore case
      let highlight = searchString;
      const parts = text.toString().split(new RegExp(`(${highlight})`, "gi"));
      return (
        <span>
          {" "}
          {parts.map((part, i) => (
            <span
              key={i}
              className={part.toLowerCase() === highlight.toLowerCase() ? "font-semibold text-slate-800" : ""}
            >
              {part}
            </span>
          ))}{" "}
        </span>
      );
    }
    return (
      <>
        <div className="flex flex-col justify-start w-full px-3 mt-1 truncate">
          <div className="flex flex-row italic font-normal">{getHighlightedText(item.name)}</div>
          <div className="flex flex-row gap-1 text-xs italic font-medium text-slate-400">
            <span>{getHighlightedText(item.itemType)}</span>
            <span>{getHighlightedText(item.itemId)}</span>
          </div>
        </div>
      </>
    );
  };

  return (
    <>
      <ReactSearchAutocomplete
        items={searchQueries}
        fuseOptions={fuseOptions}
        maxResults={8}
        onSearch={handleOnSearch}
        inputDebounce={150}
        onSelect={handleOnSelect}
        placeholder="Quick search"
        formatResult={formatResult}
        showIcon={true}
        styling={{
          // border: "purple",
          // borderWidth: "16px",
          boxShadow: "rgba(50, 50, 105, 0.15) 0px 2px 5px 0px, rgba(0, 0, 0, 0.05) 0px 1px 1px 0px;",
          // zIndex: 2000,
          fontSize: "16px",
          fontFamily: "Poppins",
        }}
      />
    </>
  );
}
