import { useSelector, useDispatch } from "react-redux";
import React, { useState, useEffect } from "react";
import axios from "axios";
import {updateMapData} from "../../../redux/mapSlice";
const buildSidebarNavigationQueries = () =>{
  return [
    {id:"home", name:"Dashboard", url:"/admin/dashboard/", tags:["home", "dashboard"],itemType:"Home", },
    {id:"lotlist", name:"Existing Parking Lots List", url:"/admin/dashboard/parkinglots/", tags:["lots", "list"],itemType:"Navigation"},
    {id:"newlot", name:"Add Parking Lot", url:"/admin/dashboard/parkinglots/newlot/",tags:["add lot","create lot", "post"],itemType:"Navigation"},
    {id:"sensorlist", name:"Existing Sensors List", url:"/admin/dashboard/sensors/",tags:["sensors", "list"],itemType:"Navigation"},
    {id:"newsensor", name:"Add Sensor", url:"/admin/dashboard/sensors/newsensor/",tags:["add sensor","create sensor", "post"],itemType:"Navigation"},
    {id:"enexlist", name:"Existing Entrance Exits List", url:"/admin/dashboard/entranceexits/",tags:["entrance exits","enexes", "enex", "list"],itemType:"Navigation"},
    {id:"newenex", name:"Add Sensor", url:"/admin/dashboard/entranceexits/newenex/",tags:["add enex","create entrance exit", "post"],itemType:"Navigation"},

    {id:"announcementlist", name: "Announcements List", url:"/admin/dashboard/announcements/",tags:["announcements", "list"],itemType:"Navigation"},
    {id:"systemwideannouncement", name: "Systemwide Announcement", url:"/admin/dashboard/announcements/edit/systemwide", tags:["systemwide","announcement"],itemType:"Navigation"},
    {id:"listpass", name:"Passes List", url:"/admin/dashboard/passes/",tags:["Permits", "passes", "pass", "list"],itemType:"Navigation"},
    {id:"newpass", name:"Add Pass", url:"/admin/dashboard/passes/newpass/",tags:["add pass","create pass", "post"],itemType:"Navigation"},
    {id:"statistics", name:"Statistics", url:"/admin/dashboard/statistics",tags:["graph","chart", "history"],itemType:"Navigation"},
  ]
}

const buildLotQueries = (lotData) => {
  //Queries Sample:
  // [{tag,id, name,url},... ]
  const editUrl = `/admin/dashboard/parkinglots/edit/`;
  let queries = [];
  for (let lot of lotData) {
    const query = {
      tag:["Parking Lot", "Lot"],
      id: "lot"+lot.lotid,
      name: "Parking Lot "+  lot.name,
      url: editUrl + lot.lotid,
      itemId:lot.lotid,
      itemType:"Parking Lot",
    };
    queries.push(query);
  }
  return queries;
};
const buildAnnouncementQueries = (lotData) => {
  //Queries Sample:
  // [{id, name,url},... ]
  const editUrl = `/admin/dashboard/announcements/edit/`;
  let queries = [];
  for (let lot of lotData) {
    const query = {
      tag:["Announcement"],
      id: "announcement"+lot.lotid,
      name: "Announcement "+lot.name,
      url: editUrl + lot.lotid,
      itemId:lot.lotid,
      itemType:"Announcement",
    };
    queries.push(query);
  }
  return queries;
};
const buildSensorQueries = (sensorData) => {
  //Queries Sample:
  // [{id, name,url},... ]
  const editUrl = `/admin/dashboard/sensors/edit/`;
  let queries = [];
  for (let sensor of sensorData) {
    const query = {
      tag:["Sensor"],
      id: "sensor"+sensor.sensorid,
      name: "Sensor " + sensor.sensorid,
      itemId:sensor.sensorid,
      url: editUrl + sensor.sensorid,
      itemType:"Sensor",
    };
    queries.push(query);
  }
  return queries;
};
const buildEnexQueries = (enexData) => {
  //Queries Sample:
  // [{id, name,url},... ]
  const editUrl = `/admin/dashboard/entranceexits/edit/`;
  let queries = [];
  for (let enex of enexData) {
    const query = {
      tag:["Entrance Exit", "enex"],
      id: "enex"+enex.enid,
      name: "Entrance Exit " + enex.enid,
      itemId:enex.enid,
      url: editUrl + enex.enid,
      itemType:"Entrance Exit",
    };
    queries.push(query);
  }
  return queries;
};
const buildPassQueries = (passData) => {
  //Queries Sample:
  // [{id, name,url},... ]
  const editUrl = `/admin/dashboard/passes/edit/`;
  let queries = [];
  for (let pass of passData) {
    const query = {
      tag:["Permit", "pass", `pass ${pass.shortname}`],
      id: "pass"+pass.passid,
      name:  pass.name + " Pass",
      itemId:pass.passid,
      url: editUrl + pass.passid,
      itemType:"Pass",
    };
    queries.push(query);
  }
  return queries;
};

// get  PassData Hook
//Call the returned function to have it update the passData in redux state
export const useGlobalPassData = ()=>{
  const dispatch = useDispatch();
  const [shouldUpdate, setShouldUpdate] = useState();
  useEffect(() => {
    if (shouldUpdate!==undefined)
    axios({
      url:`${process.env.REACT_APP_API_URL}/api/pass/`,
      method: "GET",
      headers: {
        "Content-Type": "application/json",
      },
    })
    .then(response =>{
      dispatch(updateMapData({passData: response.data}))
    })
    .catch(error=>{
      console.error(error);
    })
  },[shouldUpdate])
  const updateGlobalPassData = () =>{
    setShouldUpdate(shouldUpdate? false: true);
  }
  return {updateGlobalPassData};
}

/**
 * React Hook that computes all admin available actions
 * This gets fed to Fuse.js fuzzysearch engine
 * to allows admin to search around without clicking
 */
export const useQuickSearchQueries = () => {
  const parkingLotData = useSelector((state) => state.map.lotData);
  const sensorData = useSelector((state) => state.map.sensorData);
  const enexData = useSelector((state) => state.map.globalEnexData);
  const passData = useSelector((state) => state.map.passData);
  const {updateGlobalPassData} = useGlobalPassData();

  useEffect(()=>{
    if (!passData){
      updateGlobalPassData();
    }
  },[]);
  const lotQueries = React.useMemo(()=>{
    if (!parkingLotData) return [];
    return buildLotQueries(parkingLotData);
  },[parkingLotData])
  const sensorQueries = React.useMemo(()=>{
    if (!sensorData) return [];
    return buildSensorQueries(sensorData)
  },[sensorData])
  const enexQueries = React.useMemo(()=>{
    if (!enexData) return [];
    return buildEnexQueries(enexData);
  },[enexData])
  const announcementQueries = React.useMemo(()=>{
    if (!parkingLotData) return [];
    return buildAnnouncementQueries(parkingLotData)
  },[parkingLotData])
  const passQueries = React.useMemo(()=>{
    if (!passData) return [];
    return buildPassQueries(passData);
  },[passData])

  return React.useMemo(() => {
    let allSearchQueries = [];
    allSearchQueries = allSearchQueries.concat(buildSidebarNavigationQueries());
    allSearchQueries = allSearchQueries.concat(announcementQueries);
    allSearchQueries = allSearchQueries.concat(sensorQueries);
    allSearchQueries = allSearchQueries.concat(passQueries);
    allSearchQueries = allSearchQueries.concat(enexQueries);
    allSearchQueries = allSearchQueries.concat(lotQueries);
    return allSearchQueries;
  }, [parkingLotData, sensorData, enexData, passData]);
};
