import axios from "axios";
import React, { useState, useEffect } from "react";

export default function ParkingLotSensorList(props) {
  const sensorListUrl = `${process.env.REACT_APP_API_URL}/api/lot/${props.lotid}/sensors/`;
  const [sensorList, setsensorList] = useState([]);

  useEffect(() => {
    const getConfig = {
      url: sensorListUrl,
      method: "GET",
      headers: {
        "Content-Type": "application/json",
      },
    };
    axios(getConfig)
      .then((response) => {
        setsensorList(response.data);
      })
      .catch((error) => {
        console.error(error);
      });
  }, [sensorListUrl]);

  return (
    <div className="relative flex flex-col items-center min-h-screen sm:justify-center bg-indigo-500/75 ">
      <div className="grid w-full grid-cols-1 md:grid-cols-2 md:gap-4">
        <div className="p-8 pt-0 border-b sm:border-b-0 sm:border-l-2 ">
          <h4 className="mx-auto my-2 mt-1 text-xl font-semibold leading-tight text-center text-gray-200 uppercase truncate">Sensors</h4>
          <div className="bg-blue-300/50 my-2 px-10 py-2 rounded-xl mx-auto w-screen shadow-md max-w-full md:max-w-[80%] max-h-[32rem] overflow-y-hidden hover:overflow-y-auto lots-list">
            {sensorList.map(function (data, idx) {
              return (
                <div key={data.enid} className="grid grid-cols-12 p-5 pt-3 my-1 transition duration-300 transform bg-white rounded-lg drop-shadow-lg hover:scale-105 hover:-translate-x-3">
                  <div className="col-span-11">
                  <h4 className="my-2 text-xl font-semibold leading-tight uppercase truncate">{data.enid===null ? "Unassigned Sensor":"Sensor at Entrance " + data.enid}</h4>

                  <div className="mt-4">
                    <span className="font-semibold text-teal-600 text-md">Entrance side: {data.isentranceside}</span>
                    <span className="text-sm text-gray-600">(since {data.timelastupdate})</span>
                  </div>
                  </div>
                </div>
              );
            })}
          </div>
        </div>
      </div>
    </div>
  );
}
