import axios from "axios";
import React, { useState, useEffect } from "react";
import { useParams } from "react-router";
import { useHistory, useLocation } from "react-router-dom";
import DeleteButton from "../utils/DeleteButton";

export default function ReadUpdateSensorForm(props) {
  const { sensorid } = useParams();
  const [apiError, setApiError] = useState(false);
  const sensorDetailURL = `${process.env.REACT_APP_API_URL}/api/sensor/${sensorid}/`;
  const location = useLocation();
  const history = useHistory();
  const [sensorInfo, setSensorInfo] = useState({
    sensorid: "",
    enid: "",
    timelastupdate: "",
    isentranceside: "",
    imageurl: "",
    imagetime: "",
  });
  const [shouldRefresh, setShouldRefresh] = useState(true);

  const handleChange = (event) => {
    setSensorInfo({ ...sensorInfo, [event.target.name]: event.target.value });
  };
  const handleSubmit = (e) => {
    e.preventDefault();
    const patchConfig = {
      url: sensorDetailURL,
      method: "PATCH",
      headers: {
        Authorization: `Bearer ${localStorage.getItem("token")}`,
        "Content-Type": "application/json",
      },
      data: { ...sensorInfo },
      withCredentials: true,
    };

    axios(patchConfig)
      .then(function (response) {
        setApiError(false);
        setShouldRefresh(!shouldRefresh);
      })
      .catch((error) => {
        setApiError(true);
        console.error(error);
      });
  };
  //
  // UseEffect
  //
  useEffect(() => {
    const getConfig = {
      url: sensorDetailURL,
      method: "GET",
      headers: {
        "Content-Type": "application/json",
      },
    };
    axios(getConfig)
      .then((response) => {
        setSensorInfo({
          sensorid: response.data.sensorid,
          enid: response.data.enid,
          timelastupdate: response.data.timelastupdate,
          isentranceside: response.data.isentranceside,
          imageurl: response.data.imageurl,
          imagetime: response.data.imagetime,
        });
      })
      .catch((error) => {
        console.error(error);
      });
  }, [sensorDetailURL, shouldRefresh]);

  const handleDeleteSensor=()=>{
    const deleteConfig = {
      url: `${process.env.REACT_APP_API_URL}/api/sensor/${sensorid}/`,
      method: "DELETE",
      headers: {
        Authorization: `Bearer ${localStorage.getItem("token")}`,
        "Content-Type": "application/json",
      },
    };
    axios(deleteConfig)
      .then((response) => {
        if (location.key) history.goBack();
        else history.go("/admin/dashboard/sensors");
      })
      .catch((error) => {
        console.error(error);
        setApiError(true);
      });
  }

  return (
    <div className="relative flex flex-col items-center sm:justify-center ">
      <div className="w-full p-2">
        {/* Add a Goback button here */}
        <div className="flex flex-row w-full">
          <button
            disabled={!location.key}
            onClick={(e) => {
              e.preventDefault();
              if (location.key) history.goBack();
            }}
            className="flex flex-row justify-center p-2 transition-all duration-700 transform bg-white border rounded-full shadow-lg w-9 h-9 group hover:w-28 hover:justify-around hover:bg-amaranth-500 border-amaranth-300/20 text-slate-700"
          >
            <i className="flex self-center text-lg fa-solid fa-chevron-left text-amaranth-400 group-hover:text-white"></i>
            <span className="self-center hidden text-lg text-white truncate transition-all duration group-hover:flex">
              Go Back
            </span>
          </button>
        </div>
        <div className="w-full max-w-sm px-10 py-8 mx-auto my-2 bg-white shadow-md rounded-xl">
          <form onSubmit={handleSubmit}>
            <div className="space-y-4 space-y">
              <h1 className="text-2xl font-semibold text-center text-gray-600">Sensor {sensorInfo.sensorid}</h1>
              <div>
                <label htmlFor="enid" className="block mb-1 font-semibold text-gray-600">
                  Entrance ID
                </label>
                <input
                  type="number"
                  pattern="[0-9]*"
                  id="enid"
                  name="enid"
                  className="w-full px-4 py-2 rounded-md outline-none bg-indigo-50"
                  onChange={handleChange}
                  value={sensorInfo.enid == null ? "" : sensorInfo.enid}
                  required
                />
              </div>
              <div>
                <label htmlFor="isentranceside" className="block mb-1 font-semibold text-gray-600">
                  Is Entrance Side
                </label>
                <input
                  type="number"
                  id="isentranceside"
                  name="isentranceside"
                  className="w-full px-4 py-2 rounded-md outline-none bg-indigo-50"
                  onChange={handleChange}
                  value={sensorInfo.isentranceside}
                  required
                />
              </div>
              Time of last fullness report: {sensorInfo.timelastupdate == null ? "unknown" : sensorInfo.timelastupdate}
              <img src={sensorInfo.imageurl == null ? "" : sensorInfo.imageurl}></img>
              {sensorInfo.imagetime ? "Latest image taken at " + sensorInfo.imagetime : "No latest image found"}
              <div className="flex flex-row gap-2">
                <button
                  type="submit"
                  className="w-full py-2 mt-4 text-lg font-semibold tracking-wider text-white rounded-md basis-5/6 bg-gradient-to-tr from-amaranth-500 to-amaranth-400 hover:from-amaranth-500 hover:to-amaranth-300 focus:outline-none focus:ring focus:ring-pink-500"
                >
                  Submit
                </button>

                <DeleteButton
                deleteItemHandler={handleDeleteSensor}
                buttonText={``}
                trashIconClass={`w-5 h-5 mt-1 mx-auto`}
                buttonClass={`flex w-full basis-1/6 align-center py-2 mt-4 text-lg font-semibold tracking-wider bg-white text-red-600 border border-red-600 hover:bg-red-600/80 hover:text-white rounded-md place-content-center basis-1/2 focus:outline-none focus:ring focus:ring-pink-500`}>
                </DeleteButton>
							</div>
            </div>
            {apiError === true && <h5>Cannot update sensor information.</h5>}
          </form>
        </div>
      </div>
    </div>
  );
}
