import axios from "axios";
import React, { useState } from "react";
import { useHistory, useLocation } from "react-router-dom";

import { useGetSensorData } from "../adminmap/AdminMap";

export default function SensorPost() {
  const [apiError, setApiError] = useState(false);
  const [responseSuccess, setResponseSuccess] = useState(false);
  const getSensorData = useGetSensorData();
  const sensorListUrl = `${process.env.REACT_APP_API_URL}/api/sensor/`;
  const location = useLocation();
  const history = useHistory();
  const [sensorInfo, setSensorInfo] = useState(() => {
    if (location.state && location.state.defaultAddSensor)
      return {
        enid: location.state.defaultAddSensor.enid ? location.state.defaultAddSensor.enid : "",
        isentranceside: location.state.defaultAddSensor.isentranceside
          ? location.state.defaultAddSensor.isentranceside
          : "",
      };
    return {
      enid: "",
      isentranceside: "",
    };
  });
  const handleChange = (event) => {
    setSensorInfo({ ...sensorInfo, [event.target.name]: event.target.value });
    setResponseSuccess(false);
  };
  const handleSubmit = (e) => {
    e.preventDefault();
    const postConfig = {
      url: sensorListUrl,
      method: "POST",
      headers: {
        Authorization: `Bearer ${localStorage.getItem("token")}`,
        "Content-Type": "application/json",
      },
      data: { ...sensorInfo },
      withCredentials: true,
    };

    axios(postConfig)
      .then(function (response) {
        // Reset Form
        setSensorInfo({
          enid: "",
          isentranceside: "",
        });
        setApiError(false);
        getSensorData();
        setResponseSuccess(true)
      })
      .catch((error) => {
        setApiError(true);
        console.error(error);
      });
  };
  const handleGoBack = (e) => {
    e.preventDefault();
    if (location.key) history.goBack();
  };

  //   Render
  return (
    <>
      {sensorInfo && (
        <div className="flex flex-col justify-between w-full lot-post">
          <div className="max-w-sm px-1 my-2 rounded-xl">
            {/* Add a Goback button here */}
            <div className="flex flex-row w-full">
              <button
                disabled={!location.key}
                onClick={(e) => handleGoBack(e)}
                className="flex flex-row justify-center p-2 transition-all duration-700 transform bg-white border rounded-full shadow-lg w-9 h-9 group hover:w-28 hover:justify-around hover:bg-amaranth-500 border-amaranth-300/20 text-slate-700"
              >
                <i className="flex self-center text-lg fa-solid fa-chevron-left text-amaranth-400 group-hover:text-white"></i>
                <span className="self-center hidden text-lg text-white truncate transition-all duration group-hover:flex">
                  Go Back
                </span>
              </button>
            </div>
            <form onSubmit={handleSubmit}>
              <div className="flex flex-col justify-between gap-2 ">
                <div className="flex flex-col w-full rounded-md">
                  <div>
                    <label htmlFor="enid" className="block mb-1 font-semibold text-gray-600 uppercase">
                      Entrance
                    </label>
                    <input
                      type="text"
                      id="enid"
                      name="enid"
                      className="w-full px-2 py-2 text-sm transition-all duration-150 ease-linear bg-white border-0 rounded shadow placeholder-blueGray-300 text-blueGray-600 focus:outline-none focus:ring"
                      onChange={handleChange}
                      value={sensorInfo.enid}
                      required
                    />
                  </div>
                  <div>
                    <label htmlFor="isentranceside" className="block mb-1 font-semibold text-gray-600 uppercase">
                      Is Entrance Side
                    </label>
                    <input
                      type="text"
                      id="isentranceside"
                      name="isentranceside"
                      className="w-full px-2 py-2 text-sm transition-all duration-150 ease-linear bg-white border-0 rounded shadow placeholder-blueGray-300 text-blueGray-600 focus:outline-none focus:ring"
                      onChange={handleChange}
                      value={sensorInfo.isentranceside}
                      required
                    />
                    <div className="flex-row block gap-2">
                      <button
                        type="submit"
                        className="w-full py-2 mt-4 text-lg font-semibold tracking-wider text-white rounded-md bg-gradient-to-tr from-amaranth-500 to-amaranth-400 hover:from-amaranth-500 hover:to-amaranth-300 focus:outline-none focus:ring focus:ring-pink-500"
                      >
                        Submit
                      </button>
                    </div>
                  </div>
                </div>
              </div>
              {apiError === true && <h5>Cannot create a new sensor</h5>}
              {responseSuccess === true && <h5>Sensor created successfully</h5>}
            </form>
          </div>
        </div>
      )}
    </>
  );
}
