import axios from "axios";
import React, { useState, useEffect } from "react";
import { useDispatch, useSelector } from "react-redux";
import { showActionBar } from "../../../redux/actionBarSlice";
import {Link} from "react-router-dom";
import { useGetSensorData } from "../adminmap/AdminMap";

export default function SensorsList() {
  const [apiError, setApiError] = useState(false);
  const sensorListUrl = `${process.env.REACT_APP_API_URL}/api/sensor/`;
  const getSensorData = useGetSensorData();
  const [sensorList, setSensorList] = useState([]);
  const [shouldRefresh, setShouldRefresh] = useState(true);

  useEffect(() => {
    const getConfig = {
      url: sensorListUrl,
      method: "GET",
      headers: {
        "Content-Type": "application/json",
      },
    };
    axios(getConfig)
      .then((response) => {
        setSensorList(response.data);
        getSensorData();
      })
      .catch((error) => {
        setApiError(true);
        console.error(error);
      });
  }, [sensorListUrl, shouldRefresh]);

  const handleDeleteSensor = (event, sensorid) => {
    event.preventDefault();
    const deleteConfig = {
      url: `${process.env.REACT_APP_API_URL}/api/sensor/${sensorid}/`,
      method: "DELETE",
      headers: {
        Authorization: `Bearer ${localStorage.getItem("token")}`,
        "Content-Type": "application/json",
      },
    };
    axios(deleteConfig)
      .then((response) => {
        setShouldRefresh(!shouldRefresh);
      })
      .catch((error) => {
        console.error(error);
      });
  };



  return (
    <div className="flex flex-col items-center justify-between flex-shrink-0 h-full overflow-y-auto lot-list">
      {sensorList.map(function (data, idx) {
        return (
          <div key={data.enid} className="grid grid-cols-12 p-5 pt-3 my-1 transition duration-300 transform bg-white rounded-lg drop-shadow-lg hover:scale-105 hover:-translate-x-3">
            <div className="col-span-11">
              <h4 className="my-2 text-xl font-semibold leading-tight uppercase truncate">{data.enid === null ? "Unassigned Sensor" : "Sensor at Entrance " + data.enid}</h4>

              <div className="mt-4">
                <span className="font-semibold text-teal-600 text-md">Entrance side: {data.isentranceside}</span>
                <span className="spacer"></span>
                <span className="text-sm text-gray-600">(since {data.timelastupdate === null ? "unknown time" : data.timelastupdate})</span>
              </div>
            </div>
            <div className="flex flex-col justify-center col-span-1 text-center align-middle">
              <button
                onClick={(e) => handleDeleteSensor(e, data.sensorid)}
                className="text-red-500  hover:scale-120 hover:text-red-700 focus:ring-2 focus:ring-red-300 font-medium rounded-full text-md px-5 py-2.5 text-center mr-2 mb-2"
              >
                <i className="fas fa-trash-alt"></i>
              </button>
              <Link
                to={`/admin/dashboard/sensors/edit/${data.sensorid}`}
                className="text-gray-600  hover:scale-120 hover:text-black focus:ring-2 focus:ring-blue-300 font-medium rounded-full text-md px-5 py-2.5 text-center mr-2 mb-2">
                <i className="fas fa-pencil-alt"></i>
              </Link>
            </div>
          </div>

        );
      })}
    </div>
  );
}