import React, { Fragment } from "react";
import { useDispatch, useSelector } from "react-redux";
import { showActionBar, hideActionBar } from "../../../redux/actionBarSlice";
import { Redirect, NavLink } from "react-router-dom";
import { Tab } from "@headlessui/react";
import { useRouteMatch } from "react-router-dom";
function SideBar() {
  let { path, url } = useRouteMatch();
  const isShowing = useSelector((state) => state.actionBar.showing);
  const dispatch = useDispatch();
  const handleActionBarToggle = (e, componentToLoad) => {
    e.preventDefault();
    let componentDisplayContent = "";
    // dispatch(showActionBar({ componentToLoad, componentDisplayContent }));
    return <Redirect to={`/${componentToLoad}`}></Redirect>;
  };

  const tabIndexMap = {
    "/admin/dashboard/": 0,
    "/admin/dashboard/sensors": 0,
    "/admin/dashboard/parkinglots": 0,
    "/admin/dashboard/": 0,
  };

  return (
    <Fragment>
      <div className={`side-bar flex flex-col z-[1200] border w-64 static h-full`}>
        <div className="flex flex-col flex-shrink-0 h-full overflow-y-auto bg-white text-slate-800">
          <div className="">
            {/* List starts here*/}
            <ul className="flex flex-col py-1 pl-1 space-y-1">
              {/* GROUP CAPTION */}
              <li className="px-3">
                <div className="flex flex-row items-center justify-between h-8">
                  <div className="text-xs font-bold tracking-wide uppercase text-slate-500">System</div>
                  {/* <i className="mx-2 text-sm fa-solid fa-chevron-down"></i> */}
                </div>
              </li>
              {/* Group Item*/}

              <NavLink
                exact
                to="/admin/dashboard/"
                onClick={() => dispatch(hideActionBar())}
                className={`relative flex flex-row items-center h-11 focus:outline-none hover:bg-gray-50 text-gray-600 hover:text-gray-800 border-l-4 border-transparent hover:border-amaranth-500 pr-6`}
                activeClassName={`font-semibold border-amaranth-500 text-gray-800`}
              >
                <span className="inline-flex items-center justify-center ml-4">
                  <i className="fa-solid fa-house"></i>
                </span>
                <span className="ml-2 text-sm tracking-wide truncate">Dashboard</span>
              </NavLink>

              <NavLink
                to={`/admin/dashboard/sensors`}
                className={`relative flex flex-row items-center h-11 focus:outline-none hover:bg-gray-50 text-gray-600 hover:text-gray-800 border-l-4 border-transparent hover:border-amaranth-500 pr-6`}
                activeClassName={`font-semibold border-amaranth-500 text-gray-800`}
              >
                <span className="inline-flex items-center justify-center ml-4">
                  <i className="fa-solid fa-microchip"></i>
                </span>
                <span className="ml-2 text-sm tracking-wide truncate">Sensors</span>
              </NavLink>

              <NavLink
                to="/admin/dashboard/parkinglots"
                className={`relative flex flex-row items-center h-11 focus:outline-none hover:bg-gray-50 text-gray-600 hover:text-gray-800 border-l-4 border-transparent hover:border-amaranth-500 pr-6`}
                activeClassName={`font-semibold border-amaranth-500 text-gray-800`}
              >
                <span className="inline-flex items-center justify-center ml-4">
                  <i className="fa-solid fa-square-parking"></i>
                </span>
                <span className="ml-2 text-sm tracking-wide truncate">Parking Areas</span>
              </NavLink>

              <NavLink
                to="/admin/dashboard/passes"
                // onClick={(e) => handleActionBarToggle(e, "Passes", "")}
                className={`relative flex flex-row items-center h-11 focus:outline-none hover:bg-gray-50 text-gray-600 hover:text-gray-800 border-l-4 border-transparent hover:border-amaranth-500 pr-6`}
                activeClassName={`font-semibold border-amaranth-500 text-gray-800`}
              >
                <span className="inline-flex items-center justify-center ml-4">
                  <i className="fa-solid fa-ticket"></i>
                </span>
                <span className="ml-2 text-sm tracking-wide truncate">Passes</span>
              </NavLink>

              <NavLink
                to="/admin/dashboard/entranceexits"
                // onClick={(e) => handleActionBarToggle(e, "EntranceExits", "")}
                className={`relative flex flex-row items-center h-11 focus:outline-none hover:bg-gray-50 text-gray-600 hover:text-gray-800 border-l-4 border-transparent hover:border-amaranth-500 pr-6`}
                activeClassName={`font-semibold border-amaranth-500 text-gray-800`}
              >
                <span className="inline-flex items-center justify-center ml-4">
                  <i className="fa-solid fa-car-side"></i>
                </span>
                <span className="ml-2 text-sm tracking-wide truncate">Entrances and Exits</span>
              </NavLink>

              <li className="px-3">
                <div className="flex flex-row items-center justify-between h-8">
                  <div className="text-xs font-bold tracking-wider uppercase text-slate-500">Utilities</div>
                  {/* <i className="mx-2 text-sm fa-solid fa-chevron-down"></i> */}
                </div>
              </li>

                <NavLink
                  to="/admin/dashboard/announcements"
                  className={`relative flex flex-row items-center h-11 focus:outline-none hover:bg-gray-50 text-gray-600 hover:text-gray-800 border-l-4 border-transparent hover:border-amaranth-500 pr-6`}
                  activeClassName={`font-semibold border-amaranth-500 text-gray-800`}
                >
                  <span className="inline-flex items-center justify-center ml-4">
                    <i className="fa-solid fa-bullhorn"></i>
                  </span>
                  <span className="ml-2 text-sm tracking-wide truncate">Announcements</span>
                </NavLink>

              <NavLink
                to="/admin/dashboard/statistics"
                className={`relative flex flex-row items-center h-11 focus:outline-none hover:bg-gray-50 text-gray-600 hover:text-gray-800 border-l-4 border-transparent hover:border-amaranth-500 pr-6`}
                activeClassName={`font-semibold border-amaranth-500 text-gray-800`}
              >
                <span className="inline-flex items-center justify-center ml-4">
                  <i className="fa-solid fa-chart-line"></i>
                </span>
                <span className="ml-2 text-sm tracking-wide truncate">Statistics</span>
              </NavLink>

              {/* <li>
                <button className="relative flex flex-row items-center pr-6 text-gray-600 border-l-4 border-transparent h-11 focus:outline-none hover:bg-gray-50 hover:text-gray-800 hover:border-amaranth-500">
                  <span className="inline-flex items-center justify-center ml-4">
                    <i className="fa-solid fa-network-wired"></i>
                  </span>
                  <span className="ml-2 text-sm tracking-wide truncate">Network</span>
                </button>
              </li> */}

              {/* <li>
                <button className="relative flex flex-row items-center pr-6 text-gray-600 border-l-4 border-transparent h-11 focus:outline-none hover:bg-gray-50 hover:text-gray-800 hover:border-amaranth-500">
                  <span className="inline-flex items-center justify-center ml-4">
                    <i className="fa-solid fa-database"></i>
                  </span>
                  <span className="ml-2 text-sm tracking-wide truncate">Database</span>
                </button>
              </li> */}
              {/* MAP GROUP */}
              {/* <li className="px-5">
                <div className="flex flex-row items-center justify-between h-8">
                  <div className="text-sm font-bold tracking-wide uppercase text-slate-500">Parking Map</div>
                  <i className="mx-2 text-sm fa-solid fa-chevron-down"></i>
                </div>
              </li>
              <li>
                <button
                  onClick={e => handleActionBarToggle(e, "EntranceExits", "")}
                  className="relative flex flex-row items-center pr-6 text-gray-600 border-l-4 border-transparent h-11 focus:outline-none hover:bg-gray-50 hover:text-gray-800 hover:border-amaranth-500">
                  <span className="inline-flex items-center justify-center ml-4">
                    <i className="fa-solid fa-neuter"></i>
                  </span>
                  <span className="ml-2 text-sm tracking-wide truncate">Entrances and Exits</span>
                </button>
              </li>
              <li>
                <button
                onClick={e => handleActionBarToggle(e, "Statistics", "")}
                className="relative flex flex-row items-center pr-6 text-gray-600 border-l-4 border-transparent h-11 focus:outline-none hover:bg-gray-50 hover:text-gray-800 hover:border-amaranth-500">
                  <span className="inline-flex items-center justify-center ml-4">
                    <i className="fa-solid fa-chart-line"></i>
                  </span>
                  <span className="ml-2 text-sm tracking-wide truncate">Statistics</span>
                </button>
              </li> */}
            </ul>
          </div>
          {/* LOGOUT BTN */}
          <NavLink
            to="/admin/logout"
            className="relative flex flex-row items-center pr-6 text-gray-600 border-l-4 border-transparent h-11 focus:outline-none hover:bg-gray-50 hover:text-gray-800 hover:border-amaranth-500"
          >
            <span className="inline-flex items-center justify-center ml-2">
              <i className="fa-solid fa-right-from-bracket"></i>
            </span>

            <span className="ml-2 text-sm tracking-wide truncate">Logout</span>
          </NavLink>
        </div>
      </div>
    </Fragment>
  );
}
export default SideBar;
