import MultiDayPercentChart from './MultiDayPercentChart';
import React, { Fragment, useEffect, useState } from "react";
import MultiSelect from './MultiSelect';
import DateSelect from './DateSelect';
import Card from './Card';
import axios from "axios";
import {Tab} from '@headlessui/react'

function MetricSelect(props){
    return  <Tab.Group onChange={props.onChange}>
    <Tab.List className='inline'>
    <Tab
          className={({ selected }) =>
            selected ? 'ml-2 pl-2 pr-2 border-2 rounded-lg text-black' : 'ml-2 pl-2 pr-2 border rounded-lg text-slate-300'
          }
        >
          Avg</Tab>
          <Tab
          className={({ selected }) =>
          selected ? 'disabled ml-2 pl-2 pr-2 border-2 rounded-lg text-black' : 'disabled ml-2 pl-2 pr-2 border rounded-lg text-slate-300'
          }
        >Max</Tab>
    </Tab.List>
  </Tab.Group>
}

const metrics = {AVG:0,
                 MAX:1};

export default function MultiDayPercent(props){

    const [graphData, setGraphData] = useState([]);
    var [metric, setMetric] = useState('avg');
    const today = new Date();
    const year = today.getFullYear();
    const month = String(today.getMonth() + 1).padStart(2,'0');
    const day = String(today.getDate()).padStart(2,'0');
    var [startDate, setStartDate] = useState(`${year}-${month}-${day}`);
    var [endDate, setEndDate] = useState(`${year}-${month}-${day}`);
    
    const [fullLotList, setFullLotList] = useState([]);
    const [selectedLots, setSelectedLots] = useState([]);
  
    const lotListUrl = `${process.env.REACT_APP_API_URL}/api/lot/`;
    useEffect(() => {
        axios.get(lotListUrl)
            .then(response => {
                var lots = response["data"].map((lot)=>{return lot.lotid});
                setSelectedLots([lots[0]]);
                setFullLotList(lots);}
            )
            .catch((error) => {console.error(error)});
        }, []);

    function handleSelectLot(lot){
        const lot_idx = selectedLots.indexOf(lot);
        if (lot_idx === -1){
            setSelectedLots(selectedLots.concat([lot]));
        } else {
            var newLots = selectedLots.slice();
            newLots.splice(lot_idx,1);
            setSelectedLots(newLots);
        }
        
    }

    function handleMetricChange(idx){
        if (idx === metrics.AVG){
            setMetric('avg')
        }
        if (idx === metrics.MAX){
            setMetric('max')
        }
    }

    function handleStartDateChange(){
        const date = document.getElementById(`dateInputstart${props.idx}`).value;
        setStartDate(date);
    }

    function handleEndDateChange(){
        const date = document.getElementById(`dateInputend${props.idx}`).value;
        setEndDate(date);
    }

    const dataUrl = `${process.env.REACT_APP_API_URL}/api/statistics/percent/avg/${selectedLots.join(' ')}/${startDate}/${endDate}`;
    useEffect(()=>{axios.get(dataUrl)
                        .then((response)=>{setGraphData(response["data"])})
                        .catch((error)=> {console.error(error)});},
            [selectedLots, startDate, endDate, metric])

    // const graphData = [{day: 1,
    //               lot1: 0.7,
    //               lot2: 0.6},
    //               {day: 2,
    //               lot1: 0.6,
    //               lot2: 0.65},
    //               {day: 3,
    //               lot1: 0.85,
    //               lot2: 0.81},
    //               {day: 4,
    //               lot1: 0.74,
    //               lot2: 0.84},
    //               {day: 5,
    //               lot1: 0.2,
    //               lot2: 0.3},
    //               {day: 6,
    //               lot1: 0.15,
    //               lot2: 0.25}]

    return <Card>
                <div class="m-0 p-0 flex-none border-r border-gray-400 bg-white">
                    <MultiDayPercentChart data={graphData} lots={selectedLots}/>
                </div>
                <div class="p-4 flex flex-col w-full">
                    <span class="flex justify-between">
                        Multi Day Percentage 
                        <button onClick={()=>props.onClose(props.idx)}>
                            <i class="rounded-lg border-2 p-1 fa-solid fa-xmark" />
                        </button>
                    </span>
                    <span class="inline font-normal">
                        Metric: 
                        <MetricSelect onChange={handleMetricChange}/>
                    </span>
                    <DateSelect idx={`start${props.idx}`} value={startDate} message="Start:" onChange={handleStartDateChange}/>
                    <DateSelect idx={`end${props.idx}`} value={endDate} message="End:"  onChange={handleEndDateChange}/>
                    <MultiSelect options={fullLotList} selected={selectedLots} message="Select Lots" onChange={handleSelectLot}/>
                </div>
            </Card>
}