import {ResponsiveContainer, Dot, Rectangle, BarChart, Bar, CartesianGrid, XAxis, YAxis, Tooltip, Legend} from 'recharts';
import React from 'react';


function formatPercent(ratio){
    return `${Math.round(ratio * 100)}%`;
}

function formatDate(timestamp){
    const date = new Date(timestamp * 1000);
    const month = date.getMonth() + 1;
    const day = date.getDate();
    return `${month}/${day}`;
}

function formatLabel(timestamp){
    return formatDate(timestamp);
}

function generateBar(lotName, idx){
    const colors = ["#8884d8", "#82ca9d", "#ca829d", "#ca9d82"];
    return <Bar shape={<Rectangle width='1'/>} barSize='1' dataKey={lotName} fill={colors[idx % 4]} ></Bar>;
}

export default function MultiDayPercentChart(props){

    var lotList = [];
    if (props.lots.length > 0){
        lotList = props.lots.map((num)=>`lot${num}`);
    }

    return <ResponsiveContainer height={350} width={500}>
            <BarChart width={500} 
                     height={350} 
                     maxBarSize={40}
                     data={props.data}
                     barCategoryGap='10%'
                     barGap={0}
                     margin={{
                        top: 20,
                        right: 30,
                        left: 10,
                        bottom: 10,
                    }}>
                <CartesianGrid strokeDasharray="3 3" />
                <XAxis dataKey="day"
                        domain={['auto', 'auto']}
                        name="Day" 
                        type="number"
                        
                        scale="auto"
                        tickFormatter={formatDate}/>
                <YAxis tickFormatter = {formatPercent}/>
                <Tooltip labelFormatter={formatLabel}/>
                <Legend />
                {lotList.map(generateBar)}
          </BarChart></ResponsiveContainer>
}
