import OneDayPercentGraph from './OneDayPercentGraph';
import React, { useEffect, useState } from "react";
import MultiSelect from './MultiSelect';
import Card from './Card';
import axios from "axios";
import DateSelect from './DateSelect';

export default function OneDayPercent(props){

    const [graphData, setGraphData] = useState([]);
    const today = new Date();
    const year = today.getFullYear();
    const month = String(today.getMonth() + 1).padStart(2,'0');
    const day = String(today.getDate()).padStart(2,'0');
    var [date, setDate] = useState(`${year}-${month}-${day}`);
    
    const [fullLotList, setFullLotList] = useState([]);
    const [selectedLots, setSelectedLots] = useState([]);
  
    const lotListUrl = `${process.env.REACT_APP_API_URL}/api/lot/`;
    useEffect(() => {
        axios.get(lotListUrl)
            .then(response => {
                var lots = response["data"].map((lot)=>{return lot.lotid});
                setSelectedLots([lots[0]]);
                setFullLotList(lots);}
            )
            .catch((error) => {console.error(error)});
        }, []);

    function handleSelectLot(lot){
        const lot_idx = selectedLots.indexOf(lot);
        if (lot_idx === -1){
            setSelectedLots(selectedLots.concat([lot]));
        } else {
            var newLots = selectedLots.slice();
            newLots.splice(lot_idx,1);
            setSelectedLots(newLots);
        }
        
    }

    function handleDateChange(){
        date = document.getElementById(`dateInput${props.idx}`).value;
        setDate(date);
    }

    const dataUrl = `${process.env.REACT_APP_API_URL}/api/statistics/percent/${selectedLots.join(' ')}/${date}`;
    useEffect(()=>{axios.get(dataUrl)
                        .then((response)=>{setGraphData(response["data"])})
                        .catch((error)=> {console.error(error)});},
            [selectedLots, date])

    return <Card>
                <div class="m-0 p-0 flex-none border-r border-gray-400 bg-white">
                    <OneDayPercentGraph data={graphData} lots={selectedLots}/>
                </div>
                <div class="w-full bg-white p-4 flex flex-col">
                    <span class="flex justify-between">
                        One Day Percentage 
                        <button onClick={()=>props.onClose(props.idx)}>
                            <i class="rounded-lg border-2 p-1 fa-solid fa-xmark" />
                        </button>
                    </span>
                    <DateSelect idx={props.idx} value={date} message="Date:" onChange={handleDateChange}/>
                    <MultiSelect options={fullLotList} selected={selectedLots} message="Select Lots" onChange={handleSelectLot}/>
                </div>
            </Card>
}