import React from "react";
import {ResponsiveContainer, Dot, LineChart, Line, XAxis, YAxis, CartesianGrid, Tooltip, Legend } from 'recharts';

function CustomDot(props){
    return <Dot  fill={props.color} r={2} cx={props.cx} cy={props.cy} />
}

function generateLine(lotName, idx){
    const colors = ["#8884d8", "#82ca9d", "#ca829d", "#ca9d82"];
    return <Line type="monotone" dataKey={lotName} dot={<CustomDot color={colors[idx % 4]}/>} stroke={colors[idx % 4]} ></Line>;
}

function formatLabel(timestamp){
    return `time: ${formatTime(timestamp)}`;
}

function formatValue(value, name){
    return `${Math.round(value * 100)}%`;
}

function formatTime(timestamp){
    const date = new Date(timestamp * 1000);
    var hours = date.getHours();
    var pm = hours >= 12 ? 'pm' : '';
    hours %= 12;
    if (hours === 0){
        hours = 12;
    }
    var minutes = `${date.getMinutes()}`;
    if (minutes.length === 1){
        minutes = '0' + minutes;
    }
    const time_str = `${hours}:${minutes}${pm}`;
    return time_str;
}

function formatPercent(ratio){
    return `${Math.round(ratio * 100)}%`;
}

export default function OneDayPercentGraph(props){

    var lotList = [];
    if (props.lots.length > 0){
        lotList = props.lots.map((num)=>`lot${num}`);
    }

    return <ResponsiveContainer height={350} width={500}>
                <LineChart
                    width={500}
                    height={350}
                    data={props.data}
                    margin={{
                        top: 20,
                        right: 30,
                        left: 10,
                        bottom: 10,
                    }}
                >
                    <CartesianGrid strokeDasharray="3 3" />
                    <XAxis dataKey="time"
                        domain={['auto', 'auto']}
                        name='Time'
                        type="number"
                        tickFormatter={formatTime} />
                    <YAxis tickFormatter={formatPercent} />
                    <Tooltip formatter={formatValue} labelFormatter={formatLabel} />
                    <Legend />
                    {lotList.map(generateLine)}
                </LineChart>
            </ResponsiveContainer>

}