import { Listbox, Transition } from '@headlessui/react'
import { Fragment } from 'react'


export default function SingleSelect(props){
    return <div className="flex h-full">
    <Listbox className="m-2" value={props.selected} onChange={props.onChange}>
        <div className="relative mt-1">
        <Listbox.Button className="relative w-full py-2 pl-3 pr-10 text-left bg-white rounded-lg shadow-md cursor-default focus:outline-none focus-visible:ring-2 focus-visible:ring-opacity-75 focus-visible:ring-white focus-visible:ring-offset-orange-300 focus-visible:ring-offset-2 focus-visible:border-indigo-500 sm:text-sm">
            <span className="block truncate">{props.selected}</span>
            <span className="absolute inset-y-0 right-0 flex items-center pr-2 pointer-events-none">
            <i className="fa-solid fa-chevron-down" />
            </span>
        </Listbox.Button>
        <Transition
            as={Fragment}
            leave="transition ease-in duration-100"
            leaveFrom="opacity-100"
            leaveTo="opacity-0"
        >
            <Listbox.Options className="absolute z-[1000] w-[500] py-1 mt-1 overflow-auto text-base bg-white rounded-md shadow-lg max-h-40 ring-1 ring-black ring-opacity-5 focus:outline-none sm:text-sm">
            {props.options.map((option, optionIdx) => (
                <Listbox.Option
                    key={optionIdx}
                    className={({ active }) =>
                        active ? 'text-amber-900 bg-amber-100 cursor-default select-none relative py-2 pl-10 pr-4' : 'cursor-default select-none relative py-2 pl-10 pr-4 text-gray-900'
                    }
                    value={option}
                    >
                        <span
                            className={
                                props.selected === option ? 'block font-medium' : 'block font-normal'
                            }
                        >
                            {option}
                        </span>
                        {props.selected === option ? (
                            <span className="absolute inset-y-0 left-0 flex items-center pl-3 text-amber-600">
                                <i className="fa-solid fa-check" />
                            </span>
                        ) : null}
                </Listbox.Option>
            ))}
            </Listbox.Options>
        </Transition>
        </div>
    </Listbox>

    </div>
}