import axios from "axios";
import React, { useState, useEffect } from "react";
import Card from './Card';
import SingleSelect from "./SingleSelect";

export default function StatisticsSensors(props) {

    let singlePanelURL = `${process.env.REACT_APP_GRAFANA_URL}${process.env.REACT_APP_SINGLE_PANEL_PATH}`;
    let fullDashboardURL = `${process.env.REACT_APP_GRAFANA_URL}${process.env.REACT_APP_DASHBOARD_PATH}`;
    let sensorListURL = `${process.env.REACT_APP_API_URL}/api/sensor/`;
    const [sensorList, setSensorList] = useState([]);
    const [selectedSensor, setSelectedSensor] = useState("sensor1");

    const handleChange = (sensor) => {
        setSelectedSensor(sensor);
    };

    useEffect(() => {
        const getConfig = {
            url: sensorListURL,
            method: "GET",
            headers: {
                "Content-Type": "application/json",
            },
        };
        axios(getConfig)
            .then((response) => {
                setSensorList(response.data.map((d) => { return "sensor" + d.enid; }));
            })
            .catch((error) => {
                console.error(error);
            });
    }, []);

    return (<>
        <div className="pt-5 pl-3">
            <span className='flex flex-row'>
                <SingleSelect selected={selectedSensor} onChange={handleChange} options={sensorList} />

                <a href={`${fullDashboardURL}&var-server=${selectedSensor}`} className="sm:text-sm text-base font-normal shadow-none"><button class='rounded-lg bg-white p-2 m-2 shadow-md'>see more metrics...</button></a>
            </span>
        </div>
        <div className="px-5 mt-3">
            <Card>
                <div>
                    <div className="grid gap-5 md:grid-cols-1 xl:grid-cols-2">
                        <div>
                            <div className="grid gap-5 p-5 grid-cols-4">
                                <iframe
                                    src={`${singlePanelURL}${process.env.REACT_APP_UPTIME_PANEL_ID}&var-server=${selectedSensor}`}
                                    width="100%" frameborder="0" title="uptime">
                                </iframe>
                                <iframe
                                    src={`${singlePanelURL}${process.env.REACT_APP_CPU_PANEL_ID}&var-server=${selectedSensor}`}
                                    width="100%" frameborder="0" title="cpu usage">
                                </iframe>
                                <iframe
                                    src={`${singlePanelURL}${process.env.REACT_APP_MEMORY_PANEL_ID}&var-server=${selectedSensor}`}
                                    width="100%" frameborder="0" title="memory usage">
                                </iframe>
                                <iframe
                                    src={`${singlePanelURL}${process.env.REACT_APP_ROOTFS_PANEL_ID}&var-server=${selectedSensor}`}
                                    width="100%" frameborder="0" title="rootfs usage">
                                </iframe>
                            </div>
                        </div>
                    </div>
                </div>
            </Card>
        </div>
        <div className="grid gap-5 p-5 md:grid-cols-1 xl:grid-cols-2 w-100">
            <Card>
                <iframe
                    src={`${singlePanelURL}${process.env.REACT_APP_FULL_CPU_PANEL_ID}&var-server=${selectedSensor}`}
                    width="100%" height="350" frameborder="0" title="full cpu usage">
                </iframe>
            </Card>
            <Card>
                <iframe
                    src={`${singlePanelURL}${process.env.REACT_APP_FULL_MEMORY_PANEL_ID}&var-server=${selectedSensor}`}
                    width="100%" height="350" frameborder="0" title="full memory usage">
                </iframe>
            </Card>
            <Card>
                <iframe
                    src={`${singlePanelURL}${process.env.REACT_APP_FULL_NETWORK_PANEL_ID}&var-server=${selectedSensor}`}
                    width="100%" height="350" frameborder="0" title="full network usage">
                </iframe>
            </Card>
        </div>
    </>
    );
}