import { Dialog, Transition } from '@headlessui/react'
import { TrashIcon } from '@heroicons/react/solid'
import { Fragment, useState } from 'react'

export default function DeleteButton(props) {
  let [isOpen, setIsOpen] = useState(false);

  function closeConfirmModal() {
    setIsOpen(false)
  }

  function openConfirmModal() {
    setIsOpen(true)
  }

  return (
    <>
        <button
          type="button"
          onClick={openConfirmModal}
          className={
              props.buttonClass? props.buttonClass :"inline-flex w-full py-2 mt-4 text-sm font-medium text-white bg-red-800 rounded-md bg-opacity-20 hover:bg-opacity-30 focus:outline-none focus-visible:ring-2 focus-visible:ring-white focus-visible:ring-opacity-75"
              }
        >
         <TrashIcon className={props.trashIconClass? props.trashIconClass: "w-5 h-5 mt-1 mr-1"}/>
          {props.buttonText?props.buttonText:""}
        </button>

      <Transition appear show={isOpen} as={Fragment}>
        <Dialog
          as="div"
          className="fixed inset-0 z-[1400] overflow-y-auto"
          onClose={closeConfirmModal}
        >
          <div className="min-h-screen px-4 text-center">
            <Transition.Child
              as={Fragment}
              enter="ease-out duration-300"
              enterFrom="opacity-0"
              enterTo="opacity-100"
              leave="ease-in duration-200"
              leaveFrom="opacity-100"
              leaveTo="opacity-0"
            >
              <Dialog.Overlay className="fixed inset-0 bg-black opacity-50" />
            </Transition.Child>

            {/* This element is to trick the browser into centering the modal contents. */}
            <span
              className="inline-block h-screen align-middle"
              aria-hidden="true"
            >
              &#8203;
            </span>
            <Transition.Child
              as={Fragment}
              enter="ease-out duration-300"
              enterFrom="opacity-0 scale-95"
              enterTo="opacity-100 scale-100"
              leave="ease-in duration-200"
              leaveFrom="opacity-100 scale-100"
              leaveTo="opacity-0 scale-95"
            >
              <div className="inline-block w-full max-w-md p-6 my-8 overflow-hidden text-left align-middle transition-all transform bg-white shadow-xl rounded-2xl">
                <Dialog.Title
                  as="h3"
                  className="text-lg font-medium leading-6 text-gray-900"
                >
                  Are you sure?
                </Dialog.Title>
                <div className="mt-2">
                  <p className="text-sm text-gray-500">
                    Deleting this item will also delete its row in the database. This cannot be undone
                  </p>
                </div>

                <div className="flex-row gap-2 mt-4 space-x-3">
                  <button
                    type="button"
                    className="inline-flex justify-center px-4 py-2 text-sm font-medium text-white bg-red-500 border border-transparent rounded-md basis-1/2 hover:bg-red-200 focus:outline-none focus-visible:ring-2 focus-visible:ring-offset-2 focus-visible:ring-red-500"
                    onClick={()=>{
                      props.deleteItemHandler();
                      closeConfirmModal();
                    }}
                  >
                    <TrashIcon className={`w-3 h-3 mt-1 mr-1`}/>
                    Delete
                  </button>
                  <button
                    type="button"
                    className="inline-flex justify-center px-4 py-2 text-sm font-medium bg-gray-200 border border-transparent rounded-md basis-1/2 text-slate-500 hover:bg-blue-200 focus:outline-none focus-visible:ring-2 focus-visible:ring-offset-2 focus-visible:ring-blue-500"
                    onClick={closeConfirmModal}
                  >
                    Cancel
                  </button>
                </div>
              </div>
            </Transition.Child>
          </div>
        </Dialog>
      </Transition>
    </>
  )
}