import React, { useState, useRef, useEffect } from "react";

import { useDispatch, useSelector } from "react-redux";
import { showHalf, showFull, setTransitionEnd } from "../../redux/lotSelectSlice";
import SingleLot from "./lots/SingleLot";
import { updateMapData } from "../../redux/mapSlice";
import NearbyLots from "./lots/NearbyLots";
import {Switch, Route, useParams, NavLink, useHistory, useLocation} from "react-router-dom";
import BookmarkList from "./lots/BookmarkList";
import SearchList from "./lots/SearchList";
export default function MainModal() {
  const watchCurrentPosition = useSelector((state) => state.map.watchCurrentPosition);
  const display = useSelector((state) => state.lotSelect.display);
  const {whichComponent} = useParams();

  const params = useParams();
  const currentLocation = useSelector((state) => state.map.currentLocation);
  let history = useHistory();
  const location = useLocation();
  const dispatch = useDispatch();

  const panelRef = useRef();

  useEffect(() => {
    if (currentLocation && display==="" && !whichComponent) { //if we have location & by default we will show nearby lots
      dispatch(showHalf({ componentToLoad: "nearby" }));
      history.push("/map/nearby");
    }
    //if whichComponent is being loaded we need to show the modal
    if (!display && whichComponent){
      dispatch(showHalf({componentToLoad: whichComponent}));
    }
  }, [display, currentLocation, whichComponent]);

  // Handle sliding
  const [mouseDownY, setMouseDownY] = useState(0);
  const [mouseUpY, setMouseUpY] = useState(0);
  const [mouseHolding, setMouseHolding] = useState(false);
  const [mouseClickFired, setMouseClickFired] = useState(false);
  function handleMouseDown(e) {
    //if(e.currentTarget != e.target ) return;
    setMouseDownY(e.clientY);
    setMouseClickFired(true);
  }
  function handleMouseUp(e) {
    //if(e.currentTarget != e.target ) return;
    if (mouseUpY - mouseDownY < -75 && mouseHolding) {
      movePanelUp();
    }
    if (mouseUpY - mouseDownY > 75 && mouseHolding) {
      movePanelDown();
    }
    setMouseUpY(0);
    setMouseDownY(0);
    if (mouseClickFired)
    setMouseHolding(false);
    setMouseClickFired(false);
  }
  function handleMouseMove(e) {
    if (mouseClickFired){
      setMouseHolding(true);
      setMouseUpY(e.clientY);
    }
  }
  function handleMouseLeave(e) {
    setMouseUpY(e.clientY);
    if (e.clientY - mouseDownY < -75 && mouseHolding) {
      movePanelUp();
    }
    if (e.clientY - mouseDownY > 75 && mouseHolding) {
      movePanelDown();
    }
    setMouseUpY(0);
    setMouseDownY(0);
    if (mouseClickFired)
    setMouseHolding(false);
    setMouseClickFired(false);
  }

  function handleTouchStart(e) {
    setMouseDownY(e.targetTouches[0].clientY);
    // setMouseHolding(true);
  }
  function handleTouchMove(e) {
    setMouseHolding(true);
    setMouseUpY(e.targetTouches[0].clientY);
  }
  function handleTouchEnd(e) {
    if (mouseUpY - mouseDownY < -100 && mouseHolding) {
      movePanelUp();
    }
    if (mouseUpY - mouseDownY > 100 && mouseHolding) {
      movePanelDown();
    }
    //reset mouse
    setMouseUpY(0);
    setMouseDownY(0);
    setMouseHolding(false);
  }

  //SLiding Actions
  function movePanelUp() {
    dispatch(showFull({ componentToLoad: whichComponent }));
  }
  function movePanelDown() {
    dispatch(showHalf({ componentToLoad: whichComponent }));
  }
  function handlePanelDisplay(display) {

    if ((display === "") | !display) {
      return "h-1/3 translate-y-[300%] w-full mainmodal select-none bg-white flex flex-col shadow-4sides  justify-start place-items-center rounded-t-3xl z-[1200] w-full text-slate-700 transform transition-all duration-400 ease-linear ";
    } else if (display === "half") {
      return "h-1/3 translate-y-[200%] w-full ease-in mainmodal select-none bg-white flex flex-col shadow-4sides  justify-start place-items-center rounded-t-3xl z-[1200] w-full text-slate-700 transform transition-all duration-400 ease-linear ";
    } else if (display === "full") {
      return "h-4/5 translate-y-[15%] w-[92%] place-self-center rounded-b-xl mainmodal select-none bg-white flex flex-col shadow-4sides  justify-start place-items-center rounded-t-3xl z-[1200] w-full text-slate-700 transform transition-all duration-400 ease-linear ";
    }
  }

  const handleWatchMe = () => {
    dispatch(updateMapData({ watchCurrentPosition: !watchCurrentPosition }));
  };

  const handleBookmarksButton = (e, isBookmarkSelected) => {
    // Going from selected to unselected
    if (isBookmarkSelected)
    {
      if (location.key) {
        history.goBack();
      } else {
        history.push("/map/nearby");
      }
    }
    // Going from unselected to selected
    else
    {
      history.push("/map/bookmarks");
    }


  };

  const handleGoBack = (e) =>{
    history.goBack();
  }

  // Determine if bookmark button is selected
  const isBookmarkSelected = whichComponent === "bookmarks" ? true: false;

  return (
    <div
      ref={panelRef}
      onMouseDown={handleMouseDown}
      onMouseMove={handleMouseMove}
      onMouseUp={handleMouseUp}
      onMouseLeave={handleMouseLeave}
      onTouchStart={handleTouchStart}
      onTouchEnd={handleTouchEnd}
      onTouchMove={handleTouchMove}
      onTransitionEnd={() => {
        dispatch(setTransitionEnd({ transitionEnd: true }));
      }}
      className={handlePanelDisplay(display)}
    >
      {(display === undefined || display !== "full") && (
        <div className="absolute flex flex-row justify-between w-full m-0 bg-opacity-0 -translate-y-14">
          <div className="flex flex-row ml-4 place-items-end">
            <button
              onClick={(e) => handleBookmarksButton(e, isBookmarkSelected)}
              className={isBookmarkSelected ? `bg-slate-700 text-white flex px-2 py-1 text-sm  rounded-full shadow-xl place-items-center focus:outline-none
              transition duration-300` : `flex px-2 py-1 text-sm bg-white rounded-full shadow-xl text-slate-700 place-items-center focus:outline-none
              transition duration-300`}

            >
              <i className="pr-1 text-base align-top fa-regular fa-bookmark"></i>
              <span className="text-sm font-medium">Bookmarks</span>
            </button>
          </div>
          <button onClick={handleWatchMe} className="w-12 h-12 mr-4 text-3xl bg-white rounded-lg text-slate-600 ">
            <i className="fa-solid fa-location-crosshairs"></i>
          </button>
        </div>
      )}
      {/* Explore ---- Bookmarks bar on Full view */}
      {/*Switch between displaying full or not full */}
      {!!(isNaN(parseInt(whichComponent)) && display === "full" && whichComponent !=="lot") && (
        <>
          <div className="w-full p-1 bg-slate-700 rounded-t-3xl ">
            <div className="flex flex-row justify-around w-full mx-2 text-xs">
              <NavLink
                to={`/map/nearby`}
                className="flex-col text-white"
              >
                <div
                  className={
                    whichComponent !== "bookmarks" ? "bg-white/80 translate-x-0 w-3.5 h-[2px] mx-auto  mb-1 rounded-full transition-transform duration-300"  : "w-3.5 h-[2px] mx-auto  mb-1 rounded-full transition-transform duration-300 bg-white/0 translate-x-4"
                  }


                ></div>
                <div className="flex flex-row place-items-center">
                  <i className="mr-1 fas fa-compass"></i>
                  <span className="tracking-wide">Explore</span>
                </div>
              </NavLink>
              <NavLink
               to={`/map/bookmarks`}
               className="flex-col text-white">
                <div
                  className={
                    whichComponent === "bookmarks" ? "bg-white/80 translate-x-0 w-3.5 h-[2px] mx-auto mb-1 rounded-full" : "w-3.5 h-[2px] mx-auto mb-1 rounded-full bg-white/0 -translate-x-4 transition-transform duration-300"
                  }
                ></div>
                <div className="flex flex-row place-items-center">
                  <i className="mr-1 fas fa-bookmark"></i>
                  <span className="tracking-wide">Bookmarks</span>
                </div>
              </NavLink>
            </div>
          </div>
        </>
      )}
      {/* Go Back button when SingleLot is displaying */}
      {display === "full" && whichComponent==="lot" &&
      <div
        onClick={(e)=>handleGoBack(e)}
        className="z-[1200] absolute left-0 -top-12 h-10 w-10 bg-white border shadow-4sides rounded-full content-center">
        <i class="fa-solid fa-chevron-left text-2xl translate-x-3 translate-y-1 text-slate-800"></i>
      </div>}
      {/* {handleShowChild(whichComponent)} */}
      <Switch>
        <Route path="/map/search/:terms/:lat?/:lng?">
                  <SearchList/>
        </Route>
        <Route path="/map/nearby">
                  <NearbyLots/>
        </Route>
        <Route path="/map/bookmarks">
                  <BookmarkList/>
        </Route>
        <Route path="/map/lot/:lotid(\d+)">
                  <SingleLot/>
        </Route>
      </Switch>
    </div>
  );
}
