import React, { Fragment, useState, useEffect } from "react";
import MainBar from "./MainBar";
import UserMenu from "./UserMenu";
import UserMap from "./map/UserMap";
import { useSelector, useDispatch } from "react-redux";

import MainModal from "./MainModal";
import {Switch, Route, useRouteMatch} from "react-router-dom";
import axios from "axios";
import { updateMapData } from "../../redux/mapSlice";

function UserView() {
  const panelDisplay = useSelector((state) => state.lotSelect.display);
  let { path, url } = useRouteMatch();
  const dispatch = useDispatch();
  // Get all lots data
  useEffect(() => {
    axios({
        url: `${process.env.REACT_APP_API_URL}/api/lotcomplete/`,
        headers: { "Content-Type": "application/json" },
        method: "GET",
    })
    .then(response => {
      dispatch(updateMapData({lots:response.data}));
    })
    .catch(error=>{
      console.error(error);
    });
    //get highest lot capacity
    axios({
      url: `${process.env.REACT_APP_API_URL}/api/lot/maxcapacity/`,
        headers: { "Content-Type": "application/json" },
        method: "GET",
    })
    .then(response=>{
      dispatch(updateMapData({maxLotCapacity:response.data}));
    })
    .catch(error=>{
      console.error(error);
    })
  },[])

  return (
    <div className="user-wrapper z-[1000] flex flex-col h-full flex-shrink justify-start flex-grow-0 antialiased">
      <div className="flex flex-col w-full h-screen overflow-hidden">
        <UserMap />
        <UserMenu />
        {/* Only shows MainBar outside when panel is not in full */}
        {(panelDisplay !== "full" || !panelDisplay)  && <MainBar/>}
        {/* Lot Display */}
        <Switch>
          <Route path="/map/:whichComponent?">
            <MainModal/>
          </Route>
        </Switch>
      </div>
    </div>
  );
}

export default UserView;
