import { useEffect, useState } from 'react';
import { RadioGroup } from '@headlessui/react';
import {clearToggles, showOnly, showAll, showPass, hidePass} from "../../../redux/filterSlice";
import { useDispatch, useSelector } from "react-redux";
import { updatePasses } from "../../../utils/pass";

function PassOption(props){
    return <RadioGroup.Option value={props.value}>
                {({ checked }) => (
                    <span className={checked ? 'text-white bg-[#428be7] shadow border rounded-lg m-1 px-2 py-1 flex flex-row w-full justify-between' : 'shadow border rounded-lg m-1 px-2 py-1 flex flex-row w-full justify-between'}>
                        <label>{props.text} </label>{checked && (<i className='text-xl text-blue-200 fa-solid fa-circle-check'/>)}
                        </span>
                )}
            </RadioGroup.Option>;
}

const PASSES = {ALL : -1};

export default function FilterMenu(props){
    const dispatch = useDispatch();
    const Toggles = useSelector((state) => state.filterToggles.Toggles);

    var toggledOn = [];

    for (const [pass, val] of Object.entries(Toggles)){
        if(val){
            toggledOn.push(pass);
        }
    }

    var initSelectedPass = PASSES.ALL;

    if(toggledOn.length === 1){
        initSelectedPass = toggledOn[0];
    }


    // a list of dictionaries containing name/shortname of all passes
    const passes = useSelector((state)=> state.map.passes);



    var options = [
        {value: PASSES.ALL,
        text: 'All'}
    ];

    const shortnames = [];

    for (const pass of passes){
        options.push({value: pass.shortname,
                      text: pass.name});
        shortnames.push(pass.shortname);
    }


    const [passSelected, setPassSelected] = useState(initSelectedPass);

    function handleChange(pass){
        setPassSelected(pass);

        if (pass === PASSES.ALL){
            dispatch(showAll());
        }else{
            dispatch(showOnly(pass));
        }
    }

    // check if the admin has added or removed any passes.
    useEffect(()=>{
        if (passes.length > 0){
            var needReset = false;

            for (const [pass, val] of Object.entries(Toggles)){
                if (!shortnames.includes(pass)){
                    needReset = true;
                    break;
                }
            }

            for (const shortname of shortnames){
                if(!Object.keys(Toggles).includes(shortname)){
                    needReset = true;
                    break;
                }
            }

            if (needReset){
                dispatch(clearToggles());
                for(const shortname of shortnames){
                    dispatch(showPass(shortname));
                }
                setPassSelected(PASSES.ALL);
            }
        }
    },[passes]);

    return <div className="flex flex-col w-full justify-right">
                <RadioGroup value={passSelected} onChange={handleChange}>
                    <RadioGroup.Label><label className="font-bold">Show Passes:</label></RadioGroup.Label>
                    <div className='flex-row w-full pl-5 pr-3'>
                        {options.map((pass)=>(<PassOption key={pass.value} value={pass.value} text={pass.text}/>))}
                    </div>
                </RadioGroup>
            </div>

}