import axios from "axios";
import React, { useState, useEffect, Component } from "react";
import BookmarkButton from "../bookmark/BookmarkButton";
import { useSelector, useDispatch } from "react-redux";
import { showComponent } from "../../../redux/lotSelectSlice";
import MainBar from "../MainBar";
import InfiniteScroll from "react-infinite-scroll-component";
import { useParams, useHistory } from "react-router";
import { Link } from "react-router-dom";
import Directions from "../icons/Directions";
import SmallControlElement from "../SmallControlElement";

export default function LotList({lotlist, whichComponent}) {
  let {terms, lat, lng} = useParams();
  const showingLotList = lotlist;
  const display = useSelector((state) => state.lotSelect.display);
  const [showingLots, setShowingLots] = useState([]);
  const lotStallsRemaining = useSelector((state) => state.map.lotStallsRemaining);

  const [hasMore, setHasMore] = useState(true);
  const dispatch = useDispatch();
  let history = useHistory();
  useEffect(() => {
    setShowingLots(showingLotList.slice(0, 20));
    if (showingLots.length >= showingLotList.length) {
      setHasMore(false);
    } else setHasMore(true);
  }, [showingLotList]);

  const fetchMoreData = () => {
    if (showingLots.length >= showingLotList.length) {
      setHasMore(false);
      return;
    }
    setTimeout(() => {
      setShowingLots(showingLots.concat(showingLotList.slice(showingLots.length, showingLots.length + 10)));
    }, 1500);
  };

  const topDisplay = () => {
    if (whichComponent === "search")
      return (
        <>
          {/* PUT MAIN BAR HERE */}
          {display === "full" && <MainBar defaultSearchTerm={terms} />}
          <div className={`flex flex-row w-full text-slate-500 font-medium text-sm mx-3 my-2`}>
            {!!(terms && showingLots.length) && (terms === "*" ? `Parking lots nearby selected building` : `Parking lots matching "${terms}"`)}
            {!!(terms && showingLots.length === 0) && `No parking lots found matching "${terms}"`}
          </div>
        </>
      );
    else if (whichComponent==="bookmarks")
        return(
          <>
          <div className={`flex flex-row w-full text-slate-700 text-base font-medium mx-3 my-1`}>
            {!!(showingLots.length === 0) && `No saved lots`}
            {!!(showingLots.length) && `Nearby saved `}
          </div>
          {!!(showingLots.length === 0) && (
            <div className="mx-3 text-sm text-slate-400">
              Bookmark parking lots to have them show up here
            </div>
          )}
          </>
        )
    else if (whichComponent ==="nearby")
        return(
        <>
          {display === "full" && <MainBar />}
          <div className={`flex flex-row w-full text-slate-500 font-medium text-sm mx-3 my-2`}>
            Nearby parking lots
          </div>
   </>
        )
  };


  return (
    <div className="flex flex-col w-full overflow-hidden">
      <div className={`flex flex-col w-full h-full m-1`}>
        {/* small control element */}
          <SmallControlElement/>

        {topDisplay()}
        <div
          id="LotsList"
          className={display === "half" ? "overflow-hidden w-full pl-3.5" : "overflow-y-scroll overflow-x-hidden w-full pl-3.5"}
        >
          {!!showingLots.length && (
            <InfiniteScroll
              dataLength={showingLots.length}
              next={fetchMoreData}
              hasMore={hasMore}
              style={{ width: "100%", overflow: "hidden" }}
              loader={<h4>Loading...</h4>}
              endMessage={
                <p style={{ textAlign: "center" }}>
                  <span className="text-sm font-semibold text-slate-400">You have seen it all</span>
                </p>
              }
              scrollableTarget="LotsList"
            >
              {showingLots.map(function (data, idx) {
                return (
                  <div
                  onClick={(e)=>{history.push(`/map/lot/${data.lot.lotid}`)}}
                  className="flex flex-row w-full py-2 pl-0.5 border-b border-bottom border-b-slate-200" key={data.lot.lotid}>
                    <div className="flex flex-col w-full">
                      <div className="flex flex-row w-full flex-nowrap">
                        {lotStallsRemaining &&(
                        <>
                          {lotStallsRemaining[data.lot.lotid] > 50? (
                          <i className="flex mt-1 text-green-500 fas fa-circle"></i>
                        ) : lotStallsRemaining[data.lot.lotid] > 25 ? (
                          <i className="flex mt-1 text-yellow-500 fas fa-circle"></i>
                        ) : (
                          <i className="flex mt-1 text-red-500 fas fa-circle"></i>
                        )}
                        </>)}

                        <div className="flex text-slate-800 font-medium ml-1.5 mr-4 self-start truncate"> {data.lot.name} </div>
                      </div>
                      <div className="flex flex-row gap-1 text-sm font-medium text-slate-600">
                        {data.distance != null ? (
                          <span className="distance-text">
                            {data.distance > 5 ? Math.round(data.distance) : data.distance.toFixed(1)} mi
                          </span>
                        ) : (
                          ""
                        )}
                        <span className="spacer"></span>
                        <span className="entrances-text">
                          {data.enexcount} Entrance{data.enexcount == 1 ? "" : "s"}
                        </span>
                      </div>
                      <div className="flex flex-row w-full gap-2 m-0 place-items-center">
                        {data.accpasses.map(function (accpass, idx) {
                          if (accpass.shortname == "D") {
                            return (
                              <span key={accpass.shortname} className="permit-symbol permit-symbol-general">
                                <i className="text-lg text-indigo-500 fas fa-wheelchair"></i>
                              </span>
                            );
                          } else {
                            return <span key={accpass.shortname} className="permit-symbol permit-symbol-custom">{accpass.shortname} </span>;
                          }
                        })}
                      </div>
                      <div className="flex">
                        <a
                          href={`https://www.google.com/maps/dir/?api=1&destination=${data.lot.latitude},${data.lot.longitude}`}
                        >
                          <Directions/>
                        </a>
                      </div>
                    </div>
                    <div
                      className="flex flex-row align-top basis-1/4 text-slate-500 hover:text-slate-700 hover:font-semibold"
                    >
                      <div className="mr-1 -translate-y-1">
                      <BookmarkButton lotid={data.lot.lotid} />
                      </div>
                    </div>
                  </div>
                );
              })}
            </InfiniteScroll>
          )}
        </div>
      </div>
    </div>
  );
}
