import axios from "axios";
import { useState, useEffect } from "react";
import { useDispatch, useSelector } from "react-redux";
import { showHalf, showFull, hideLotSelect, showComponent } from "../../../redux/lotSelectSlice";
import { updateMapData } from "../../../redux/mapSlice";
import BookmarkButton from "../bookmark/BookmarkButton";
import MainBar from "../MainBar";
import InfiniteScroll from "react-infinite-scroll-component";
import {getString} from "../../../utils/search";
import LotList from "./LotList";

export default function NearbyLots() {
  const display = useSelector((state) => state.lotSelect.display);
  const currentLocation = useSelector((state) => state.map.currentLocation);
  const nearbyLots = useSelector((state) => state.map.nearbyLots);
  const [hasMore, setHasMore] = useState(true);
  const [showingNearbyLots, setShowingNearbyLots] = useState([]);
  const [reload, setReload] = useState();
  const Toggles = useSelector((state) => state.filterToggles.Toggles);
    
  const filters = getString(Toggles);

  const dispatch = useDispatch();
  useEffect(() => {
    // GET NEARBY LOTS if location is found
    if (currentLocation)
    axios({
      url: `${process.env.REACT_APP_API_URL}/api/lotsearch/${currentLocation.lat}/${currentLocation.lng}/${filters}`,
      headers: { "Content-Type": "application/json" },
      method: "GET",
    })
      .then((response) => {
        dispatch(updateMapData({ nearbyLots: response.data }));
        setShowingNearbyLots(response.data.slice(0, 50));
      })
      .catch((error) => {
        console.error(error);
      });
  }, [currentLocation, Toggles]);

  const fetchMoreData = () => {
    if (showingNearbyLots.length >= nearbyLots.length) {
      setHasMore(false);
      return;
    }
    setTimeout(() => {
      setShowingNearbyLots(
        showingNearbyLots.concat(nearbyLots.slice(showingNearbyLots.length, showingNearbyLots.length + 10))
      );
    }, 1500);
  };

  return (
    <>
      {currentLocation&&nearbyLots && showingNearbyLots && (
        <LotList lotlist={nearbyLots} whichComponent={"nearby"}/>
      )}
    </>
  );
}
