import axios from "axios";
import React, { useState,  useEffect, Fragment } from "react";
import { useSelector, useDispatch } from "react-redux";
import AcceptedPass from "../acceptedpass/AcceptedPass";
import { useParams } from "react-router";
import HalfHoursChart from "../visualizations/HalfHoursChart";
import BookmarkButton from "../bookmark/BookmarkButton";
import { Dialog, Transition } from "@headlessui/react"; // Dialog box for admin announcements
import Directions from "../icons/Directions";
import FullnessCarsVis from "../visualizations/FullnessCarsVis";
import { updateMapData } from "../../../redux/mapSlice";

import L from 'leaflet';
import SmallControlElement from "../SmallControlElement";

export default function SingleLot() {
  const display = useSelector((state) => state.lotSelect.display);
  const { lotid } = useParams();
  const [lotData, setLotData] = useState();
  const [lotAccPasses, setLotAccPasses] = useState();
  const [lotPercentFull, setLotPercentFull] = useState();
  const [halfHoursPrediction, setHalfHoursPrediction] = useState();
  const [lotAnnouncement, setLotAnnouncement] = useState();
  const [apiError, setApiError] = useState();
  const lotStallsRemaining = useSelector((state) => state.map.lotStallsRemaining);
  const [modalShowing, setModalShowing] = useState(false);
  const [lotTotalStalls, setlotTotalStalls] = useState();
  const dispatch = useDispatch();
  const currentLocation = useSelector((state) => state.map.currentLocation);

  // Open and close admin announcement dialog box
  function closeModal() {
    setModalShowing(false);
  }
  function openModal() {
    setModalShowing(true);
  }

  useEffect(() => {
    return () =>{
      dispatch(
        updateMapData({
          userMapFlyToLatLng: undefined,
          userMapFlyToZoomLevel: 12,
        })
      );
    }
  },[])

  useEffect(() => {
    //get lot Data
    axios({
      url: `${process.env.REACT_APP_API_URL}/api/lot/${lotid}`,
      method: "GET",
      headers: {
        "Content-Type": "application/json",
      },
    })
      .then((response) => {
        setLotData(response.data);
        //If lotid changes => tells map to fly to that lot:
        dispatch(
          updateMapData({
            userMapFlyToLatLng: { lat: response.data.latitude, lng: response.data.longitude },
            userMapFlyToZoomLevel: 17,
          })
        );
      })
      .catch((error) => {
        console.error(error);
        setApiError(error);
      });
    //get lot acceptedpass
    axios({
      url: `${process.env.REACT_APP_API_URL}/api/lot/${lotid}/acceptedpasses`,
      method: "GET",
      headers: {
        "Content-Type": "application/json",
      },
    })
      .then((response) => {
        setLotAccPasses(response.data);
        // Calculate total stalls:
        let totalStalls = 0;
        response.data.forEach(accpass => totalStalls += parseInt(accpass["allottedstalls"]));
        setlotTotalStalls(totalStalls);
      })
      .catch((error) => {
        console.error(error);
        setApiError(error);
      });
    //get percentfull
    axios({
      url: `${process.env.REACT_APP_API_URL}/api/lot/${lotid}/percentfull`,
      method: "GET",
      headers: {
        "Content-Type": "application/json",
      },
    })
      .then((response) => {
        setLotPercentFull(response.data);
      })
      .catch((error) => {
        console.error(error);
        setApiError(error);
      });
    //get halfhours prediction:
    axios({
      url: `${process.env.REACT_APP_API_URL}/api/lot/${lotid}/prediction/halfhours/`,
      method: "GET",
      headers: {
        "Content-Type": "application/json",
      },
    })
      .then((response) => {
        setHalfHoursPrediction(response.data);
      })
      .catch((error) => {
        console.error(error);
        setApiError(error);
      });
    // Get Admin Announcement
    axios({
      url: `${process.env.REACT_APP_API_URL}/api/adminannouncement/${lotid}/`,
      method: "GET",
      headers: {
        "Content-Type": "application/json",
      },
    })
      .then((response) => {
        setLotAnnouncement(response.data);
      })
      .catch((error) => {
        console.error(error);
        setApiError(error);
      });
  }, [lotid]);

  const getDistance = () => {
    if (currentLocation != null)
    {
      const currentPosLatLng = L.latLng(currentLocation.lat, currentLocation.lng);
      const lotPositionLatLng = L.latLng(lotData.latitude, lotData.longitude);
      const distance = currentPosLatLng.distanceTo(lotPositionLatLng);
      const distanceInMiles = (distance*0.000621371192).toFixed(1);


    return <>{distanceInMiles} mi</>;
    }

    return "";
  };

  // Find current date set to midnight for comparison (for expiration calc)
  const currentDate = new Date();
  currentDate.setHours(0, 0, 0, 0);



  // Single Lot gets lotid from redux state and display accordingly
  return (
    <>
      {lotData && (
        <div
          className={
            display === "half" ? "overflow-y-hidden userview-lotinfo flex flex-col w-full h-full" : "overflow-y-auto userview-lotinfo flex flex-col w-full h-full"
          }
        >
          <div className="flex flex-col pl-2 basis-1/2 rounded-xl">

            {/* small control element */}
            <SmallControlElement/>

            <div className="flex flex-row items-baseline justify-start gap-1 mt-2 ml-2 text-lg text-gray-700">
              <span className="font-medium tracking-wide">{lotData.name}</span>
              <div className="absolute ml-auto top-4 right-4">
                <BookmarkButton lotid={lotData.lotid} />
              </div>
            </div>
            <div className="flex flex-row justify-start gap-1 px-2 mb-1.5">
            {lotStallsRemaining[lotData.lotid]!==undefined || lotStallsRemaining[lotData.lotid] !=="nodata"?
                lotStallsRemaining[lotData.lotid] > 50? (
                    <i className="flex text-green-500 fas fa-circle "></i>
                  ) : lotStallsRemaining[lotData.lotid] > 25 ? (
                    <i className="flex text-yellow-500 fas fa-circle "></i>
                  ) : (
                    <i className="flex text-red-500 fas fa-circle "></i>
                  ): <i className="text-sm text-gray-400 align-middle -translate-y-1 fas fa-circle "></i> }
                {!!(lotStallsRemaining ) && (<TextDescription stallsRemaining={lotStallsRemaining[lotData.lotid]}/>)}
            </div>

            {/* Show announcement if dates are active, showing partial announcement in lot card*/}
            {lotAnnouncement && (
              <div
                className={
                  lotAnnouncement.announcement === "N/A" ||
                  (new Date(lotAnnouncement.startDate) > currentDate && currentDate < new Date(lotAnnouncement.endDate))
                    ? "hidden flex-row flex-nowrap w-[100%]"
                    : "flex flex-row flex-nowrap w-[100%]"
                }
              >
                <div
                  onClick={openModal}
                  className="flex flex-row px-1 mx-2 mb-1 truncate border rounded border-yellow-700/60 bg-yellow-400/40 place-self-center place-items-center"
                >
                  <i className="text-lg text-yellow-500 -translate-y-px fa-solid fa-triangle-exclamation"></i>
                  <span className="px-2 truncate yellow-800">{lotAnnouncement.announcement}</span>
                  {/* Dialog box for complete announcement readout*/}
                  <Transition appear show={modalShowing} as={Fragment}>
                    <Dialog as="div" className="fixed inset-0 z-[1300] overflow-y-auto" onClose={closeModal}>
                      <div className="min-h-screen px-4 text-center">
                        <Transition.Child
                          as={Fragment}
                          enter="ease-out duration-300"
                          enterFrom="opacity-0"
                          enterTo="opacity-100"
                          leave="ease-in duration-200"
                          leaveFrom="opacity-100"
                          leaveTo="opacity-0"
                        >
                          <Dialog.Overlay className="fixed inset-0 bg-black opacity-30" />
                        </Transition.Child>

                        {/* This element is to trick the browser into centering the modal contents. */}
                        <span className="inline-block h-screen align-middle" aria-hidden="true">
                          &#8203;
                        </span>
                        <Transition.Child
                          as={Fragment}
                          enter="ease-out duration-300"
                          enterFrom="opacity-0 scale-95"
                          enterTo="opacity-100 scale-100"
                          leave="ease-in duration-200"
                          leaveFrom="opacity-100 scale-100"
                          leaveTo="opacity-0 scale-95"
                        >
                          <div className="inline-block w-full max-w-md p-6 my-8 overflow-hidden text-left align-middle transition-all transform bg-white shadow-xl rounded-2xl">
                            <Dialog.Title
                              as="h3"
                              className="mx-2 text-lg font-medium leading-6 text-center text-gray-900"
                            >
                              <i className="mr-2 text-xl text-yellow-500 fa-solid fa-triangle-exclamation"></i>
                              Announcement: {lotData.name}
                            </Dialog.Title>
                            <div className="p-2 mt-2">
                              <p className="text-sm text-slate-800">{lotAnnouncement.announcement}</p>
                            </div>

                            <div className="mt-4">
                              <button
                                type="button"
                                className="inline-flex justify-center px-4 py-2 text-sm font-medium bg-yellow-100 border border-transparent rounded-md text-yellow-900/80 hover:bg-red-200 focus:outline-none focus-visible:ring-2 focus-visible:ring-offset-2 focus-visible:ring-rose-500"
                                onClick={closeModal}
                              >
                                Got it, thanks!
                              </button>
                            </div>
                          </div>
                        </Transition.Child>
                      </div>
                    </Dialog>
                  </Transition>
                </div>
              </div>
            )}

            <div className="flex flex-row ml-2 ">
              <a href={`https://www.google.com/maps/dir/?api=1&destination=${lotData.latitude},${lotData.longitude}`}>
                <Directions />
              </a>
            </div>
            <div className="flex flex-row ml-4">
              <div className="text-sm font-normal distance">{getDistance()}</div>
            </div>
            <div className="flex flex-row justify-between w-full basis-1/2">
                {/* Fullness visualization */}
                <div className="flex basis-1/2 ">
                  {lotData.usedstalls !== undefined && lotTotalStalls !== undefined && (
                  <FullnessCarsVis
                  totalStalls={lotTotalStalls}
                  usedStalls={lotData.usedstalls}/>)}
                </div>
                <div className="flex flex-col text-sm font-medium text-gray-600 pl-7 justify-self-end basis-1/2">
                  <div className="flex flex-col ml-2 text-sm font-semibold tracking-tight uppercase">Total spaces</div>
                  {lotAccPasses &&
                    lotAccPasses.map(function (accPass, idx) {
                      return (
                        <div key={accPass.accpassid}>
                          <AcceptedPass
                            passShortName={accPass.name === "Disabled Spots" ? "" : accPass.shortname}
                            occupancy={accPass.allottedstalls}
                            iconClassName={
                              accPass.name === "Disabled Spots"
                                ? "fas fa-wheelchair permit-symbol-custom text-indigo-500"
                                : "permit-symbol-custom"
                            }
                          />
                        </div>
                      );
                    })}
              </div>
            </div>
            </div>
            {display === "full" && halfHoursPrediction && lotPercentFull !== undefined && (
              <div className="flex flex-col flex-auto flex-grow w-full border-t border-t-slate-300">
                <HalfHoursChart halfhours={halfHoursPrediction} currentPercent={lotPercentFull} />
              </div>
            )}
        </div>
      )}
    </>
  );
}
export const TextDescription = ({stallsRemaining})=>{
  let textDescription;
  if (stallsRemaining === undefined ){
    textDescription = "No data available";
  }
  else if (stallsRemaining>50){
    textDescription = "Many available spaces";
  }
  else if (stallsRemaining > 25){
    textDescription = "Some available spaces";
  }
  else {
    textDescription = "Few available spaces";
  }

  return (
  <>
  <div className="text-xs font-medium text-gray-500">
    {textDescription}
  </div>
  </>)
}