import { useState, useEffect } from "react";
import { useMap, Marker } from "react-leaflet";
import L from "leaflet";
import Radio from "../../../assets/icons/Radio.svg";
import { useDispatch, useSelector } from "react-redux";
import {updateMapData} from "../../../redux/mapSlice";

export default function CurrentLocationMarker() {
  const watchCurrentPosition = useSelector((state)=>state.map.watchCurrentPosition);
  const currentLocation = useSelector((state)=>state.map.currentLocation);
  const [currentPos, setCurrentPos] = useState();
  const [bbox, setBbox] = useState([]);
  const map = useMap();
  const dispatch = useDispatch();
  const [timeoutRefresh, setTimeoutRefresh] = useState()
  useEffect(() => {
    map.locate({watch:true, timeout:5000, maximumAge:5000, enableHighAccuracy:false}).on("locationfound", function (e) {
      setCurrentPos(e.latlng);
      dispatch(updateMapData({currentLocation: {lat:e.latlng.lat, lng:e.latlng.lng}}));
      if (!currentLocation){
        // TODO: Why the U has accuracy radius of 5000? even when it's correct
        // And why is Chrome not getting accurate location but firefox developer does
        const radius = Math.min(18,e.accuracy);
        const circle = L.circle(e.latlng, radius);
        circle.addTo(map);
      }

    });
    map.on("locationerror", function (e) {
      console.error(e);
    });
    if (currentLocation)
      map.flyTo(new L.LatLng(currentLocation.lat, currentLocation.lng));

  }, [map, watchCurrentPosition]);
  const iconCurrent = new L.Icon({
    iconUrl: Radio,
    iconRetinaUrl: Radio,
    iconSize: [30,30],
});
  return <>{currentPos && <Marker position={currentPos} icon={iconCurrent}></Marker>}</>;
}
