import {useLocation, matchPath } from "react-router";
import { useDispatch, useSelector } from "react-redux";
import { showHalf } from "../../../redux/lotSelectSlice";
import { useMapEvents } from "react-leaflet";
import { useCallback } from "react";
import {useHistory} from "react-router-dom";

// Check if a URL is on the urlString that gets passed in
const useIsOnRoute = (urlString) => {
    const currentURL = useLocation();
    const match = matchPath(currentURL.pathname, {
      path: urlString,
      exact: true,
    });   

    return match?.isExact ? true : false     
}

// This function handles what location is routed to if the map is clicked in the User view in a variety of situations
export const useOnMapClick = () => {    
    const dispatch = useDispatch();
    const isBookmarkURL = useIsOnRoute("/map/bookmarks")
    const isLotViewURL = useIsOnRoute("/map/lot/:id")
    const isNearbyURL = useIsOnRoute("/map/nearby")
    const isSearchURL = useIsOnRoute("/map/search/:terms/:lat/:long")
    const display = useSelector((state) => state.lotSelect.display);
    const displayIsHalf = display === "half"
    let history = useHistory();

    const onMapClick = useCallback (
     () => {
        if (isBookmarkURL)
        {
            dispatch(showHalf({ componentToLoad: "bookmarks" }));
        }
        if (isLotViewURL)
        {
            displayIsHalf ? history.push('/map/nearby') : dispatch(showHalf({ componentToLoad: "lot" }));          
        }
        if (isNearbyURL)
        {
            dispatch(showHalf({ componentToLoad: "nearby" }));        
        }
        if (isSearchURL)
        {
            dispatch(showHalf({ componentToLoad: "search" }));        
        }
    },[isBookmarkURL,isLotViewURL,isNearbyURL,isSearchURL,displayIsHalf]);

    const map = useMapEvents({
        click: onMapClick
      });
}

// Wrap everything in a component to work correctly in leaflet
export const MapClickComponent = () => {
    useOnMapClick();
    return <></>
}