import React, { useState, useEffect } from "react";
import { MapContainer, TileLayer } from "react-leaflet";
import "leaflet/dist/leaflet.css";
import "./UserMap.css";
import axios from "axios";
import { fetchLotsLayer } from "./MapConstants";
import { useDispatch, useSelector } from "react-redux";
import {updateMapData} from "../../../redux/mapSlice";
import CurrentLocationMarker from "./CurrentLocationMarker";
import LotsLayer from "./LotsLayer";
import Legend from './Legend';
import { MapClickComponent } from "./MapClickComponent";

import { updatePasses } from "../../../utils/pass";


function UserMap() {
  const [mapData, setMapData] = useState();
  const [map, setMap] = useState(null);
  const lotStallsRemaining={};
  var lotPasses={};
  // a list of dictionaries containing name/shortname of all passes
  var passes=[];
  const [lotStallsRemainingFinished, setLotStallsRemainingFinished] = useState(false);
  const [lotPassesFinished, setLotPassesFinished] = useState(false);
  const dispatch = useDispatch();
  const Toggles = useSelector((state) => state.filterToggles.Toggles);

  useEffect(()=>{
    // 'lot/acceptedpasses/'
    const passesUrl = `${process.env.REACT_APP_API_URL}/api/lot/acceptedpasses/`;
    const getPassesConfig = {
      url: passesUrl,
      method: "GET",
      headers: {
        "Content-Type": "application/json",
      },
    }

    axios(getPassesConfig)
        .then(response =>{
          lotPasses = response.data;
        })
        .catch(error=>{
          console.error("error occured while fetching lot passes for map view.")
        })
        .finally(()=>{
          setLotPassesFinished(true);
          dispatch(updateMapData({lotPasses:lotPasses}));
        });

  },[])

  useEffect(()=>{
    updatePasses(dispatch,Toggles);
  },[])


  useEffect(() => {
    if (!mapData)
      fetchLotsLayer()
        .then((response) => response.json())
        .then((result) => {
          setMapData(result);
        })
        .catch((error) => console.error(error));

    // If Map is loaded and geoJson is referenced (loaded)
    if (mapData){
      // Get stalls remaining for all lots
      for (let feature of mapData.features){
        let plot = parseInt(feature.properties.PLOT);
        const stallsRemainingUrl = `${process.env.REACT_APP_API_URL}/api/lot/${plot}/stallsremaining/`;

        const getStallsRemainingConfig = {
              url: stallsRemainingUrl,
              method: "GET",
              headers: {
                "Content-Type": "application/json",
              },
            }

        axios(getStallsRemainingConfig)
        .then(response => {
          lotStallsRemaining[plot] = response.data; // change to lotPercents if percetage threshold is used
        })
        .catch(error=>{
          lotStallsRemaining[plot] = "nodata";
        })
        .finally(()=>{
          if (Object.keys(lotStallsRemaining).length === Object.keys(mapData.features).length){
            setLotStallsRemainingFinished(true);
            dispatch(updateMapData({lotStallsRemaining:lotStallsRemaining})); // change to lotPercents if percentage threshold is used
          }
        })
      }

    }
  }, [mapData]);

  //mapbox://styles/bluqzy/ckywcvgqx001e15obhw6nfyqz
  //pk.eyJ1IjoiYmx1cXp5IiwiYSI6ImNrdXl6aHBrODc3OGIycG56cG0yZmNwanEifQ.sayISMyWW1fvtwbesghNvw
  // https://api.mapbox.com/styles/v1/bluqzy/ckywcvgqx001e15obhw6nfyqz/tiles/{tilesize}/{z}/{x}/{y}{@2x}?access_token=pk.eyJ1IjoiYmx1cXp5IiwiYSI6ImNreXdkNWcwYzA3Z2UydG85aHI2OGlmbHEifQ.VhCvUs5GZh_43yNdmWMNkQ
  //https://api.mapbox.com/styles/v1/mapbox/satellite-v9/tiles/512/10/197/384%7B@2x%7D?access_token=pk.eyJ1IjoiYmx1cXp5IiwiYSI6ImNrdXl6aHBrODc3OGIycG56cG0yZmNwanEifQ.sayISMyWW1fvtwbesghNvw
  return (
    <div className="map-wrapper z-[1000]">
      <MapContainer
        center={[40.76, -111.891]}
        zoom={13}
        scrollWheelZoom={true}
        zoomControl={false}
        whenCreated={setMap}>
        <TileLayer
          attribution='&copy; <a href="https://www.openstreetmap.org/copyright">OpenStreetMap</a> contributors'
          url="https://api.mapbox.com/styles/v1/bluqzy/ckywcvgqx001e15obhw6nfyqz/tiles/256/{z}/{x}/{y}@2x?access_token=pk.eyJ1IjoiYmx1cXp5IiwiYSI6ImNrdXl6aHBrODc3OGIycG56cG0yZmNwanEifQ.sayISMyWW1fvtwbesghNvw"
        />
        <MapClickComponent/>
        <Legend map={map}/>
        (mapData && lotStallsRemainingFinished && lotPassesFinished && <LotsLayer mapData={mapData} lotStallsRemainingFinished={lotStallsRemainingFinished}/>)
        (mapData && <CurrentLocationMarker/>)

      </MapContainer>
    </div>
  );
}

export default UserMap;
