import * as d3 from "d3";
import { useSelector } from "react-redux";
import React, { useEffect, useRef } from "react";
export default function FullnessCarsVis({ totalStalls, usedStalls, transitionEnded = false }) {
  const maxLotCapacity = useSelector((state) => state.map.maxLotCapacity);
  const display = useSelector((state) => state.lotSelect.display);
  const modalTransitionEnd = useSelector((state) => state.lotSelect.transitionEnd || transitionEnded);
  const visRef = useRef();
  const gray = "#777777";
  const green = "#60d394";
  const yellow = "#ffc55d";
  const red = "#ee6055";
  const error_color = "#d3d3d3";
  const carIconColor = (stallsRemaining)=>{
    // No used stall data exists color
    if (stallsRemaining === "nodata") {
      return error_color;
    }
    // most available stalls
    if (stallsRemaining > 50) {
      return green;
    }
    // medium available stalls
    else if (stallsRemaining > 25) {
      return yellow;
    }
    // least available stalls
    else {
      return red;
    }
  }
  const maxCars = 30;
  useEffect(() => {
    console.log(totalStalls, usedStalls);

    if (modalTransitionEnd) {
      //Make SVG
      // View ports
      const parentContainer = visRef.current.parentNode.parentNode;
      const visDiv = d3.select(visRef.current);
			const minCarsThreshold = 5;

      let numCarScale = d3.scaleLinear().domain([0, maxLotCapacity]).range([0, maxCars]);
			let scaledNumCars = numCarScale(totalStalls); //normal Scaled number of car icons to display
			let reachedMinimumCars = scaledNumCars<minCarsThreshold; //true if num car icons calculated less than threshold
			//scale for when num car icons reached minimum
			let minCarsThresholdScale = d3.scaleLinear().domain([0,totalStalls]).range([0,minCarsThreshold]);
      let numCars = reachedMinimumCars?  minCarsThreshold:scaledNumCars;
      //generate a d3 range for the total number of required elements
      var data = d3.range(numCars);

      //container to hold the grid
      var container = visDiv
      .selectAll("div")
        .data([0])
        .join("div")
        .attr("class", `grid grid-cols-6 md:grid-cols-8 px-2 gap-1 place-items-center`);
        container
        .selectAll(".icon")
        .data(data)
        .join("i")
        .attr("class", ()=>reachedMinimumCars? "text-xl mx-2 icon  fa-solid fa-car md:scale-125 align-top": "text-xl mx-2 fa-solid fa-car icon text-xl md:scale-125 align-top")
        .attr("id", function (d) {
          return "icon" + d;
        })
        // .classed(`text-slate-300/60`, true);

        //Color occupied car icons
        let numOccupied = reachedMinimumCars? minCarsThresholdScale(usedStalls) : numCarScale(usedStalls);

        d3.selectAll(".icon").style(`color`, function (d, i) {
        if (d < numOccupied) {
          return carIconColor(totalStalls-usedStalls);
        } else {
          return "#e2e8f0";
        }
      });
      // console.log(numOccupied, numCars);

    }
  }, [modalTransitionEnd, totalStalls, maxLotCapacity, usedStalls]);

  return (
    <>
      <div id="percentFullVis" className="w-full h-full">
        <div ref={visRef} width="100%" height="100%"></div>
      </div>
    </>
  );
}
