import { useRef, useEffect } from "react";
import * as d3 from "d3";
import { useSelector } from "react-redux";

export default function FullnessVis({ percentage, transitionEnded = false, showPercent = false }) {
  const display = useSelector((state) => state.lotSelect.display);
  const modalTransitionEnd = useSelector((state) => state.lotSelect.transitionEnd || transitionEnded);
  const visRef = useRef();
  function setColorThreshold(percent) {
    // percent = Math.random();
    if (percent === "nodata") {
      return "#d3d3d3";
    }
    if (percent < 0.25) {
      return "#86efac"; //Green 300
    } else if (percent < 0.75) {
      return "#ffd97d";
    } else {
      return "#e11d48"; //Rose 600
    }
  }
  function setPercentText(percent) {
    if (percent === "nodata") {
      return "Unavailable";
    }
    return `${Math.round(percent * 100)}%`;
  }
  function setDescriptionText(percent) {
    // percent = Math.random();
    if (percent === "nodata") {
      return "Unavailable";
    }
    if (percent < 0.25) {
      return "Not busy";
    } else if (percent < 0.75) {
      return "Normal";
    } else {
      return "Busy";
    }
  }

  useEffect(() => {
    if (modalTransitionEnd) {
      let colorArray = ["#86efac", "#ffd97d", "#e11d48"];
      const data = [
        { percentage: 100, color: percentage < 0.25 ? "#86efac" : "#d1d5db", startAngle: 0, endAngle: 2 * Math.PI },
        {
          percentage: percentage * 100,
          color: setColorThreshold(percentage),
          startAngle: Math.PI,
          endAngle: Math.PI + (2 * Math.PI * percentage) / 2,
        },
        {
          percentage: percentage * 100,
          color: setColorThreshold(percentage),
          startAngle: Math.PI,
          endAngle: Math.PI - (2 * Math.PI * percentage) / 2,
        },
      ];
      // View ports
      const parentContainer = visRef.current.parentNode.parentNode;
      const width = parentContainer.clientWidth;
      const height = parentContainer.clientHeight;
      const svgSelect = d3.select(visRef.current);
      svgSelect.attr("width", width).attr("height", height);
      svgSelect.attr("viewBox", `0 0 ${width} ${height}`);

      // Donut = Inner circle over the outer circle
      const min = Math.min(width, height);
      const innerRadius = (min / 2) * 0.7;
      const outerRadius = (min / 2) * 0.9;
      //make arcs (calculations)
      const arc = d3.arc().outerRadius(outerRadius).innerRadius(innerRadius);

      //gradient Arc:
      const gGradient=svgSelect.selectAll(".arcfill").data([0]).join("g")
      .attr("class", "arcfill")
      .attr("transform", `translate(${width / 2},${height / 2})`);

      // Gather visual elements to svg
      const gSelect = svgSelect
        .selectAll("g")
        .data([0])
        .join("g")
        .attr("transform", `translate(${width / 2},${height / 2})`);

      //Handle Text size:
      gSelect.selectAll("text").data([percentage]).join("text").remove();

      const textSelect = gSelect.selectAll("text").data([percentage]).join("text").attr("text-anchor", "middle");
      if (showPercent) {
        textSelect.text((d) => setPercentText(d));
        textSelect.attr("class", `text-xl font-blocky font-semibold`);
      } else {
        textSelect.text((d) => setDescriptionText(d));
        if (display === "half") textSelect.attr("class", "uppercase font-bold tracking-wide");
        else if (display === "full") textSelect.attr("class", "uppercase font-medium");
      }
      //path
      const path = gSelect
        .selectAll("path")
        .data(data)
        .join("path")
        .attr("class", "piechart")
        // .attr("d", arc)
        .attr("fill", (d,i) => d.color)
        .transition()
        .duration(function (d, i) {
          if (i === 0) return 100;
          return 1500;
        })

        .attrTween("d", function (d) {
          var i = d3.interpolate(d.startAngle + 0.1, d.endAngle);
          return function (t) {
            d.endAngle = i(t);
            return arc(d);
          };
        });

    }
  }, [percentage, modalTransitionEnd]);
  // viewBox={"0 0 200 200"} width="100%" height="100%"
  return (
    <div id="percentFullVis" className="w-full h-full">
      <svg ref={visRef} width="100%" height="100%" preserveAspectRatio="xMinYMid meet"></svg>
    </div>
  );
}
