import { useEffect, useRef } from "react";
import * as d3 from "d3";
import { useSelector } from "react-redux";

export default function HalfHoursChart({ halfhours, currentPercent, transitionEnded = false }) {
  const visHalfHoursRef = useRef();
  // halfhours=[0.30, 0.60,0.70,1,0.80,0.72]; //Uncomment to use some randoms
  // add time rightnow to the beginning

  // halfHoursPred.unshift(currentPercent);

  const modalTransitionEnd = useSelector((state) => state.lotSelect.transitionEnd || transitionEnded);

  function makeTimeSeries(halfHoursPredArray) {
    let date = new Date();
    let h = date.getHours();
    let m = date.getMinutes();
    let newData = [];
    // make array of time by halfhours
    if (m > 30) m = 30;
    else m = 0;
    date.setMinutes(m);
    let timeMl = date.getTime();
    for (let i = 0; i < halfHoursPredArray.length; i++) {
      date.setTime(timeMl + 1000 * 60 * 30 * i);
      let entry = {
        index: i,
        percentage: Math.max(10, halfHoursPredArray[i] * 100),
        time: date.getTime(),
        hour: h,
        minute: m,
      };
      m = m === 30 ? 0 : 30;
      h = m === 30 ? h : h + 1;
      h = h === 25 ? 0 : h;
      newData.push(entry);
    }
    return newData;
  }

  // Utils for rounded svg path
  function roundedRect(x, y, w, h, r, tl, tr, bl, br) {
    var retval;
    retval = "M" + (x + r) + "," + y;
    retval += "h" + (w - 2 * r);
    if (tr) {
      retval += "a" + r + "," + r + " 0 0 1 " + r + "," + r;
    } else {
      retval += "h" + r;
      retval += "v" + r;
    }
    retval += "v" + (h - 2 * r);
    if (br) {
      retval += "a" + r + "," + r + " 0 0 1 " + -r + "," + r;
    } else {
      retval += "v" + r;
      retval += "h" + -r;
    }
    retval += "h" + (2 * r - w);
    if (bl) {
      retval += "a" + r + "," + r + " 0 0 1 " + -r + "," + -r;
    } else {
      retval += "h" + -r;
      retval += "v" + -r;
    }
    retval += "v" + (2 * r - h);
    if (tl) {
      retval += "a" + r + "," + r + " 0 0 1 " + r + "," + -r;
    } else {
      retval += "v" + -r;
      retval += "h" + r;
    }
    retval += "z";
    return retval;
  }

  useEffect(() => {
    if (halfhours === "nodata") return;
    if (!visHalfHoursRef.current) return;
    // Render after CSSanimation from mainmodal
    if (modalTransitionEnd) {
      const parentContainer = visHalfHoursRef.current.parentNode;
      const width = parentContainer.getBoundingClientRect().width;
      const height = parentContainer.getBoundingClientRect().height;
      const svgSelect = d3.select(visHalfHoursRef.current);
      svgSelect.selectAll("g").remove();
      svgSelect.attr("width", width).attr("height", height);
      svgSelect.attr("viewBox", `0 0 ${width} ${height}`);

      // data
      const halfHoursPred = [...halfhours];
      halfHoursPred.splice(0, 0, currentPercent);

      let data = makeTimeSeries(halfHoursPred);
      //Scales:
      const scaleTime = d3
        .scaleTime()
        .domain([Date.now() - 1000 * 60 * 30, Date.now() + 1000 * 60 * 60 * 3])
        .range([5, width - 5])
        .nice();
      const xAxis = d3.axisBottom(scaleTime).ticks(4).tickFormat(d3.timeFormat("%I %p"));

      const scalePercent = d3
        .scaleLinear()
        .domain([100, 0])
        .range([15, height - 20]);

      // DRAW AXIS + Labels
      const axisGroup = svgSelect
        .selectAll(".time-labels")
        .data([0])
        .join("g")
        .attr("class", "time-labels")
        .attr("transform", `translate(0,${height - 20})`)
        .call(xAxis);

      // const axisPercent = d3.axisLeft(scalePercent)
      // svgSelect.selectAll(".yAxis").data([0]).join("g")
      // .attr("class", "yAxis")
      // .attr("transform", `translate(25,0)`)
      // .call(axisPercent)

      //DRAW BARS
      let now = new Date(Date.now());
      const groupSelect = svgSelect
        .selectAll(".barGroup")
        .data(data)
        .join("g")
        .attr("class", "barGroup")
        .attr("transform", (d, i) => `translate(0, 0)`);
      groupSelect.each(function (d, i) {
        d3.select(this)
          .selectAll(".percentbar")
          .data((d) => [d])
          .join("path")
          .attr("class", "percentbar")
          .attr("d", (d) => {
            let x = scaleTime(new Date(d.time));
            // let x = scaleTime(new Date(now.getFullYear(), now.getMonth(), now.getDate(), d.hour,d.minute));
            let y = scalePercent(d.percentage);
            let barWidth = width / halfHoursPred.length - 10;
            let barHeight = scalePercent(0) - scalePercent(d.percentage);
            return roundedRect(x, y, barWidth, barHeight, 5, 1, 1, 0, 0);
          })
          .attr("fill", (d) => {
            if (d.index === 0) return "#2563eb";
            return "#60a5fa";
          })
          .attr("opacity", (d) => {
            if (d.index !== 0) return "0.8";
            return "1";
          });
      });
    }
  }, [halfhours, currentPercent, modalTransitionEnd]);

  function setDescriptionText(percent) {
    // percent = Math.random();
    if (percent === "nodata" || percent===undefined) {
      return "Unavailable";
    }
    else if (percent < 0.25) {
      return "Many empty spots";
    } else if (percent < 0.75) {
      return "As busy as it gets";
    } else {
      return "It might take a while";
    }
  }

  return (
    <>
      {halfhours && halfhours !== "nodata" && (
        <>
          <div className="mt-1 ml-3 font-medium prediction-title text-slate-600 font-italic">
            <span className="italic text-rose-500">&bull;Live:</span>
            {/* <span className="px-1 text-slate-400">{setDescriptionText(currentPercent)}</span> */}
            <span className="px-1 text-sm text-slate-500">Predicted lot fullness</span>
          </div>
          <div id="halfHoursVis" className="h-[90%] w-[90%] self-center">
            <svg ref={visHalfHoursRef} width="100%" height="100%" preserveAspectRatio="none"></svg>
          </div>
        </>
      )}
      {halfhours === "nodata" && (
        <>
          <div className="mt-1 ml-3 prediction-title text-slate-600 font-italic">
            <span className="text-sm italic font-normal">Prediction unavailable</span>
          </div>
        </>
      )}
    </>
  );
}
